(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    491802,       8846]
NotebookOptionsPosition[    488205,       8777]
NotebookOutlinePosition[    488603,       8793]
CellTagsIndexPosition[    488560,       8790]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Bounds on Magnitudes of Range Polynomial Coefficients under Max-Throttle \
Constraint\
\>", "Section",
 CellChangeTimes->{{3.806760841889749*^9, 3.806760852568528*^9}, {
  3.806760896117394*^9, 3.806760912268588*^9}, {3.806760945589011*^9, 
  3.806760946114862*^9}},ExpressionUUID->"5c3180f5-120f-4e11-9b6c-\
a04160ce1001"],

Cell[CellGroupData[{

Cell[TextData[{
 "We would like to bound the search space for polynomial range (i.e. phase) \
models.\n\nBounds on the Taylor series approximation error become unwieldy at \
high polynomial orders: the high-order derivatives of the throttle function \
are not nicely bounded.\n\nAnother way of bounding the coefficients of the \
range polynomial is to impose a bound on the magnitude of the throttle \
function.  Suppose that the throttle function plays the role of ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["x", ".."], TraditionalForm]],ExpressionUUID->
  "72c1be2d-0916-4dde-af7c-63a0731e9877"],
 ", so that its double integral is the (not necessarily polynomial) range \
function.  Let us consider the linear minimum mean squared error range \
polynomial corresponding to this range function.\n\nTo obtain the LMMSE \
estimate, we write"
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.806760917785946*^9, 3.806761335047249*^9}, {
   3.8067613913807783`*^9, 3.806761433895864*^9}, {3.806761517800511*^9, 
   3.806761525560769*^9}, 3.806761617129601*^9, {3.806777121978759*^9, 
   3.806777122345688*^9}, {3.806777160248637*^9, 3.8067771974158373`*^9}, {
   3.806800655096861*^9, 3.806800720007959*^9}, 
   3.8081343608007603`*^9},ExpressionUUID->"f22839e8-9d32-47d0-8eda-\
bda2e10543bf"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      UnderscriptBox["min", 
       SubscriptBox["c", "n"]], 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", "0"], "T"], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "|", " ", 
     RowBox[{
      RowBox[{"x", "[", "t", "]"}], " ", "-", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "d"], " ", 
       RowBox[{
        SubscriptBox["c", "n"], 
        SuperscriptBox["t", "n"]}]}]}], " ", "|", 
     RowBox[{"^", "2"}]}], 
    StyleBox[",", "Text",
     FontWeight->"Plain"], 
    StyleBox[" ", "Text",
     FontWeight->"Plain"], 
    StyleBox[
     RowBox[{"with", " ", "normal", " ", "equations"}], "Text",
     FontWeight->"Plain"]}], "\n", 
   RowBox[{
    RowBox[{"0", " \[AlignmentMarker]", "=", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["\[Integral]", "0"], "T"], 
      RowBox[{
       RowBox[{"\[DifferentialD]", "t"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "[", "t", "]"}], " ", "-", " ", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"m", "=", "0"}], "d"], " ", 
          RowBox[{
           SubscriptBox["c", "m"], 
           SuperscriptBox["t", "m"]}]}]}], ")"}], 
       RowBox[{
        RowBox[{"(", GridBox[{
           {"1", "t", "\[CenterEllipsis]", 
            SuperscriptBox["t", "d"]}
          }], ")"}], "\[Transpose]"}]}]}]}], 
    StyleBox[",", "Text",
     FontWeight->"Plain"], 
    StyleBox[" ", "Text",
     FontWeight->"Plain"], 
    StyleBox["or", "Text",
     FontWeight->"Plain"]}], "\n", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["\[Integral]", "0"], "T"], 
     RowBox[{
      RowBox[{"\[DifferentialD]", "t"}], " ", 
      RowBox[{"x", "[", "t", "]"}], 
      RowBox[{
       RowBox[{"(", GridBox[{
          {"1", "t", "\[CenterEllipsis]", 
           SuperscriptBox["t", "d"]}
         }], ")"}], "\[Transpose]"}]}]}], " \[AlignmentMarker]", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"m", "=", "0"}], "d"], " ", 
     RowBox[{
      SubscriptBox["c", "m"], 
      RowBox[{
       RowBox[{"(", GridBox[{
          {
           FractionBox[
            SuperscriptBox["T", 
             RowBox[{"m", "+", "1"}]], 
            RowBox[{"m", "+", "1"}]], 
           FractionBox[
            SuperscriptBox["T", 
             RowBox[{"m", "+", "2"}]], 
            RowBox[{"m", "+", "2"}]], "...", 
           FractionBox[
            SuperscriptBox["T", 
             RowBox[{"m", "+", "d", "+", "1"}]], 
            RowBox[{"m", "+", "d", "+", "1"}]]}
         }], ")"}], "\[Transpose]"}]}]}]}]}]}]], "DisplayFormula",
 Evaluatable->False,
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->False,
 CellChangeTimes->{{3.8067615660524607`*^9, 3.806761566551759*^9}, {
   3.806761620746188*^9, 3.8067616625789957`*^9}, {3.8067746324670362`*^9, 
   3.8067747213022223`*^9}, {3.80677495033084*^9, 3.8067749704391108`*^9}, 
   3.8067771195417347`*^9, 3.806777197416567*^9, {3.8067773121382008`*^9, 
   3.806777313314128*^9}, {3.8067838590605097`*^9, 3.8067838598910913`*^9}, {
   3.806800844382824*^9, 3.806800855057048*^9}, {3.8068009502513323`*^9, 
   3.8068009944608717`*^9}, {3.806950966686997*^9, 3.806950968956753*^9}, 
   3.808145815885543*^9},
 TextAlignment->
  AlignmentMarker,ExpressionUUID->"a9a1eb48-ef12-4b68-9e11-b89eced0e6ae"],

Cell[TextData[{
 "Let us non-dimensionalize the problem by taking ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"t", "\[Rule]", 
      RowBox[{"u", " ", "T"}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["T", 
        RowBox[{"m", "-", "1"}]], 
       SubscriptBox["c", "m"]}], "\[Rule]", 
      SubscriptBox["b", "m"]}]}], "}"}], TraditionalForm]], "InlineFormula",
  ExpressionUUID->"d83f0019-2e0e-47e8-bb3f-9d907016cc91"],
 "."
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.80677552252682*^9, 3.806775538901305*^9}, {
   3.80677626193685*^9, 3.806776340253071*^9}, {3.806776415903007*^9, 
   3.806776435545257*^9}, 3.806777197416898*^9, {3.8067826985464287`*^9, 
   3.806782788350843*^9}},ExpressionUUID->"f38a1e70-bd79-4ea8-a0a8-\
c74e36c7852f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SuperscriptBox[
    SubscriptBox["\[Integral]", "0"], "1"], 
   RowBox[{
    RowBox[{"\[DifferentialD]", "u"}], " ", 
    RowBox[{"x", "[", 
     RowBox[{"u", " ", "T"}], "]"}], 
    RowBox[{
     RowBox[{"(", GridBox[{
        {"1", "u", "\[CenterEllipsis]", 
         SuperscriptBox["u", "d"]}
       }], ")"}], "\[Transpose]"}]}]}], " \[AlignmentMarker]", "=", " ", 
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"m", "=", "0"}], "d"], " ", 
   RowBox[{
    SubscriptBox["b", "m"], 
    RowBox[{
     RowBox[{"(", GridBox[{
        {
         FractionBox["1", 
          RowBox[{"m", "+", "1"}]], 
         FractionBox["1", 
          RowBox[{"m", "+", "2"}]], "...", 
         FractionBox["1", 
          RowBox[{"m", "+", "d", "+", "1"}]]}
       }], ")"}], "\[Transpose]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"\[AlignmentMarker]", 
  RowBox[{"=", 
   RowBox[{
    RowBox[{"(", GridBox[{
       {
        FractionBox["1", "1"], 
        FractionBox["1", "2"], "\[CenterEllipsis]", 
        FractionBox["1", 
         RowBox[{"d", "+", "1"}]]},
       {
        FractionBox["1", "2"], 
        FractionBox["1", "3"], " ", " "},
       {"\[VerticalEllipsis]", " ", "\[DescendingEllipsis]", 
        "\[VerticalEllipsis]"},
       {
        FractionBox["1", 
         RowBox[{"d", "+", "1"}]], " ", "\[CenterEllipsis]", 
        FractionBox["1", 
         RowBox[{
          RowBox[{"2", "d"}], "+", "1"}]]}
      }], ")"}], " ", "b"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"\[AlignmentMarker]", 
  RowBox[{"=", " ", 
   RowBox[{
    RowBox[{"HilbertMatrix", "[", 
     RowBox[{"d", "+", "1"}], "]"}], ".", "b"}]}]}]}], "DisplayFormula",
 Evaluatable->False,
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->False,
 CellChangeTimes->{{3.806774755015679*^9, 3.806774759386128*^9}, 
   3.806774848162821*^9, {3.806774914087302*^9, 3.8067749487853327`*^9}, {
   3.806774984601512*^9, 3.8067750241758957`*^9}, {3.806775060311735*^9, 
   3.806775064173089*^9}, {3.806775318084794*^9, 3.806775322927322*^9}, {
   3.806775385444722*^9, 3.80677544246725*^9}, {3.8067754838103533`*^9, 
   3.806775513607945*^9}, {3.8067755480465508`*^9, 3.80677556068617*^9}, {
   3.806775637114263*^9, 3.8067756731359177`*^9}, {3.806775707814321*^9, 
   3.806775714041013*^9}, {3.806775758921629*^9, 3.806775798265832*^9}, {
   3.806775962792431*^9, 3.806776268440734*^9}, {3.806776360775009*^9, 
   3.806776518580283*^9}, {3.806776564609708*^9, 3.806776598533888*^9}, {
   3.8067768370991907`*^9, 3.806776863184926*^9}, 3.8067771974169693`*^9, {
   3.806777322151572*^9, 3.806777323618945*^9}, 3.80678328315012*^9, 
   3.806800879210063*^9, {3.806801287032922*^9, 3.806801300021899*^9}, 
   3.806950609667664*^9, {3.806950969944839*^9, 3.806950972530463*^9}},
 TextAlignment->
  AlignmentMarker,ExpressionUUID->"85584521-efc5-4a2a-a673-5bc15b436cbd"],

Cell[TextData[{
 "Now we may solve for the vector of non-dimensionalized coefficients ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "7c56ab4d-161a-4854-8c48-1d91eb5eae99"],
 ":"
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.8067766160454597`*^9, 3.806776642664384*^9}, {
   3.806776756765007*^9, 3.806776763878553*^9}, 3.806777197417018*^9, {
   3.806950837553009*^9, 
   3.8069508409074087`*^9}},ExpressionUUID->"06f6256a-c29f-4ec2-a7b9-\
b04cfba3f623"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"b", " \[AlignmentMarker]", "=", " ", 
   RowBox[{
    SuperscriptBox[
     SubscriptBox["\[Integral]", "0"], "1"], 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"u", " ", "T"}], "]"}], 
     RowBox[{
      SubscriptBox["P", "d"], "[", "u", "]"}], 
     RowBox[{"\[DifferentialD]", "u"}]}]}]}], 
  StyleBox[",", "Text",
   FontWeight->"Plain",
   FontColor->GrayLevel[0]], 
  StyleBox[" ", "Text",
   FontWeight->"Plain",
   FontColor->GrayLevel[0]], 
  StyleBox[
   RowBox[{"where", " ", "we", " ", 
    RowBox[{
     StyleBox["i", "Text",
      FontWeight->"Plain"], "ntroduce"}]}], "Text",
   FontWeight->"Plain",
   FontColor->GrayLevel[0]]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["P", "d"], "[", "u", "]"}], " \[AlignmentMarker]", "=", " ", 
   
   RowBox[{
    RowBox[{"Inverse", "[", 
     RowBox[{"HilbertMatrix", "[", 
      RowBox[{"d", "+", "1"}], "]"}], "]"}], 
    RowBox[{
     RowBox[{"(", GridBox[{
        {"1", "u", "...", 
         SuperscriptBox["u", "d"]}
       }], ")"}], "\[Transpose]"}]}]}], 
  StyleBox[",", "Text"], 
  StyleBox[" ", "Text"], 
  StyleBox[
   RowBox[{
   "and", " ", "it", " ", "will", " ", "be", " ", "helpful", " ", "to", " ", 
    "define"}], "Text"]}], "\n", 
 RowBox[{
  RowBox[{
   SubscriptBox["Q", "d"], "[", "u", "]"}], " \[AlignmentMarker]", "=", " ", 
  RowBox[{
   SuperscriptBox[
    SubscriptBox["\[Integral]", "0"], "u"], 
   RowBox[{
    RowBox[{
     SubscriptBox["P", "d"], "[", 
     SuperscriptBox["u", "\[Prime]"], "]"}], 
    RowBox[{"\[DifferentialD]", 
     SuperscriptBox["u", "\[Prime]"]}]}]}]}], "\n", 
 RowBox[{
  RowBox[{
   SubscriptBox["R", "d"], "[", "u", "]"}], " \[AlignmentMarker]", "=", " ", 
  RowBox[{
   SuperscriptBox[
    SubscriptBox["\[Integral]", "0"], "u"], 
   RowBox[{
    RowBox[{
     SubscriptBox["Q", "d"], "[", 
     SuperscriptBox["u", "\[Prime]"], "]"}], 
    RowBox[{"\[DifferentialD]", 
     SuperscriptBox["u", "\[Prime]"]}]}]}]}]}], "DisplayFormula",
 Evaluatable->False,
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->False,
 CellChangeTimes->{{3.806774755015679*^9, 3.806774759386128*^9}, 
   3.806774848162821*^9, {3.806774914087302*^9, 3.8067749487853327`*^9}, {
   3.806774984601512*^9, 3.8067750241758957`*^9}, {3.806775060311735*^9, 
   3.806775064173089*^9}, {3.806775318084794*^9, 3.806775322927322*^9}, {
   3.806775385444722*^9, 3.80677544246725*^9}, {3.8067754838103533`*^9, 
   3.806775513607945*^9}, {3.8067755480465508`*^9, 3.80677556068617*^9}, {
   3.806775637114263*^9, 3.8067756731359177`*^9}, {3.806775707814321*^9, 
   3.806775714041013*^9}, {3.806775758921629*^9, 3.806775798265832*^9}, {
   3.806775962792431*^9, 3.806776268440734*^9}, {3.806776360775009*^9, 
   3.806776518580283*^9}, {3.806776564609708*^9, 3.806776598533888*^9}, {
   3.806776712389683*^9, 3.806776729940302*^9}, {3.806776864855699*^9, 
   3.806776881485509*^9}, 3.80677719741708*^9, 3.806777327247016*^9, {
   3.806782844207996*^9, 3.806782877078267*^9}, {3.806783011617264*^9, 
   3.806783032533722*^9}, 3.80678328089611*^9, {3.806800881341443*^9, 
   3.806800882980688*^9}, {3.806801081972394*^9, 3.806801084098329*^9}, {
   3.806801117397251*^9, 3.806801181320753*^9}, {3.8069483872757998`*^9, 
   3.806948390031426*^9}, {3.806950789509927*^9, 3.8069508024755077`*^9}, 
   3.806950974135028*^9},
 TextAlignment->
  AlignmentMarker,ExpressionUUID->"784f5b84-fc50-4734-ace4-0817b4553106"],

Cell[TextData[{
 "So far, we have obtained ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "e1843b51-1680-435d-92e1-ae6f02483ad4"],
 " in terms of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "[", "t", "]"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "0ee5f3d2-2984-4b33-b0af-89c9770e5254"],
 ".  Because our throttle constraints are most naturally expressed instead in \
terms of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["x", ".."], "[", "t", "]"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "e728d7fa-88b0-4c57-9d9d-a827525ed939"],
 ", it would be helpful to re-express ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "6f79c43d-9092-4860-af8e-dd23fdb417e1"],
 " in terms of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["x", ".."], "[", "t", "]"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "a4899ab1-36ac-4f06-af82-6cf2b7ee228d"],
 ".  We can accomplish this by integrating by parts two times."
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.806776883229376*^9, 3.806777076623145*^9}, 
   3.806777197417121*^9, {3.806777245146474*^9, 3.806777252953183*^9}, 
   3.806783030436467*^9, {3.806801010829812*^9, 3.806801016397375*^9}, {
   3.80681170242846*^9, 3.8068117033193207`*^9}, {3.806950820929205*^9, 
   3.8069509528785543`*^9}, {3.806950989183889*^9, 3.806950994312271*^9}, {
   3.8069518547513227`*^9, 
   3.8069518564991703`*^9}},ExpressionUUID->"fabbf25e-4c5c-4ea5-b9cd-\
581932963357"]
}, Open  ]],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     RowBox[{"b", " \[AlignmentMarker]", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "T", "]"}], " ", 
        RowBox[{
         SubscriptBox["Q", "d"], "[", "1", "]"}]}], " ", "-", " ", 
       RowBox[{"T", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", "0"], "1"], 
         RowBox[{
          RowBox[{
           SubscriptBox["Q", "d"], "[", "u", "]"}], " ", 
          RowBox[{
           OverscriptBox["x", "."], "[", 
           RowBox[{"u", " ", "T"}], "]"}], " ", 
          RowBox[{"\[DifferentialD]", "u"}]}]}]}]}]}], "\n", 
     " \[AlignmentMarker]", 
     RowBox[{"=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "T", "]"}], " ", 
        RowBox[{
         SubscriptBox["Q", "d"], "[", "1", "]"}]}], " ", "-", " ", 
       RowBox[{"T", " ", 
        RowBox[{
         OverscriptBox["x", "."], "[", "T", "]"}], " ", 
        RowBox[{
         SubscriptBox["R", "d"], "[", "1", "]"}]}], " ", "+", " ", 
       RowBox[{
        SuperscriptBox["T", "2"], 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", "0"], "1"], 
         RowBox[{
          RowBox[{
           SubscriptBox["R", "d"], "[", "u", "]"}], " ", 
          RowBox[{
           OverscriptBox["x", ".."], "[", 
           RowBox[{"u", " ", "T"}], "]"}], " ", 
          RowBox[{"\[DifferentialD]", "u"}]}]}]}]}]}], "\[IndentingNewLine]", 
     "\[AlignmentMarker]", 
     RowBox[{"=", " ", 
      RowBox[{
       RowBox[{
        SubscriptBox["x", "final"], 
        RowBox[{
         SubscriptBox["Q", "d"], "[", "1", "]"}]}], " ", "-", " ", 
       RowBox[{"T", " ", 
        SubscriptBox["v", "final"], 
        RowBox[{
         SubscriptBox["R", "d"], "[", "1", "]"}]}], " ", "+", " ", 
       RowBox[{
        SuperscriptBox["T", "2"], " ", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", "0"], "1"], 
         RowBox[{
          RowBox[{
           SubscriptBox["R", "d"], "[", "u", "]"}], " ", 
          RowBox[{
           OverscriptBox["x", ".."], "[", 
           RowBox[{"u", " ", "T"}], "]"}], " ", 
          RowBox[{"\[DifferentialD]", "u"}]}]}]}]}]}], "\[IndentingNewLine]", 
     
     RowBox[{"|", "b", "|", "\[AlignmentMarker]", 
      RowBox[{"\[LessEqual]", " ", 
       RowBox[{"|", 
        SubscriptBox["x", "final"], "|", 
        RowBox[{"\[Times]", 
         RowBox[{"|", 
          RowBox[{
           SubscriptBox["Q", "d"], "[", "1", "]"}], "|", 
          RowBox[{"+", " ", "T"}], " ", "|", 
          SubscriptBox["v", "final"], "|", 
          RowBox[{"\[Times]", 
           RowBox[{"|", 
            RowBox[{
             SubscriptBox["R", "d"], "[", "1", "]"}], "|", " ", 
            RowBox[{"+", " ", 
             SuperscriptBox["T", "2"]}], "|", 
            SubscriptBox[
             OverscriptBox["x", ".."], "max"], "|", 
            RowBox[{"\[Times]", 
             SuperscriptBox[
              SubscriptBox["\[Integral]", "0"], "1"]}], "|", 
            RowBox[{
             SubscriptBox["R", "d"], "[", "u", "]"}], "|", " ", 
            RowBox[{"\[DifferentialD]", "u"}]}]}]}]}]}]}]}], 
     "\[IndentingNewLine]", "\[AlignmentMarker]", 
     RowBox[{
      RowBox[{"=", " ", 
       RowBox[{
        SubscriptBox["A", "d"], "|", 
        SubscriptBox["x", "final"], "|", 
        RowBox[{
         RowBox[{"+", " ", 
          SubscriptBox["B", "d"]}], " ", "T"}], "|", 
        SubscriptBox["v", "final"], "|", 
        RowBox[{
         RowBox[{"+", 
          SubscriptBox["C", "d"]}], " ", 
         SuperscriptBox["T", "2"]}], "|", 
        SubscriptBox[
         OverscriptBox["x", ".."], "max"], "|"}]}], 
      StyleBox[",", "Text"], 
      StyleBox[" ", "Text"], 
      StyleBox["where", "Text"]}], "\[IndentingNewLine]", 
     "\[AlignmentMarker]", 
     RowBox[{
      SubscriptBox["A", "d"], "\[AlignmentMarker]", "=", 
      RowBox[{
       RowBox[{"|", 
        RowBox[{
         SubscriptBox["Q", "d"], "[", "1", "]"}], "|", "\[IndentingNewLine]", 
        
        SubscriptBox["B", "d"]}], "\[AlignmentMarker]", "=", 
       RowBox[{
        RowBox[{"|", 
         RowBox[{
          SubscriptBox["R", "d"], "[", "1", "]"}], "|", "\[IndentingNewLine]", 
         SubscriptBox["C", "d"]}], "\[AlignmentMarker]", "=", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["\[Integral]", "0"], "1"], 
         RowBox[{"|", 
          RowBox[{
           SubscriptBox["R", "d"], "[", "u", "]"}], "|", " ", 
          RowBox[{"\[DifferentialD]", "u"}]}]}]}]}]}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"U", " \[AlignmentMarker]", "=", " ", 
        RowBox[{"x", "[", 
         RowBox[{"u", " ", "T"}], "]"}]}], ";", " ", 
       RowBox[{
        RowBox[{"\[DifferentialD]", "V"}], " ", "=", " ", 
        RowBox[{
         RowBox[{
          SubscriptBox["P", "d"], "[", "u", "]"}], " ", 
         RowBox[{"\[DifferentialD]", "u"}]}]}], ";", " ", 
       RowBox[{
        RowBox[{"\[DifferentialD]", "U"}], " ", "=", " ", 
        RowBox[{
         RowBox[{
          OverscriptBox["x", "."], "[", 
          RowBox[{"u", " ", "T"}], "]"}], " ", "T", " ", 
         RowBox[{"\[DifferentialD]", "u"}]}]}], ";", " ", 
       RowBox[{"V", " ", "=", " ", 
        RowBox[{
         SubscriptBox["Q", "d"], "[", "u", "]"}]}]}], ")"}], 
     "\[IndentingNewLine]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"U", " \[AlignmentMarker]", "=", " ", 
        RowBox[{
         OverscriptBox["x", "."], "[", 
         RowBox[{"u", " ", "T"}], "]"}]}], ";", " ", 
       RowBox[{
        RowBox[{"\[DifferentialD]", "V"}], " ", "=", " ", 
        RowBox[{
         RowBox[{
          SubscriptBox["Q", "d"], "[", "u", "]"}], " ", 
         RowBox[{"\[DifferentialD]", "u"}]}]}], ";", " ", 
       RowBox[{
        RowBox[{"\[DifferentialD]", "U"}], " ", "=", " ", 
        RowBox[{
         RowBox[{
          OverscriptBox["x", ".."], "[", 
          RowBox[{"u", " ", "T"}], "]"}], " ", "T", " ", 
         RowBox[{"\[DifferentialD]", "u"}]}]}], ";", " ", 
       RowBox[{"V", " ", "=", " ", 
        RowBox[{
         SubscriptBox["R", "d"], "[", "u", "]"}]}]}], ")"}]}]}
  }]], "DisplayFormula",
 CellChangeTimes->{{3.806948327245358*^9, 3.806948503952956*^9}, {
  3.806948535216895*^9, 3.806948587399169*^9}, {3.8069509766813*^9, 
  3.8069509826151953`*^9}, {3.806951060656039*^9, 3.806951067802266*^9}, {
  3.8069511804876738`*^9, 3.806951182160969*^9}},
 TextAlignment->
  AlignmentMarker,ExpressionUUID->"3e93b7dd-d0da-4d3a-be12-94f655c0e50a"],

Cell[TextData[{
 "where the absolute value applies element-wise to the vector ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "f779e2f2-64b0-444a-9a87-62104f54a314"],
 " and to the vectors-of-polynomials ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["Q", "d"], ",", " ", 
    SubscriptBox["R", "d"]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "4b1d49f0-1a35-46b5-96d1-9433d5037e6e"],
 ".\n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "d"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "9ce55f85-dfdf-4979-8842-eca1541576db"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["B", "d"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "b026950c-e345-4faa-90ad-4229feb9969f"],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "d"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "5a07e7d9-8226-4981-b2f6-d5bc16557eaa"],
 " are vectors of algebraic real numbers that depend only on the polynomial \
degree.  Using the known closed form for the inverse of the Hilbert matrix, \
we can obtain expressions for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["P", "d"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "91c878ba-3bf6-470a-8dab-2f49b8f87b8c"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["Q", "d"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "e4bae744-a99b-42c2-a607-0e71a20052bf"],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "d"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "7e7e8af7-8343-4094-8b13-a73b86ddebbb"],
 " in the general case."
}], "Text",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 CellChangeTimes->{{3.8069071534126873`*^9, 3.806907168935711*^9}, {
   3.806907201289113*^9, 3.8069072511883993`*^9}, {3.806907302544186*^9, 
   3.80690741857262*^9}, 3.806907459469201*^9, {3.806907492877379*^9, 
   3.806907533143203*^9}, {3.806948596861141*^9, 3.806948641348268*^9}, {
   3.806950185362978*^9, 3.806950201465335*^9}, {3.80695124576235*^9, 
   3.80695125150965*^9}, 
   3.8069513035940533`*^9},ExpressionUUID->"6a723a30-6706-4c9c-b565-\
4ca4a65cf90d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
    "d", ",", "Pd", ",", "Rd", ",", "Qd", ",", "Ad", ",", "Bd", ",", "Cd"}], 
    "]"}], ";"}], "\n", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"InverseHilbertMatrix", "[", "n_", "]"}], ":=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{"i", "+", "j"}]], 
        RowBox[{"(", 
         RowBox[{"i", "+", "j", "-", "1"}], ")"}], 
        RowBox[{"Binomial", "[", 
         RowBox[{
          RowBox[{"n", "+", "i", "-", "1"}], ",", 
          RowBox[{"n", "-", "j"}]}], "]"}], 
        RowBox[{"Binomial", "[", 
         RowBox[{
          RowBox[{"n", "+", "j", "-", "1"}], ",", 
          RowBox[{"n", "-", "i"}]}], "]"}], 
        SuperscriptBox[
         RowBox[{"Binomial", "[", 
          RowBox[{
           RowBox[{"i", "+", "j", "-", "2"}], ",", 
           RowBox[{"i", "-", "1"}]}], "]"}], "2"]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "n"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Pd", "[", "d_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"InverseHilbertMatrix", "[", 
        RowBox[{"d", "+", "1"}], "]"}], ".", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"u", "^", "i"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", "d"}], "}"}]}], "]"}]}], "//", 
      "ExpandAll"}]}], ";"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Pd", "[", 
    RowBox[{"d_", ",", "i_"}], "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"i", "+", "j"}]], 
      RowBox[{"(", 
       RowBox[{"i", "+", "j", "+", "1"}], ")"}], 
      RowBox[{"Binomial", "[", 
       RowBox[{
        RowBox[{"d", "+", "i", "+", "1"}], ",", 
        RowBox[{"d", "-", "j"}]}], "]"}], 
      RowBox[{"Binomial", "[", 
       RowBox[{
        RowBox[{"d", "+", "j", "+", "1"}], ",", 
        RowBox[{"d", "-", "i"}]}], "]"}], 
      SuperscriptBox[
       RowBox[{"Binomial", "[", 
        RowBox[{
         RowBox[{"i", "+", "j"}], ",", "i"}], "]"}], "2"], 
      SuperscriptBox["u", "j"]}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "d"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Qd", "[", 
    RowBox[{"d_", ",", "i_"}], "]"}], ":=", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"Pd", "[", 
      RowBox[{"d", ",", "i"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", "u"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Rd", "[", 
    RowBox[{"d_", ",", "i_"}], "]"}], ":=", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"Qd", "[", 
      RowBox[{"d", ",", "i"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", "u"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ad", "[", "d_", "]"}], ":=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Abs", "[", 
       RowBox[{"Qd", "[", 
        RowBox[{"d", ",", "i"}], "]"}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{"u", "\[Rule]", "1"}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "d"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Bd", "[", "d_", "]"}], ":=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Abs", "[", 
       RowBox[{"Rd", "[", 
        RowBox[{"d", ",", "i"}], "]"}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{"u", "\[Rule]", "1"}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "d"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Cd", "[", "d_", "]"}], ":=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"Rd", "[", 
         RowBox[{"d", ",", "i"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"u", ",", "0", ",", "1"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "d"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8066479029989967`*^9, 3.806648108206756*^9}, {
   3.8066481420000362`*^9, 3.80664822590557*^9}, {3.806648309330421*^9, 
   3.806648375629612*^9}, {3.806648428805423*^9, 3.806648434151616*^9}, {
   3.806648477337376*^9, 3.806648481877582*^9}, {3.806648562288628*^9, 
   3.806648563651862*^9}, {3.806648809878293*^9, 3.806648848122044*^9}, {
   3.806648942084214*^9, 3.806649103855835*^9}, {3.806649498252428*^9, 
   3.806649628909584*^9}, {3.806649683819895*^9, 3.806649725344377*^9}, {
   3.806693019578224*^9, 3.806693028175012*^9}, {3.806693991738159*^9, 
   3.806693993934313*^9}, {3.8066940275450077`*^9, 3.806694093298616*^9}, {
   3.806694151721579*^9, 3.806694196076663*^9}, 3.806694274764338*^9, {
   3.8066943321911793`*^9, 3.8066943744388742`*^9}, {3.806694412260293*^9, 
   3.806694531820204*^9}, {3.8066946388827763`*^9, 3.8066946401771584`*^9}, {
   3.8066946846661053`*^9, 3.8066947347120953`*^9}, {3.806694809728283*^9, 
   3.8066948581854*^9}, {3.806694896512267*^9, 3.8066948993116407`*^9}, {
   3.8066949449669647`*^9, 3.806694945054472*^9}, {3.806694985369404*^9, 
   3.8066949854556923`*^9}, {3.806695252454211*^9, 3.806695269349889*^9}, {
   3.8066954176245813`*^9, 3.8066954415734673`*^9}, {3.806695680144278*^9, 
   3.8066956869472427`*^9}, {3.806695742452483*^9, 3.80669574367199*^9}, {
   3.806695795938311*^9, 3.8066958033237257`*^9}, {3.806725666342021*^9, 
   3.806725743922841*^9}, {3.806725795161538*^9, 3.806725801464446*^9}, {
   3.806725870769167*^9, 3.8067259040494747`*^9}, {3.806725954408141*^9, 
   3.806725963517309*^9}, {3.806727381395928*^9, 3.806727403335841*^9}, {
   3.806727434486361*^9, 3.80672743965471*^9}, {3.8067275167907333`*^9, 
   3.806727528125738*^9}, {3.806728781960835*^9, 3.8067288280164633`*^9}, {
   3.806729032194393*^9, 3.806729036447392*^9}, {3.806907603663623*^9, 
   3.806907676877162*^9}, {3.806948675626533*^9, 3.806948675899914*^9}, {
   3.806948985004592*^9, 3.8069489887726727`*^9}, {3.8069491427145*^9, 
   3.8069493683282213`*^9}, {3.8069494248485727`*^9, 3.8069494901528387`*^9}, 
   3.806949531295973*^9, {3.806949649298243*^9, 3.806949649547741*^9}, 
   3.806949828721261*^9, {3.806949877190716*^9, 3.806949896624786*^9}, {
   3.8069499606141768`*^9, 3.8069499642667503`*^9}, {3.806950362891446*^9, 
   3.8069503676137943`*^9}, {3.8069513401884813`*^9, 3.806951341810566*^9}, {
   3.8069519383372726`*^9, 3.806952006694889*^9}, {3.806952360612609*^9, 
   3.806952454124153*^9}, {3.806952512970955*^9, 3.8069525427145023`*^9}, {
   3.806953035654086*^9, 3.806953116400648*^9}},
 CellLabel->
  "In[528]:=",ExpressionUUID->"b1d06e0d-d80f-4258-bcdb-c036da5769a2"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"QdGeneralCase", "=", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"0", "\[LessEqual]", "u"}], "&&", 
     RowBox[{"u", "\[LessEqual]", "1"}]}], ",", 
    RowBox[{"Unevaluated", "[", 
     RowBox[{"Refine", "[", 
      RowBox[{"Unevaluated", "[", 
       RowBox[{"Qd", "[", 
        RowBox[{"d", ",", "i"}], "]"}], "]"}], "]"}], "]"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"RdGeneralCase", "=", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"0", "\[LessEqual]", "u"}], "&&", 
     RowBox[{"u", "\[LessEqual]", "1"}]}], ",", 
    RowBox[{"Unevaluated", "[", 
     RowBox[{"Refine", "[", 
      RowBox[{"Unevaluated", "[", 
       RowBox[{"Rd", "[", 
        RowBox[{"d", ",", "i"}], "]"}], "]"}], "]"}], "]"}]}], 
   "]"}]}]}], "Input",
 Editable->False,
 Evaluatable->False,
 CellChangeTimes->{{3.8069525673487453`*^9, 3.806952640226491*^9}, {
  3.806952698751092*^9, 3.806952723302861*^9}, {3.806952939820487*^9, 
  3.806952954202044*^9}, {3.806953167616949*^9, 3.806953214348895*^9}, {
  3.806953248853088*^9, 3.806953275423891*^9}, {3.806953354000247*^9, 
  3.806953400297431*^9}, {3.8069534510574093`*^9, 
  3.806953451372363*^9}},ExpressionUUID->"fbbba7aa-c108-4f80-923a-\
dd288db360b2"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"-", "1"}], ")"}], 
   RowBox[{"1", "+", "i"}]], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", "i"}], ")"}], " ", "u", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "i"}], ")"}], " ", "u", " ", 
     RowBox[{"Binomial", "[", 
      RowBox[{
       RowBox[{"2", "+", "d"}], ",", 
       RowBox[{"d", "-", "i"}]}], "]"}], " ", 
     RowBox[{"Binomial", "[", 
      RowBox[{
       RowBox[{"1", "+", "d", "+", "i"}], ",", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}]}], "]"}], " ", 
     RowBox[{"HypergeometricPFQ", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1", "-", "d"}], ",", 
         RowBox[{"3", "+", "d"}], ",", 
         RowBox[{"2", "+", "i"}], ",", 
         RowBox[{"2", "+", "i"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", 
         RowBox[{"3", "+", "i"}], ",", 
         RowBox[{"3", "+", "i"}]}], "}"}], ",", "u"}], "]"}]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"Binomial", "[", 
      RowBox[{
       RowBox[{"1", "+", "d"}], ",", 
       RowBox[{"d", "-", "i"}]}], "]"}], " ", 
     RowBox[{"Binomial", "[", 
      RowBox[{
       RowBox[{"1", "+", "d", "+", "i"}], ",", "d"}], "]"}], " ", 
     RowBox[{"HypergeometricPFQ", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "d"}], ",", 
         RowBox[{"2", "+", "d"}], ",", 
         RowBox[{"1", "+", "i"}], ",", 
         RowBox[{"1", "+", "i"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"2", "+", "i"}], ",", 
         RowBox[{"2", "+", "i"}]}], "}"}], ",", "u"}], "]"}]}]}], 
   ")"}]}]], "Output",
 Editable->False,
 CellChangeTimes->{
  3.8069529201807337`*^9, 3.806952967170293*^9, {3.806953172053673*^9, 
   3.806953195745859*^9}, {3.806953244301619*^9, 3.806953282141493*^9}, 
   3.8069534393945713`*^9},
 CellLabel->
  "Out[509]=",ExpressionUUID->"1d00340f-3212-4540-bd1c-bf5ccec27bbc"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "6"], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"-", "1"}], ")"}], 
   RowBox[{"1", "+", "i"}]], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", "i"}], ")"}], " ", 
  SuperscriptBox["u", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "i"}], ")"}], " ", "u", " ", 
     RowBox[{"Binomial", "[", 
      RowBox[{
       RowBox[{"2", "+", "d"}], ",", 
       RowBox[{"d", "-", "i"}]}], "]"}], " ", 
     RowBox[{"Binomial", "[", 
      RowBox[{
       RowBox[{"1", "+", "d", "+", "i"}], ",", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "d"}]}], "]"}], " ", 
     RowBox[{"HypergeometricPFQ", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1", "-", "d"}], ",", 
         RowBox[{"3", "+", "d"}], ",", 
         RowBox[{"2", "+", "i"}], ",", 
         RowBox[{"2", "+", "i"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", 
         RowBox[{"3", "+", "i"}], ",", 
         RowBox[{"3", "+", "i"}]}], "}"}], ",", "u"}], "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"Binomial", "[", 
      RowBox[{
       RowBox[{"1", "+", "d"}], ",", 
       RowBox[{"d", "-", "i"}]}], "]"}], " ", 
     RowBox[{"Binomial", "[", 
      RowBox[{
       RowBox[{"1", "+", "d", "+", "i"}], ",", "d"}], "]"}], " ", 
     RowBox[{"HypergeometricPFQ", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "d"}], ",", 
         RowBox[{"2", "+", "d"}], ",", 
         RowBox[{"1", "+", "i"}], ",", 
         RowBox[{"1", "+", "i"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", 
         RowBox[{"2", "+", "i"}], ",", 
         RowBox[{"2", "+", "i"}]}], "}"}], ",", "u"}], "]"}]}]}], 
   ")"}]}]], "Output",
 Editable->False,
 CellChangeTimes->{
  3.8069529201807337`*^9, 3.806952967170293*^9, {3.806953172053673*^9, 
   3.806953195745859*^9}, {3.806953244301619*^9, 3.806953282141493*^9}, 
   3.80695348718694*^9},
 CellLabel->
  "Out[510]=",ExpressionUUID->"273b3180-1088-4d04-bcc6-69ac8cc57813"]
}, Closed]],

Cell[TextData[{
 "These expressions can then be specialized to any particular polynomial and \
coefficient orders ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "d4f3aec8-9fce-44f2-979c-2ac936e8ee09"],
 ", ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "07ad83d4-4ab9-465e-8163-e519fc054b76"],
 " and integrated (numerically, in the case of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "d"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "a5f8a5ca-0ff6-4488-94fa-a741414fcf09"],
 "):"
}], "Text",
 CellChangeTimes->{{3.806907433618257*^9, 3.8069074353770733`*^9}, {
  3.806907589142668*^9, 3.806907594285232*^9}, {3.806948685276547*^9, 
  3.8069487501124287`*^9}, {3.806948926839561*^9, 
  3.806948934753148*^9}},ExpressionUUID->"e14459a8-58b8-4473-a829-\
2c74b239ead0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dmax", "=", "6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Ad", "[", "d", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"d", ",", "0", ",", "dmax"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Bd", "[", "d", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"d", ",", "0", ",", "dmax"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Cd", "[", "d", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"d", ",", "0", ",", "dmax"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Rd", "[", 
         RowBox[{"d", ",", "i"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "d"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "Full"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"d", ",", "0", ",", "dmax"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8066479029989967`*^9, 3.806648108206756*^9}, {
   3.8066481420000362`*^9, 3.80664822590557*^9}, {3.806648309330421*^9, 
   3.806648375629612*^9}, {3.806648428805423*^9, 3.806648434151616*^9}, {
   3.806648477337376*^9, 3.806648481877582*^9}, {3.806648562288628*^9, 
   3.806648563651862*^9}, {3.806648809878293*^9, 3.806648848122044*^9}, {
   3.806648942084214*^9, 3.806649103855835*^9}, {3.806649498252428*^9, 
   3.806649628909584*^9}, {3.806649683819895*^9, 3.806649725344377*^9}, {
   3.806693019578224*^9, 3.806693028175012*^9}, {3.806693991738159*^9, 
   3.806693993934313*^9}, {3.8066940275450077`*^9, 3.806694093298616*^9}, {
   3.806694151721579*^9, 3.806694196076663*^9}, 3.806694274764338*^9, {
   3.8066943321911793`*^9, 3.8066943744388742`*^9}, {3.806694412260293*^9, 
   3.806694531820204*^9}, {3.8066946388827763`*^9, 3.8066946401771584`*^9}, {
   3.8066946846661053`*^9, 3.8066947347120953`*^9}, {3.806694809728283*^9, 
   3.8066948581854*^9}, {3.806694896512267*^9, 3.8066948993116407`*^9}, {
   3.8066949449669647`*^9, 3.806694945054472*^9}, {3.806694985369404*^9, 
   3.8066949854556923`*^9}, {3.806695252454211*^9, 3.806695269349889*^9}, {
   3.8066954176245813`*^9, 3.8066954415734673`*^9}, {3.806695680144278*^9, 
   3.8066956869472427`*^9}, {3.806695742452483*^9, 3.80669574367199*^9}, {
   3.806695795938311*^9, 3.8066958033237257`*^9}, {3.806725666342021*^9, 
   3.806725743922841*^9}, {3.806725795161538*^9, 3.806725801464446*^9}, {
   3.806725870769167*^9, 3.8067259040494747`*^9}, {3.806725954408141*^9, 
   3.806725963517309*^9}, {3.806727381395928*^9, 3.806727403335841*^9}, {
   3.806727434486361*^9, 3.80672743965471*^9}, {3.8067275167907333`*^9, 
   3.806727528125738*^9}, {3.806728781960835*^9, 3.806728816141706*^9}, {
   3.806728893200594*^9, 3.806728934097699*^9}, {3.806728976768694*^9, 
   3.806728985108777*^9}, {3.806729018688258*^9, 3.806729021335631*^9}, {
   3.806729188670745*^9, 3.8067292303026114`*^9}, {3.8067293772138777`*^9, 
   3.8067294209748173`*^9}, {3.806907686961217*^9, 3.806907691441427*^9}, {
   3.806948763060563*^9, 3.806948854677678*^9}, {3.806949551961293*^9, 
   3.806949620919414*^9}, {3.806949692481762*^9, 3.8069497221952457`*^9}, {
   3.8069500589082613`*^9, 3.8069500943362427`*^9}, {3.806951488394721*^9, 
   3.806951589896166*^9}, {3.8069516590434227`*^9, 3.8069516884909763`*^9}, {
   3.8069520146268187`*^9, 3.806952173163577*^9}, {3.806953136633923*^9, 
   3.8069531523900757`*^9}},
 CellLabel->
  "In[535]:=",ExpressionUUID->"779f02d4-92f8-4572-88a3-c53328b51dc6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "1", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}],
     "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8069524562089*^9, 3.806952545863447*^9, {3.806953130438311*^9, 
   3.8069531530933523`*^9}, 3.806953812454089*^9},
 CellLabel->
  "Out[536]=",ExpressionUUID->"82b365e3-3c9d-4c49-9330-8c43ec19abb8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    FractionBox["1", "2"], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}],
     "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8069524562089*^9, 3.806952545863447*^9, {3.806953130438311*^9, 
   3.8069531530933523`*^9}, 3.8069538124599533`*^9},
 CellLabel->
  "Out[537]=",ExpressionUUID->"d5e2901f-3a0d-4b4d-8790-8d6ebe30c7a0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0.1666666666666669`", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.41666666666666724`", ",", "0.5000000000000006`"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"0.5000000000000004`", ",", "1.0000000000000004`", ",", "0.5`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.5000000000000003`", ",", "0.9999999999999992`", ",", 
     "1.1602606057000058`", ",", "0.7291666666666652`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.5000000000000004`", ",", "0.9999999999999799`", ",", 
     "2.0871159901257395`", ",", "3.1817828549496308`", ",", 
     "1.5619960364156813`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.49999999999999584`", ",", "0.9999999999999828`", ",", 
     "3.320844440343759`", ",", "8.87814372247621`", ",", 
     "9.947863001958599`", ",", "3.943576388888495`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.4999999999999785`", ",", "0.9999999999994422`", ",", 
     "4.8940898231879615`", ",", "19.88887840673983`", ",", 
     "37.49905537911168`", ",", "32.950196714344095`", ",", 
     "10.924986091383712`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8069524562089*^9, 3.806952545863447*^9, {3.806953130438311*^9, 
   3.8069531530933523`*^9}, 3.80695381301406*^9},
 CellLabel->
  "Out[538]=",ExpressionUUID->"5447a28e-7643-4ce2-ba6d-377ed562821e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwV1fk/lAsDhnFbJRURaQYpW5EmydbiuW0lWwuGLE1kSVSoUDrRCCWkOqKY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         "]]},
       Annotation[#, "Charting`Private`Tag$1913496#1"]& ]}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    Method->{
     "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
      "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotRange->{{0, 1}, {2.0824656393169509`*^-16, 0.49999997959183695`}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.05], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwt0nk01YkbBnBLCyWKGssQJhTZKlsz3EeDykWKWyhdbrZIlkIhlUJZI7dr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         "]]},
       Annotation[#, "Charting`Private`Tag$1913540#1"]& ], 
      TagBox[
       {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwV0gdYz10bB/AkStISnpCkIRp6kqThzoiWvG3hSVNJKhUpWjSsEpK0aWn8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         "]]},
       Annotation[#, "Charting`Private`Tag$1913540#2"]& ]}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    Method->{
     "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
      "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotRange->{{0, 1}, {-0.9999999999999989, 0.9999999795918363}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.05], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwtznk41IkDBnBkW6kldJEjMVOkQSulNC+rcm3KlSzJlVyFalMkTWtQzkqu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         "]]},
       Annotation[#, "Charting`Private`Tag$1913586#1"]& ], 
      TagBox[
       {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwV1nk4Vc8fB3CS0GINEdkiJEmkJB99KWuyZikhiogkLaJQCEkqSVIRStn3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         "]]},
       Annotation[#, "Charting`Private`Tag$1913586#2"]& ], 
      TagBox[
       {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwd13k4lF8bB3BbkvrZS4ksIZWkEiV8hRKVyFJKEipUthaJklBEUiFJQpQl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         "]]},
       Annotation[#, "Charting`Private`Tag$1913586#3"]& ]}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    Method->{
     "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
      "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotRange->{{0, 1}, {-1.5119999830390312`, 0.9999999795918368}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.05], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwtz3k01AsbB3BLaa5tkttCZNeGRLTQfJUWoShbLk1jyZaKqEhh3BFKRc0r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         "]]},
       Annotation[#, "Charting`Private`Tag$1913634#1"]& ], 
      TagBox[
       {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwdl3k41d3XxhEllMJTEYkkEUVKIdsTlSJDKBoQUiRTMjSIMjUYk2RKqBCZ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         "]]},
       Annotation[#, "Charting`Private`Tag$1913634#2"]& ], 
      TagBox[
       {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwd1nk8lM8fAPC1u0USUsmRUPKlXOlQyOcplFzlKiEhpSRKJF2OkCJXSO5S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         "]]},
       Annotation[#, "Charting`Private`Tag$1913634#3"]& ], 
      TagBox[
       {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwd13c81d8bAHArSSINISIrJCSklEdWViVUioSEfMuKrGSESKKSzLIqiZCZ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         "]]},
       Annotation[#, "Charting`Private`Tag$1913634#4"]& ]}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    Method->{
     "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
      "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotRange->{{0, 1}, {-1.717780023529913, 2.5141952085526436`}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.05], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwt1Hk01WsXB3BDyW2SdMuRIfOQRDIUnW9SFOXeQpKcnJQpmSKpTF10MoV0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         "]]},
       Annotation[#, "Charting`Private`Tag$1913684#1"]& ], 
      TagBox[
       {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwV13c81V0cB/BrVMhemY9RpCIaUipHsiUUEiWbkoxKCqFlJFRSSUmJqJCE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         "]]},
       Annotation[#, "Charting`Private`Tag$1913684#2"]& ], 
      TagBox[
       {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwl13c81d//AHAh695wLw1KRkglCaXF623LyM4I2VHIiFRWskLWR1YqoyQl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         "]]},
       Annotation[#, "Charting`Private`Tag$1913684#3"]& ], 
      TagBox[
       {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwd13c8ld8fAPBrc0lcV9yLjJBKUskoOU8ZiRRFMlJmkiTJqMzsyugrK0lW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         "]]},
       Annotation[#, "Charting`Private`Tag$1913684#4"]& ], 
      TagBox[
       {RGBColor[0.528488, 0.470624, 0.701351], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwd2Hc8Vf8bAPBzzesqIZSVFV8RCSGV52REoigrIkmSJCOFZGSXVUlIWaWi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         "]]},
       Annotation[#, "Charting`Private`Tag$1913684#5"]& ]}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    Method->{
     "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
      "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotRange->{{0, 1}, {-5.249070091850671, 6.643260012066975}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.05], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwlknk01Vsbx43R5CAqUzJWMuUaGn2VmchwkikpUqiM3dCArjlKcpGIjCGO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         "]]},
       Annotation[#, "Charting`Private`Tag$1913736#1"]& ], 
      TagBox[
       {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwV1gk0FE4YAHDkL5XcKUKKJEkqRcQgRUjkKiSEbiRFh/tIIpIkJLkTchPy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         "]]},
       Annotation[#, "Charting`Private`Tag$1913736#2"]& ], 
      TagBox[
       {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwd13k81E0YAPANlRB2Hdm1kkglSZJCzISUMzkqQs5IQghJhZDclVAhIiQk
R26/n1uO3LdUbrlDub2zrz/y+X6eZ2aeeWZmVwJm9tqWdAQCYRr9Q/utajne
gk/oyfOrRIbejLWWY1CkOPwgSwJRIYVnKylC4MTbqOhsshLg95ARsH+tBIap
Ql6uwprgzFICSzrfFaDW2JUVQ9YFQVKn9/97YAGEgvjeb/Hrg6OpvvKFM/Zg
XdU80lTYGBwTphubm3YBv33aK00jTIH1Di1/yr5H4IrFv5LnZAuwm40oFHfO
B1QqUvIqom+AGU+7J5YRT4G4oFzmIv9N0LlqeoLDKxRE05l8OJBwC/zSeL1X
nO4FYBz0fndZ2A5o5NT4eIdGgMKfrY0Vug5Abb3n/Xer18BBy0LVMOIOqMoy
oHsbEAu+H3uiGEx2BpVhdN03OhNA+Fse/MC1u8B8JDnOQy8JqLKlnimNdgGX
tMqrHy+ngC8zDSdn+e+BAN8jywc/ZABbY+OsJ6buIKkk7xpHXybY/21WbF/C
feB/uJtv2jELhKSTDl0SfgjMMpIAR2cuOMeXmDhh9QgEGx7FifF54GH1a/Yy
XU+QmJA1/M2jAEhKiQbrR3iBREkt8qRlCYjjuugXQPYB+jf/bspvlIP7jZGV
lwt9QBoPnhwvWAku+/6kE7zmC8KPW6XVX6oCLEt3HhVF+4EDLu4qR6pqgFt7
uNsU/1OgRcxK4tjRCHSCvn/Jx5+CbbGsrh+tvwExJeElH9MA8LuYI9G1tQkM
Z+fd4UsIBGd2qvhkGbWASy96bTSFQ8BJKli86NAORNUEP1BqQsBEw7ltTnId
gJHedmzUKhRUZLmITuzuBNcLNj9jumFgqqOMOS2/C3AdDhO7GvEMDOXZnH8t
2Qe8GLMPPiWHA3GLQzJ6138BkfPP/LMcwkGsbkv32YlfoNXXfqKvJhysnE8e
anUeBEL0oh/FXF4CKd3tYY1hQ6B6I1GsvTUCsPqIDb/sGwEsCxEn+YNegR4d
MiNL/m8Q9d1dMXczFjg6vx3RzP0DzlL1Ewf03oIrR+jcKtkWwG+DU9sZ09+C
TPl5K8xmAeydumeefjQOdB1rDj6zfxHY35Q6QOiPA/l+LC3ckUuAZPEp5f3p
d+DpTrtXtyKWwVX9+E9z84kgQC31zNHvm2C2T5fpHeU92E3c6W8ltwX8jBkt
dRTfg99Mdte+x2yBbHN7ypfw9+DFubmqwmMEyGon53v/VBKIeXmWLfIPAVZ5
9xjseJAMZjteuhR50EGJNOIOKmMquPo4LqA8Zjtk3vIyPL/3ExDUCLthOMMM
o25eMRZV/gRmOsMSX/CzQKF2UROi3SeAdbJz4VosUP5Dl3lfySegpIc/+5vF
Ags+ROTmiWWCU79iFBpcdsNpnalitW+ZgGPOS+PTGivUS4msd9qdBcp0D2yG
rbHDaCNv9RsCWeD3/b/LzBxEOEi63Xj1ZBYAH7dddhchQvsHCk1yRlmg0tra
WlyfCJ9qT7fuTM8Cxb4pRuu5RFiyrtD7Rj0bOFH/HRq3JcEDl2bGKwJzQH74
CdnqbxyQ8ui8jFV8DiipzgndP8oB2dPjApnycsBmOavUzQ0OuMqoI3ZpMAc8
loUpOUc4YTOe5zRwOhcY8dMHyj/hhO7iXpvLI7kggbFm/Y80F/zGxskpBvPA
+ZKU+NdB3LBC7rZli14ecCSTI4fjuGH+reovzrfyQGYZ3zGOXG6YUOOmXxSR
B/gIiWl837mh26PvsRem80Cy5fbioSN74P7ZpMPmr/NBoTyw4qzcA12/SYOo
xQJAqK1o5xvggaxiuSNfGQuBrsCb9ZhpHpgYLB60Ri0ER7RION0GD2xRP9hj
fK4QuBVeqrjHS4ZH6jmdDkQUAqEqHlveK2T4o2Y2KetUEbBQo0/j/UqGLgdv
aQyrFYHfb5iX+jrJkOXJ6AKXSREIFpqPeTRMhtLK3+E9/yIgqGD11WGLDF9U
1vWCniKQUBj1cfkEBZ4ve8/a6F4M0j+aPA+LpMCBfQK5myHFoJH37pFHCRTo
7Bl9TTyhGISZ2B/W+kSB8eBFyov6YhDY38n3qpoC10o8FQyoJSBaa+1e1QIF
fiq85jJWUgLe2EppPbjAC5UpXVRyawkYKAm+GqTNC/vvaVeojpYAM+H+nQ8M
eeEuaRX2DNZSwDD48wS9Ay80z5NKdb5eCkylwwriX/LCPTnEgW3bMLAz7OAi
fx8vNAxa0x3mxoD1iLv9nyFe+M5ipL5aFAOFDHtT46Z4oShXQUHgVQzI6fSd
CdvghQouJi+5MjHQ1L7FUMRHhf6aqizLVRhI0nv53uYAFTYKSz7u7cNAPPNK
/ZIoFaZNPs5vosfBNZfa57GyVCgVfSUp/BgORk4YOktfoUJ9/4ZfvjI4kEyH
6ZVGVOjhfJbP9RwOYk8bKB2xoMIy9SPh+tdwEPog+GGAAxWqb2x67X2CA/Gy
8PqwJ1RoN+FUwvYcB767+6P/BlHhs47xZUIMDvg/MHw59ZwKO9Nb7YeycED3
rrFALZoKTY2TjFIGcGDW5/K7MIMKfVR5X72awMFYvmj/ahYVJkmFtQcs4oDK
z8XOnUeFU6zuareZyoBGozMcKKVC1rUZP2OuMnB2xk8+sJwKj4+Zl1/cVwYY
MwjeHNVU6IJpSEtIlYHZDO4fuQ1U+OpjubPg2TIgOqu03tREhcWRpzI51cvA
xvFNy6pWKtzmIHDwn2kZUL0xcEihmwqFDCPMxm3LAFunz5OvvVSofIE5tse1
DPR9zJET/U6FQfuWOIuDy4D/NrXSx7+oMIPFRis9Cq03xRnmNkSFLcsDgbEJ
ZeDZA7HaCyNUuDisUxOaUQY0FQdsFkepkLulls6roAz4NL/3uD9OhdIlcvKO
lWXA3e4s3cAEFRp+yLpn3lQGnrcmE6iTVPjw5cFc3d4y0Nm668HJKSqM94qe
OzdSBhx4Wz1Epqmw8jZR9NRcGRgdSty+hjyq72d1aK0MOCde50ueocJdymvv
yDvKQXc9T53YLBWKSjgMMBHLwZYzP+k5subeEfI6bzkg862tNSPfYTLQmxYu
B4n6t0ImkcP/fgsbOF4OQkOsmn8hfxlUbGg6Uw7WEvd+zUbuvOA1H3y+HGgK
HdMxR/6bUcqtrl0Olq8w/5lF63NzrcsyGZUD9gVyuj7yqfvSprVW5SDt2GJg
HKr36i8XPz/HcnAwyDKiEu3P7XzOR6UH5eDi01vtVWj/UenzzXT+5WDF6qRm
4m8qzOc49hd/Xg7AmCCLCepX9z1b3kcx5SCB7iv3yhgVLv/4AOVSyoFH5piL
Peo3j/KY5VpWObCLczpZMUyFp9OEAgtKysHgSti1xUG0Psks07W2HAjyhv+h
Q+fp5va242Qbrf5tDLMDVFigRNmXNY7WKySXXEf3oTf1yjmHhXLwnLnIbbiL
ClfZX9qIbZYDjYtZncodVCjznS03laMCeDg+T0hE981AUaPXem8FCCSOHYxD
99H9Q8CW8OEKsOed9b17X6mw8O521QT5CjD6sDyzCt3n3j4Fe1OVCvCdzzn9
NIbmP+sZzq9bAVraGd4/LaJCWda1gTc3K8C9NPOcqmx0n5PmnMLDK8BCr+DH
5HdU2M8i9kr7bQWYsotrZ46lwnXHW6XsqRUgPCTLUPMVFcqBUcZgrALY/Ugp
sQulwtKuvhjf3xXA/H0E2OtOhQNy5ArFpQqABar1uDhT4WbC5fFthEog4b8O
MuyoUN6hReIhVyVgCo7MKDCjQoyxpsYFVgIVeqvPSipU+NOOYVpSrRJcvPlc
+6UCFRI6zpIW9CqBQaCedBX6/IHxxYb2tyrBOZ0B7oqjVIhLZ81bRVSCoXT6
jtPsVFhuE8OrP1UJPIyK5ilNvDB74tYt47+VgHvqt85mNS9MtJYpMidUgYvO
wweqS3mh740uAzvOKiDQ/0+HPoMXXjAjvn58pgo48OXdOxnIC5v0fXkygqpA
eYuSih/khXi3jnV2RBVgE87D86R4YeaV/fn5cVXA+mx67DdRXvhcD7tSkVMF
Hv4405TGwwsvX1qJ6O6vAu7bG5tEZymw/8JtLvqj1eCQfCKdKvp+aayRtWQ8
VQ00+39k9wRSYKkyU+7us9WgwuZZ70VPCnyrlKzLo1cN5EUONs1aU6AZ/PXi
6INqYKrwRIUgTYHjp/RIVxurgT7PnVtO7WS4JCzHln67BpR5zdYcWOGB8oMK
NQFuNcA+wXTp9gQP9Iu58Mj6cQ3YhAtDr3t4IDen7qzgqxpA+nfwVkIBD5Ta
dqvpdWUN2C3Rt3THjQe69UWF+vPWgt4p8THe+T1wPXSRzeJrLXhOJa0YN3FD
upWP7LwH6kBqWqlr6TlOyNuosACO1YEEW8eXj45zQsn4ng4L6Tqg5hfAdoyP
E1qq7HyToVEHSCaJ7vqLHLD2ldkBBZc6sFMkqHcgngOGypBlbtbUARWxcvWy
FRKkeviZ592sB1X2akPPY4hQasvki05GAxCkyzrffXc3bPCR/FYt0gSUeWY6
K05sg/xhkysfZpqBT328lnh9D5j892OgQ7wVyMdVNW5pL2CJv4vqWEPawF2D
A4wWSTtwu8iLgjYv2kCqa+eda5078FNKQ/erotpAoOif+FM7duJ1MUxHPRLa
AH5oITvGcic+r6UfOpHfBsTTJOWogoy4fN5fncqhNnD/8gUdPGoX3vP4+Pd7
0u1gefLOv8jbLDgrX/Ls8HA7SLm7S6Wllx2Hlx9/H5poB0zJ/gHu0+y4Y+j1
+sGZdrAQ/omHk0DEO7fxJP9cbgdHpAsn9hwg4rGj/sb9LB2AOPtul6kdERfL
tGlsk+wAH9UZGmY2iLiGotjHcp8OwHHcbyOZnQN/6MH0quxpB5Aa0jqsJMCB
Z+aO+uEhHeD9XweppuMcOOeht2alUR3AqftR/WdtDryfhZ1SmNYBKP67K5Nf
cOC2nfP+n9s7gMC+7fKaJE486GbujTihTpDTJ3RIkY4L/w3T/ZlFOoHBZnXB
DyIXfp7nfarLsU7Qyz1dc0OAC6erCZ9Rl+kE6wk5xyQhF35PyNll5WInMJsr
YK734MJv/JDw077fCRrMCiR/znPhZ/Uy3zO0doLYH7PzN+q58VjRlBr7rk7g
Tb/HHHZz4+v0cRO9/Z1gcRI7Qj/CjednhR79PNYJFDjmE5U2uXExdvtco41O
YPLsnOWXY3twav3Rqi+HuoDhc9CvGbIH/ws/Dls/6gL7XyopCcvw4MWJk29c
fbpA87idnLMiD+7NKKrj97QL9KrUfU1X58FZm9PKEl50gf6C60FDxjy48PWM
2IFkZKkuTX1vHvzyg89XdZu7gPBixSebKh6c+muezbwDjXe8csihkQcfVJKo
udPbBcYf7N4w6eDB7ViyT4YOdwHbt06fGEZ4cL83OaS65S7gwz44qUNPxnML
8hqAQDeQ8e6MYjtDxt35lh9rCneD7qnfb78qkHHodVrW6Eg38LjK991OhYw3
XCj44H4S5Rt//ON+mYwPdxX65ap0gzm9qmuv7Ml4quyaXKVmN2j/mTacdpeM
O7yVXWrV6QZ75XZEfrxPxtdvFJvPGXWD2pv/HG2ekHHOvyXwiGM3OJ3cNzYd
Q8Z79Tf/SbsiOw6/MUgg43El8p8ueHSDnOohh6wUMi7qi/Hd8EM2qXIXzCbj
Spxlq3GvUX1fs9aZasi4s0RlDndFN8Ctgy1mf5PxG5L74p7VdoNMtz5+y1ky
flXKI5DlWzfwUbmnW75AxmVlJM3oerpBWDD/kRPrZJxOIZFtZqYbWLdaxsww
U/BFRcKa9WI3kIwaPB7HRsFHzhmODq10g/yCWSVpDgpeq8JZ0sPQA7T275gU
oFDw0Es+NlWUHhBXwGnQKEzBPXV+6sF9PUDU23p70WEK7qh35mzRgR4wRzko
EyZKwS/rL+75LN4DhiOWleePU/AL17ToRaV6gG5Nw/4HkhRc2ihtJkm2Bxhq
hYTOSVFwqqlFVbRyD4B/NIVCZCk4qzmeuUe9B3gMY1r5chScYEmNfn6pB+Q3
bNtTByj4kHW7o78hqq+/0T1RkYK324gb05v1AB6He3y3z1HwatsglYdWPWC5
/rQF33kKnuqgtM/ZsQek0AtPSKpS8GjHOOZZ1x4gOSd4NFqNggc7r/+9+aAH
2H7s2DepTsEfulwdHPZG+w3RrxHQpOAObjmN1/17QHHskCC8SMHN3NkLeoN7
QObDEmllLQqu62GbqPcCjXdUZpG8RMGVH9aGNkehejQXYndpU/BTnkL31WJ7
wIXbmkvVyIe8PW9UJ/SAqMx/JFsdCk7x6b909kMP2OeYuLaMzOJ3Wq44A613
jz/7ti4F33wSfuhUTg8QWr8gV4c893SOI6sA7f8pdyyrHgX/Fai+JYqhfjK+
6JFBbg1O+Z1cieb7PLCgiVwZytC5v64H5BCOzasif3lmUhbT1AOi0751iCGn
vChO4+noAYnv+JJW0fyvX/JEvehF9S2H3chADox0fsz6sweYjGXxqiJ7vGq2
ezqC+lmyv64R1Wv3RtSAYbIHsPwId5FGNonxP/doDtX3ufVAMNqv9tth8dUl
NF9kYX8t6o9SPKTeXUPx3yBuCvXvZEL0zjlCL9Cdsrm7jPor/H75j82OXvT/
4aumU6j/PMm6AyPMvaDZSvZmrQYFZ/qQ+dWE2At4kvSfB6HzWk9lye3j7gXs
7GyDp9F5/sioDGwR6AVUyMWseoGCN08zTEkc7AWMv3jffVGm4LjoOfVw0V7w
k8XoEgu6L3GpVSxXTvWC/mU7VqezFDxsYvvt/DMo3/L6QR9037wOKTeSFXrB
+puvdg/RfTRLqg7uV+8F+d28cWLSaH8jO2bktHvBIeuil8PoPisKndd8e6UX
4GWKLY/RfRd6V8NqZtYL3Ow0JB4eo+CjMbWhY66o/kQuVXMhCt7Zzzh34UEv
MHG+QLUQoOA1vCpaqd694CpX7Q3Nveh8Xn1lvx2M8gvOPvqxh4LbvKx79ucd
ij+Q9FjcRcEN2pn+6KSg/mSZfju7g4Krcahp56b3gn2Fg01udBRc9Fk9yS2/
F7TPYxsJq2R8OqjhxUZjL+C8sNk6O0HGB+pZFo3bekG3muntwBEy/o1JQxfv
7gUNnzP+sP8i4xn+jZyPh9D+jop87+lCn38+314yrvQC6OvCZlFJxhfvN0dy
CPUBXIifZPoKfX4Wsi87H+4DhKSuA29fkPGOFa2rnWJ9YNly+4eaYDL+xbWF
55V0H2DcVBbo9iLjbk6tr/Ze7AMX3rR0/LMm42s27W8Ou/eB03p3bGROkHFd
KaNnYo/6wHiYn2isKBlP2zbqd8KnD1jv7Pw4e4CMG0f9uyMX0gfctMzpDHnI
eFkV5cKld33A0yNzwWCdB3+yz3TRra4PxN0PPrGC8+AcndPqtZR+sO+vK8vi
GR7cNt5FoZEfOej7Or8kD15pu3WqVagfLE+XVMgc4cFd6ImC/WL9wN/q+NoZ
Mg/eIy65MqvQD8QlJPnvLu7B3wa6v99zqx/ECVq0FSfvwY+c3bl5o6gfeB4j
/5nbtgfPTP14sBtH49vXLPn/cuOSnFqXVKqRE9mOyf7mxs+MRSUeaekH+S5B
yzKt3LhmsIja3Gg/0HJW/GMYz4079mhE3SN9B/nLbKtSZ7jxgjvhEkE3v4Nu
E/+/HyzQ3wvvBKw+7xkAJuqL4pOPOXDJKFbhauoACFt4mbfkzIHvC1kb7hUY
APt23DJYsOTAV+91mDGIDoC43VKitec58PRLT42vwAGQuVnq18PEgXNsm9fb
sB4AP5+MWiSHkPAf13EllULke59LdYKJuCvf9f2/DH+AuDrjZLV2Vlx0So+5
S+Mn8FTLiddK3Y5zsM0xVq7+BISaXSZOjH8xBuzNJ8HoX4DgdjuRYF6K3ZIs
6tmlNggIOsrPQhkWwEcVs7jSv4PAc3dRUnkZHZQUFZAHK8gHDpt/+kUHS1l/
9mFryMlGA37b6GFzm9GeMsIQIGyArCVIDxeN9EMqmIaAZ+kf2eZSeijvqOVR
uxd5udnJ4gsDbH4tf7VVGdmuTtomfAfUf7CxpK2C/I9F3vvzDjh4vfhFmxpy
jaSY97cdcFFIpqldC9ngn4c0405I/nRSucsArZdO9HnsvhOaVYhK9tuhuK7r
qqMBI1yapLCPRqD4N7Ph4zuZYHjMWE30K+TFIMJFQSZ44mLOI51olN/3qVMd
MME7WRqzeDyKp7Re+u3CBKfdPL+9SUOeW5j7MMwER7aPBl0qR/nJtxMPFjLD
Dv7Pu0qmUfzckwUv9d3QueVBmdMc8t6RyACL3ZDjseo9kQXkw0Yydzx2w0uj
Q+ORy2g8e7pI98fdsDGNu9aRfhgQsuIimXaxwippD79DZOQ3dYzzxawwV+c8
fbjSMPA8Ua4guJ0d+qvl+1LPo7ghy4wmKzs0VDzM+F4Fxb+wtdrsYYd0J5h3
f9FErjtxxOkwO9QkNXF3X0V2Dbhbpc4Ox5svi1BvIy/oS94KY4dFtTVpifbI
o38jI6PYYQh++thRR+SrWp3ZcexQMpMiKe+K1qt821iUyQ69QgfkTLyQx1+Q
djWzQ4rmjUuJL1H+BbnH4cxEOH2uq000CsWLhw4Wk4gQl7twOfc1ivupXGkj
E+GNoyLXqt8in1NWaj5IhNksMxbjH5AvNvfRKxKhev1dN9FSNL555rKmCxHy
V4yu5uDILZPJth5E+KfwygO5CmQtOgV3byJ8lSrtrVmLvMqmaB5ChKNPNwId
WpFv/eG2fU+Ejy74vs0ZpdWrf+hyMxG2Glsbik+g9cy3uDQ7iFDorho5bRLF
/30oP9lLhHXxxBcJc8g+C5rtQ0TIuRbj93wVWShuVuMvqp/opci6gWx8+VnF
KhEWHLQgBGyh+TQVfxzaIkJjXRF3L4YRQFA0dS3fSYIp6V9uO7AiW/CaHuch
wdWKVyJT7CPo/bwQFaKSoEavx5gVB4qHToXv2EeCf3Yoml7nQdZMOPn6IAme
MWnS1dyPbFsfuH6SBJtJ47KiUmj8Jz/jtIskuP9w/XLyaRTPuqwZpU2Cd0FG
rqAsinOMVDvpkSDF1vkYL0RxZsGLKwYkaFFFEGRSRU72/yBvSYJf+oZ++Koj
t2o0JFmR4K4/1dHbLiKPsTpt3iTBjL3B3Cs6aD43CTUPOxJcdiUzjRuhOP93
/iwXElQNWa82N0G+sH4two0EYxJ/PP5hhvLpRik27iSo0PJ+o9MK2SNM4OcD
Egwf8y/UtkHOy7zp/YgExzZuuX6zReMzDU5yepFgkIjEfNUd5PSUqzt8SHAA
cmWcdUY+yv/5hi8JHr+ybFPigsZfrQz54keCnY9Lh3PuIwsM9Ak9JcHDr+Pj
xR+ifJModcUAEvTI9DFO80TxLJZzlwJJUOC7aneCL/JLjWbZYBIMKJf9pOeP
LNtsJRKC+p8s6rczEI03Zn27PZQEDYL5jAqCUfyctmsjcrkjK3o3KK68Ou8V
RoIiV7eY+F6g+Fc3dsFnJPhCbu7Xt5corqHbnom8vv9XvmcUsvRBcOQ56j9j
a6jEG5R/Ik77OXLDdPmN4RjkeS/2UeSTbdlyEXG0ehLchV+QYGx+IueFBDS+
e+a5DvKO2JeTK++RR8yv3Ua2e+xX/jEF2Zyr0wm5y9r1ldFHZD+R7VbIUNPa
gS0DzVc28FsZOeWE/vmyTBR39HrKgcxOVt3rlE2r12WoAa1/b1NmSegLymc8
ueaIPDh0pKEzH8Wfq7RtR1b9Sk3wL0LxMR07X7S/rIzd7jKlyMaMTfOoH5Tw
Ta0pHOWrH1tWRfa+N3swtgLF5d9PhaH+TRr/3LxYjfzX4FMF6reuUkvHtq/I
ZnqKQ+g8ig+Xp2XXo/Gv0j/OBpGgEFv2Y8tvyI1hk+Po/IIWEwz2tKB8F7ij
CZ3vYk/48a9tKK5D2opH52+E+TLe70TxIw49pv4kKBZg9WWgD8VF+2EKuj8R
9leDwwaQV/Z3iKH7taWrYqHwC+XzW+m/80bvi/8IKWkUxf9JndVC9/P0durE
lQkUn4pOC0D3N+43C75rCrkuZ0/WfRK8kztz+/Y88vbgjRpXEux9/UOJfxH5
ylfPL3fR/fds5m35i+az/MT53IkESWpZXyXXkRs0PdntSTDn590D6ztGgec+
gXER9B6p1TfW03eNAgKrxR1vMxL0/Xil7ToLMj/T8ZrrJHjZRdqrgoh8oN+K
B73nf8wb/QFUZOWnyr0aJGgyP519hh/ZWYUrWpUEazsHAmYEkA0kzqmdJ8Go
ePy09kFkSZMfdyAJypzyCSdLICeWx/88jt6TGVkqRhKZfvKMlhgJOoVkdO07
hbyQU/9JhATTRroph84gr1Z3ywuS4N7wo/FSysi6t5RiOEiQbr4zXccAOX/g
mMk8EcZSbS92GdLWexvSMkWEshe2zRtcRy5WkzkxToTOb49ImlkgW38LqxlA
n98anoUOdsivno1L1hNhferhmmBvZG2dkYPxRGjdWWpN9EWm284a/4YIGeh0
mV4+QT7PPsUUQYTy+g81ooOQA4yGMwOIMHNnW1tqBPJD+RBlJyIMt/D4WZOK
zOgu+/YsERrubVrZ1obcMJN6po0dspIdc4s6kPXeVMjWs8MyDq47d7uRgxpZ
RSrYofCua+Pj35GryTbtWexwdmG0s2kceZrdxfQZO/T+upkds4nsvylhpcYO
U5zF7KRFxgCBRyJq9gYbNLBvObwgipwScW5Cmw3utnEeSTuGnDPsVinPBh2v
FxruO4nsEvCDn5sNyqoqq+2EyGdsC25XsMJv/MaHOvSQhQwfPeRhhUt1wYMO
XsgPazYV0llgP3OH9fpjZMm5b1KRLLBcnTr7xA95YEaFw4sFhn1LXYsNRC6V
+eCnywJFWms4G18iJwbM6a8yQ+OebecPpyIrNHDVnWWG1WN3P/5qReZkx57h
u2AUg7GzttA4IET4b6P47IAcA7nv6CqRo/4V3Sdsge0PvHSl70wAgmeq12D4
NCB8MP40SPoNCIS5iZ8mFlj1VJfdWy6ar76R3nqGBYlfEjPkobmMOzA3DtuT
r5jewUezcJUIcyYmVnPoY+2h/+MZwnoYZjjyJylDHhnil9Qqv2EFAk9i3W2Q
fx4Tb2YfwB5aEoxP3Ub25CWF/x3AlD7c41u0R47z+5Pd9wNrFreNvn0XWStj
gtD6ExsHl16beNJ8IfpyxCDGbcwboRxBm2/zz0PWUczx9adgUjny3Lx8Zd4U
lrf++kl5JS1fZmQf3zS2buzn5ViDLE6J4fGexp4IGt1tbUBu/pzWqTqDRacx
GT3vQmY30b7fNYtVlVqKkqZp898/a2s3j/EM8dYTeSbRfoK6qlQWMaNzO6vK
KMiZjD+f3l3E3iX/Kb3DhzzH/ZoYv4iJ2n7NatlPi7Ou2fxbxM4uubx+dhTZ
ROeWXPwSZrOz9SZREZk9dlZg4i9WcsSfkWiHLE7aRn9hBZNq39P43IGWL1eq
dXMFy/RIfsbpRFt/ItAsYAV711hN4XFD9mQMaalfwfzttx/l90bWmsruUlvF
tLO9Lx2NoMV5avThGlZ/jcT9KYq2nqtTi9EapsTwrlf8DS2OiTDdX8NO6ZWZ
S8YhO+gylOasYdR/W3dlU2nrrz4UObCOjck8eK1SSlv/fdTcyjpmMsRyvR5H
/hlgbsGxgfUGRgtqVCCHjQdGiG5gDf1FaVq1tPniLp803sCyHq6WXmlFjssN
v1q6gXmUuw5ZjtLGh9FzOW5iSzY7U8bGafksI4ZPNjE7jkjbm5O0+KFuk+hN
zNTiy5LtHK2/wXbRVZuY8o6lnc6rtP7ubBvg3MKIqo6i3qxTqL6bMXeTtrC4
MjZmGSLNZsJ9+VuYuHT6xDwHzYOvZuq2MM1D40mmZGTPd0V7Z7awgB3GAmeF
kJdPSWnxEHDyw7WtZWGaC4dO7yPgKUtRA5mHkU3ITMsHCXjNcNubfceQcaen
K1IEnKFChZsgg5xf832nDgF/ITO2mHcG2Xqz950+Ad+f5dNmD5Br/05wmBBw
GI+F/VBCjjvM7mZLwJt4jOwjzyOHVRBvORJw47BVjYuqtPoGVk64EfAHj04y
YxeReeDl848JOMu/1gkXbeTx0rxn/gQ82s6hVkyPVo9E7+dgAl5o9NE31oA2
/03oFEnA/8oKEB5a0uqrKlpJIeC+2aUDJ61p9XGpz6cRcM4jhiXTNshXB8xL
Mwn4CUqku5EDrZ6znD15BLz8maQ+lxMtvj1BuIiAa+9qPdV4l9bPl+9VSgm4
wzLL0pn7yM1pf9kqCfiWfWrb4gPk0+7y2dUEPGTsfFaaJ62+2KkjXwk43/WR
MIvHyP4Fm/fqCXhap7c91Y/Wn2bHmEYCLqu5T7PdH5lR63xEEwGvqyoRDQpE
jmK+b9FCwA3krjErhSA7yO9mbCPgEznLE2thyOxBG57tBNxNNKI2+wVyCkG9
qYOAMyaeSL4VQVuPtPKnk4BH8rb4Cr6i1Re/faqLgAu/sLPoe0Pbz1/Hwm4C
nsvEovgiltbfGgXjHgKu5P1BQC2edh4nXbuQ21aUCfSJtPENJOFeAm52Z3ig
MAn5kB+PKvL8uFeJ4wfkn7WBisieJvzRImm0/lg7kJDZu4vdBzNo86fUfUHz
vb1ooP/6M20/Mm/FkcVq/p3SzkHOlFt4hOoplX/JzZRHOz/FhkRUr8YXiaWy
Atp5aIi/RfvpP9rcdq+Ylt9wwB7t9+0k8QE9RruvxtuPon6YfdARDi5D7uZe
qmpF+7V62cRdiax1dk0a9XNCqMstrprWH++9T1G/0wZ59ot8RRbvsMxG5+EQ
Z1CfXU87v+DufHRef3kH+Gqaafs9c12vBt23Hv4arTZa/RGPp9D5P4g0dejt
oJ3H/kXjcvQ+OEbKp3tp9TgNdBSj99MsbOv6HZlw51ZvAQEPCLHm2vaT1k+2
W4VfCDiRacqKc4S2v5ApFnQf22uOEmPHaPbzeYTua5SvfeHB38j7NIsa0X3e
u22BRXaWdn6PTm7EEfDBUskvlfO0+z/1bCCagL/3cLmuufj/+8DeRBFw0eWV
z6YrtPotyz+EEvDZXNlrk2vIcxdzVgMIeJbTA4a7m7R+sn066EfApWcJV/zp
0fckfnyNy4OAK4/uXM/YjZyvlXLuBgHflajy/jQ7skN4lBt63w2mgZrlJFp8
ksPfgIDrfGeN79iDvE9v8YwmATdp51JeF0A+lHybIEnAhZ5fmfUVos1vUUU+
SsDHLr6KYjtIy/dVZBcm4Hb11Mn9osgXTjG+3EPA75cLhqlI0fIt5Ql/tjB5
T0vpttPIkEuYaXALo5NPHjSURY7brGxq2cL8C0ROOkBkgtd0SOYWFpF5vDdC
lVbvnfuDNltYZiwQGjZG/pn+e3fbJrbgvrDT1BQ5k0rUxjYxqSvJk9/NkU3W
fl/5uIkVsbFld1nT5m9K+uC9iVV7Dpytd6TVUzl9S2wT6zN7cD3LD5kd+5Pg
voHtOFj02jODtp+Pfc1ja5gKvf3DjUzaejmfvzWsYUE/9pu5Z9PqP60R+XkN
I0YFHHbOp833WyLAHX0f7TLItyqnjd/vRWBawyQmlzs0O2n1HPb15F/FjD5J
Efk2aeMdfgUeXMa+GCyzNhNmkD9JNNMvY6w7Clke0yPvq10a/vEPww3lGCcY
kfF5Ce/If9h+JqWtHA5aXNknmuEfNmpxaVr9MHLcjmPfO5cwO4rtVw9d2nz3
/ymYLGCevvFe/ak0z5O7zaaw3a47VU3TkT2/t3pzTmGvrW+TRj/R4uYnJKon
sWw16YTZHJoZbN8fnsRGiS2VdBhtfcs+5vkJTC2WwHi4DZlQ0Kr9eAzjzrse
cneNlh/MfKx8EEtIqbq8ukGztkSd6yAm/voI/yPCLBoP7BKODmIqD/598t+O
THDYw/P6F+ahGNryhg3ZU8FFweUnNthUylkuSPOwfpN7P5Y+zveGVZ2Wf0t8
8Ug75h/jazKgSfPQlkFcG2ahPX0g4xItP82RibsNoxYXZ2pcoVmr0Wh7KxYQ
eq06yIyWP94iNNGE3VCqCDS0pFlRZnHsG6awInJJ1Jpmc4myiUZsxWy1r/42
zeU+gX/rMWupV/NM92iWPGMrVYspTRLyeu//P56cpVmD8cdZe6Q+pPkEt5VN
Nda56/ROVR+aLzZfTavEzn3vpD4NpTk8bflaGbbvufzg1ec00+nrPsOxdeWk
5EMvadaWE32JYTmZdyVqX9PMKUJ6Xozt9+G8sDPp//W7Cme+YJunPXZ3pfyf
v0vyTS7WMz3UmvSRZl03R60cLOxKtpHyZ5pXJ0s7PmO2LLyC3Dk0R2vvTsrE
LpR5j498oZnRWXErA9sS0XbyLabZNkw+NhXr/VFwWg+jedErPCAF+xIusClU
TnNmyYOAJMxuc86/soZmlmtc1e8w1eyrmuF1NDeoqNLFYwescQ6LRpp5zoCk
WKy/JTSWvo3mMOl7VlFYvt8/87aO/+cL5vV/iYXLXj+c0E2zf5pQ+3PMYa56
xrHv//Oa41cPw9Tei+UoDPw/fkriVyAmbBBxj/SLZhOxMz5PMDq2TfnBIZrn
Bly8H2MDFZYMWaM0/7TbKniEFbo1fvWaoBmOTBy+h0UcPRl6aer/+Pupy07Y
ncFoXYHZ/+Nu4X62mHokA2V+/n/7hg2aY4fUbX/gizR7vioJ0scYtrUnhv2j
mcB4rVcd+5kra2Oy+r/PZJZKY8U2CcfEN/63OGs3GYvkZ17a2vrf6Mez5D8I
/z9I
         "]]},
       Annotation[#, "Charting`Private`Tag$1913736#3"]& ], 
      TagBox[
       {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwd13c8FG4YAHChSMgel5XN3QknKvG+pTKTRFpmkqRIyM5OIcqoRCkSEjLL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         "]]},
       Annotation[#, "Charting`Private`Tag$1913736#4"]& ], 
      TagBox[
       {RGBColor[0.528488, 0.470624, 0.701351], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwl13c81d8bAHBJJakQMuOalxDXJVLOKZIVKpWySxq2ZFVWkqJIkuyQKNkr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         "]]},
       Annotation[#, "Charting`Private`Tag$1913736#5"]& ], 
      TagBox[
       {RGBColor[0.772079, 0.431554, 0.102387], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwd13k8lE8cB3A5crPryrnrSghJcpTMhBwhhRJFRCq5QqQIhVRCkSTJVe7c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         "]]},
       Annotation[#, "Charting`Private`Tag$1913736#6"]& ]}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    Method->{
     "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
      "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotRange->{{0, 1}, {-21.022094066466323`, 19.520481419848252`}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.05], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwlx3k41AkAh/ERaVpFtNW6krMciZxdvkWlVEruaBC5c61EJUdDkntnXQ0m
hs0VcrUhwnYoyj3COJI7U627jf3ts3+8z/t8JC95nr+8hkQiBRL9d4PL4611
E6Y6hQKvXQ4v8x7i0RPxGhBWx5mnqtupJxt01DKS6aXCR/GdL2d5y6GPOiNi
MiHX5Azx/JicIE/SnM6p5u7HacImMA48HN4sww2ZKPHsVQlLdCunzBR0bcQ/
BvZJdnIULLcZ6pp6bMEktaPRLtEOZrfTJhSExWHusFCTIOwADcMTk+9npdCo
J1LZQHeE0Su5sIaZnVCRPlQ8K+ECwSMftpkG7AZ9jW2ubJYbDmQa21W+VgV5
ODTTTM4DmnpnA36Ia+DpYFtzg4kXRqMMir890YbXOQcD60Rv/J7MH7Ex9SD6
99zRixb2Bd/OKwUnEnVBy/ilTtbqKkYFWMeuzhyFgUDewWd0P7i0fRtnOuuj
YuatBkciAFk8J9dx1Z+GO4Xy+I7ddVzWeKTwkHEWUi0c5R1ZNyCa0NQufc4I
MYVCu4zkbqGmXHF/WbAJjokzmRNOQXDIq7+mpmqGWy9SNz03CYbgK6WNBV/N
oa6pFG2ZGAL32fM7yJlWYGw5Gx4pTAVt0d7cj22HG81JjWZPqahVid3dO3sJ
ZmGDa6StwhCz3i22RsgBG+a8g6ro4QgyNmRVOzjCv4PmPy1xFyUHTw7P27jB
OKq/4kndXfiX0b8mF7tD+ajcHNUuEkaSf+vqkD0wUlrpLZ51D988+64pOnrB
6LcProZyMZAX7lUTNP4VSqekc0VexuCxg/U/GVt9QeZ2Hxt1ikXOVAn9ar8v
bP5cKak1icP3WKlilq8ftsjHKVskxoPX745K5esAhJBLd94VpqHuVGRPf2gw
FPTjIx570TDmuXUxfl0I2sI8J3pfEqacyPwaHQIZbqV8Zb/fsUL3qc3MCMWL
H0zljrZERGkzfc27qNjwd6KGRFQK6HR3jn/0XST3X9crX0lHpN+QVzp3Ao6I
WTLZphmwfnU/pd06AZMXtNaSCzOAiXdZjIoEbJ8OsC/czcDibfqF726/wdNF
U5bUxwA7+TYrtJ8GIYeih9nameBfypqifEiCheWDoi9fmUhlP5tf3JMOTq/J
T5ki2VDZnyS1Ep+OcAr5srFeNnR5E9SsZtNRau8pUkHLBil72PSXpxng9zgU
dkMrB+8ifEVrmQz8FdpzgTfwD9hlPY8IPJCJvQWCvGLkPNjsKU2nhWaDbzXE
Wn97EbTyWRaZVgWQNZoZb7hXBu+hFbPK7eW41rIPybN/IlU6pUbbtxrbygTZ
XFy10N40c7zd9jkqhvXevjtYD6EvVVJBro2od00TtZxuBLiCryisfYk5uUMC
hVdeIjd6KPSD/GusWcrfJCrbhFqGm62h3htortpWGD96C/Eb5V9cRJrxlqre
8kLhHe4jfpfcUAsk4qaWcmfeI6Ilv2qjx3tMLQywO1XaoKXWKSDm0grmZFUT
f0w7LrDsSnJi28Av/gdnZKQDN0Q3U7TftCPKpdyRIdMF3oJFz5X1nZg/nD/i
HNSN6w98WmdvdsF3b2PZ1gYWfASf6OZNdWPgUeO9VskP0HzObSsW2YPvrh33
5a/3wlnktNKCYi8Uj6xbcazqQ4rkLbWb5X3Qz5R0KtnGRrKKSX7aRTauidtI
DVkPgG3NuFk8NAClaVO+7jODYHg+4FHIHcRmgS/kxuVB5F2sWc53HgJP7f0i
afoQ3PkrFh2EhuGmXtWz/tQwxuOa+ZXqhpF/8hLj2fwwWFobqAu2HzE3JbJp
NPEjBtnxzLOcjyg31uemHR2Bf5d48OHbIwg6EZZRNjqCQVWy4L31nyDZb8DK
CvuETQlXLJbufcJ+LSpNeO8oGE2pakMio7De/m6Jq30UX+bORc5mjWKuKXrY
K2QMO1yOLfNgDMk8FN/zMuMgGaRNhHWPYTO7PHNN4zgY5ckWwlfHsTYwxGSf
9wRITnYr6+SJ51KKhoUmURfzpsGXNQGf1KJoofpJBP9Qc4mmT6JGMYIs6DGF
4Cs9W+dtpiBo4KMUyj8N0sL6oktbptG3+317QDVhw7+89ndOozgdMiOUzwje
xzajBX/GxSJNQfGVzyClq6uHS8wgOOxBSF/eDEhqYz6O9TMoHBe/z3+aA1Jv
a2CyKQcRaWG2bEPCiWfkFS04cDj/WfaREeFbt+WfXeBArLq6+Iw5YRW5fZ9s
OIiMtXoRdYmwE4tf25UDZ82Urz8FEK45Tp29xYEU9ecT63IIj807Tz7kYEX7
5sZu4iQd+Zq4fA56Pn9syyFOanjBrf2Igzjz0ovHSwjb/hx0t5SDVYXzv4ZV
E+bzeq/9jIO+1th07nbCx5pEW4g/CV+wb+8kzKReDO/igHbARj6LRVi/+ht6
ODiVrVymyya8t0y1kvhT/+bXIROE16pVVRBP3K0RazRN+NOo0XXi3sN0E0kO
YUu6N4jvOu0+UDdL2KDDqYU4D1cHM26BsAPldDLxwfIDrrbLhAWWOu2JV7tm
7VH5QfjmGz5V4kkSfHOrq4Ql//+/SN3Khw==
         "]]},
       Annotation[#, "Charting`Private`Tag$1913790#1"]& ], 
      TagBox[
       {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwd13c81d8bAHBJpcwi0TJSqRCFlhyVJFQSRdkpvqSQorJXRqEIiSgqI3uP
67m2yN5Z1ybicmVdbr/z+f3l9X49z3nOc55z7oWwySPNe8xMTExX1zMxET9V
7403kSe0FdrzIlDamesklgs7rfsFZFAaJUFZbpwdjkeHR2YKKKHWZkaLd4M4
DO8WdbM/cBWFNc6Fbj2oCGp1HRlRAlroVLvg9+3R6iD6as+Xf4K6KIQrSMn5
8k1YVb0bZnzAAN299EmbumoIvz1by41DjdHhi593FWTcg1umi6S3AqYodPS3
63X0AMov7Mwti7yPTNnKpzY22YDUvrNp84L/IRuZizVGU08gktkoYX+sJVon
qL/pk/VzYB10/3zzwEM0R+OsztRzgQJKc12ZljXiuGykWXbLHaw1TFX1Qm0Q
n6OLFouMF/QefXnhtYAdErPVq5p294eQaH7y/jtPkOfbdX1+8wGgypUoXxz5
FG1WdZuwUXsDOdM/ZWcEn6HEG7+hR/YdPDAwyHhp/Byd39KuEnY1DETqZySF
Yl+g4bLbEfHO7yEgeZvY9QPOqM+toal230e4uCcubsLMBf1uCLgtqR4DzpUR
3CVaruiRS7DEpzefQEZO/LVuqBsynSX3eZ+Ng5jt17z9BDxRVkv9vcHtifCi
Lqz8ZoEnGrb2/8z+NQluelGY993xQtHPbb3MFJOB/a+NS2GkNzo71VQXcTkN
HFpDHKYEfdEOeq7LfHsmXA/+ZXH1QACaEnHtpNUXgrjavoSdVQFIOyCO9H6g
CFjXPxgbNQtEjmIUtYdLJDDMZ6SDVhCS5UgYlxUgw/ZDQZI6oW/Q1YG5pV2W
peDGmnnQVyAEnTJZZk4wr4LDl974ZFiHoMieL9ds9lZDs9ejie6qEFRky9Yv
1V4NouvFkySfvkM1p/kDn6jVQOVanGRrcyg6VrE+Qk69DthpobKCr96juq7O
4tGGJgjvfX4hm/EROVhJKjYkd4KO7qdU6mwcunUnoo1ragjY/rnpXdqbikKb
WpL/qc9C+H+3DMSVU1G6vvfVT+azINoqbrT1YSrivnrk6THPWVBI6LjbTUpF
Z0n8x0UKZyE/ITQ7VzINyd//YH9UbA7+3JgqUqtPQ5/KYEM5Yw6048NqH3Nk
IJF+5gzOyHmI1HdXvy+cgfg+3mjfmz0Pg9us6nRkM1CFs7MfX/08PHI633BW
PwPJt+TXFf6bB1/NP82bkjPQ5EZ/7k7jv0BaPf/rg3omSnwmTD8ivAD7r0+P
l/lnofnWjAVm/0XY6XLptNmnLPTN4IO+0+dF4E6O8d+Sm4X+bYh+0pq/CCus
NySvD2ahtpA+Fv7xRWgk5z7uO5mN5PlkumfOL8FzKTfG0kg2Our09GXx7BI8
Mvh1LZKejXJanW9RNy6D6avjn9DWHGT/LlNnddcyXBsfueAtn4OOs8jf/3xx
GURjVH15gnNQQbDmjn1hy1DPxcsrqZiLKp5qyvYcW4Gys1b3mrRzkVOE1aPP
F1cgz7Iyx84yF307W8t8TmcFYqscdAtDc9Ha4kjrRqcVcHDp/ajyJxelSlDj
MspXQGTm66G7EXnogUNCg4M6HXbsYXqxMS0PbXA2f1mgRwd2Nd2fCRV5KEt0
w+2WB3RY/Mr2iErNQ4kKozx+r+jw08A6y+lSPtp/sV9rSw0d7OtPofD5fNTD
aR+pdnYVOCWzR36wFqB41uksbtVViHst9Yq+uwANipCC02+uQpP6wS6DiwWI
zmEa4P1oFY7U8j7eH1qAUqnv5xyjV6G/auZrxolCJM2r5xy+tApPD1peGVYr
RC5h7If5168B+8tR2najQvSsWOjhY441OKXcq/jMpxCpLSiQi4TXILi85hfq
KkRxAzlxESprcKnkC2fd8yLkkJKp7BW4Bn1CwtmMgCI09GOTIoStgZ1r5B2p
2CKUabKR3hq9Bp9QcHxwbREKGbepDU5dAzrJ9fzt3ST0o4PdybBuDd7uWR33
lyIhHbsQMYfWNRBzsg8kKZHQ9sbn1Q+610Bb/mGPkBUJJZsbsPweX4PUgjtP
x0gktDHTUVuWmQHKOzt2CzSTUMKNMT9JVgb0PNMsUx0lofhTvCvrORmw+dRl
7hTOYnTFvzD5ggAD7ubKJdoZFqPdb7Pe7JBkwApfhsbXx8XoeG9GAe0YA4Ke
Six2vCxGNx/52n0/wQCSrKjSmbRipJejXZupyIAdWVv71q0DRNq7YLbrOgP0
XtG1hvkAXdskayWuzYDPpiO1leKArC/v0eDVZYD49vx8fx1Ad8dOL5obMcD2
z2ephw8BndljTWm7y4DcilffNDwBSa27MitgxoDzT43ebU8DlH74c8dBKwb4
XFVlX6oANLaT1Dr7iAF1B2Q8fnUDssoqUwm2ZcC2f3tWimYBOZRoqbA/YcD3
SY+8hvVkFLLBaFzPngH1HUs0MicZWb3dr+D1jAGzZVZHMwTIKGKPrKHXCwbw
pg1axIqSUdpNK2N9JwbIRd76GnKUjDgV6Lc5XBig6/NzwOs0GWU66pq8c2WA
o925PfYXyaix8FrAXzcGfDTK0THXIKOxtdm/Eh4MKFE/EqJ7h4w2LEWnKXgy
YPhkTIPqfTKys2RpP+jFgI37t7PJ25CRuyuv8wT2oa1+yhKOZNQmzFXi4c0A
9TWG296XZOR3yzF3AfvhxGMS11syMo8Tf37+JQPetI0vMUWR0XGTkyJm2Fkl
+jJz38goSvBftSl2e3Lzo6EMMtJjHPA5g738/lJSK4mM/myNfDaJ6+32Lhqt
qCajHRCYa4etYCstkttCRt93Oeh14H6MDb7qx/eR0ftrXB482J6qu96/nyCj
j381lQ/h83yVC2r1mycjByePEn583h8iG7gd/5FR7+t93IN4HlOcz9WstpSg
UbPFK154Xpz0aW+D7SXIR5UljBnPU3rsbuk1oRLk0h646Tae91O4cuqYXAm6
km3fFIbv531Sqd2+cyXoY8kHU2d8f0VhJ9J41UvQutyfbxG+33XWwgcXjUtQ
9+5XcprWDBDVCzUZf1CCLFTqxmLxe1FWYfvYZV+Crse5JDVaMOCV0F/eotcl
iP7+8HChKQNS2C00ksPxfutTQp8bM6Bpqc//Y2wJatia285rwAC+pmpmt/wS
1Kk05NhzkwGnSGcVbMtLUHriTZEtN/B7T8h4drehBD3hmWnhucaAT26R1Isj
Jajiu29PoTIDyq22ip+glqATJwPtbp9nwKiut5kYvQTN3YaItrP483DMum/L
1lL05PHYdhMZBuQMXvjZIF+KivgcrDsE8f2puM2+vlSKckQqGfY7GbCQUsyn
rlmKTK973l/kZcCJF6eMq81K0euDNy4Gb2ZAHs/RBfLbUvT1SEXf+dk16Hz2
YJdLVCkqXxtu6/29Bkv9CYpn40vRl7ymNJ3hNTj5XdQ/n1SKaO+0Iqbb1yBf
aadQxngpSld+yvhYsAa/Em9dtKaVIhlN7Tb5zDVY4X5nIckoRYwLL+IKk9bg
dC9XdiJPGfLpiMvTi1yDgicbVGMVypAEyeWDlOMaFH2lPg4JKUNyecatCnJr
0MMu+V4zugxx/X3CWBVfg1Vby2LuxDIk/dPA9OO+NTiLRllfQxma8ht28Ode
g+KO7iiv3zhf0aV/28QqAGtV1VPFcvTZyqB5MWQVSi2idulOlaNNoTVdYl10
yJywtDRYKEdRX2xCberoEGd+uvAuUwXKT19y/VJCB6/7Hbcf8lagHxUDxg0J
dFAx2RrhIV+BCtP0RiSf0aFB14s/5VUFcmS2TzjFS4ceFavt6yUq0e6SmMZ7
8ivw98BZrmSrKvRlsNrQUm8JFAbPV/k5VKEbCX+vSKgtgXeUiou5RxVaIGmE
UU4tAR+v1sy+91UobchqbNeOJZBbZ9kQUV6F9my0Pfq7cREcusMDfXZVIys+
K8qW84uwGjjPZfqjGl3UEnJ+uWsBmJeTuHftr0FTat37YrNoIPfPKOdGyk+k
HvjcJld6Gn56ytRXHm5AfoMaQTMRI3Caq5b5jWwDaj33zqnefgTi3xufuKPY
gOQ2PVYo1xoBj5SAmBntBqShZM/xlxPnd47b8rs1oHrtc8E2nsMQfyRqh0VH
A0oJbKYx2w3B+Qn3tI3nG1FzgPqXvvsD8EyyvsbyUiPqcPk5s6Q8AGmPBUYa
1RsRsxGXoNTBAdjLSBX4cKsRUQdru/+OUWB5W6/7UatGlO4hHTBkQYE0+RPa
OuGN6NsMvbdrqg8EgyaXE6Yb0e7qwA+xqt1QbOySkEFrRBGH1j5Y8XWDwXEe
3cKlRiSltjPQdvAXRLafzvvJ3IRS3LykJV/8Av49fk9n+JqQ09UTr2xTu2Bb
ohhNBjWhJC1+PcN9nfiPvHtTENiETHLYhaVPt0Hcu+UP1SFN6JX3f1PA0QZK
Zq/Vmt43oeuymfTAgVZw35KdOBjbhMQL04LnfVuBocHy34a8JjRSvPF6a28L
LPV+HlGlNKFdXI6/tr5thsnF/r42qWakZe5Efi3RCDlmgaWqcs1o116T2oCN
jeDaofAVzjQjmeE/U2XQAHy5UVYJys3IaDXej3GgAf9+u7PqqNeMAmpUo46v
1UHEfLuAqE8zyiv+Pt5VXQv3TL3Xwl83o/ioGvVzXrUg1So7wBHcjIpC3CSu
n6+FysyQ+MWoZsR+b0LNsrgGZm01T9RmNiPP+DCuwOIfoDJbp2Xb34xcE1TC
S/qqgMfY6eTYcDPi7t7m8+NLFfQ1iu/W+92MVh+kcDpZVYFdmv/Qxb/NiCpX
7zLGqIToR5dtBdhaEL/dOFf9oUqw6F/SDuBuQUFjZ3vkFipA5lr8qfV8Lcg1
8Z2xelkF1EhuWvdHqAXxcjjzOBtWwMKf8kCyXAvavc1A/l90OZTo2z2WlW9B
og6fmJpsyuFV3b5biedaUIj+jK6GUjmIJLvvDVFvQXrrOfbrTJbBlQeKyWYm
LehV02fNgHNlEPe7sIYzoAWFG1hKx3KWwsOwa/ssgluQnZidzMpkCZxQGnpR
Ed6CsqZY7y7/KIGaqC0SjrEtSGOK6xb1ZQnMaugGTuTh/SfIs2S2EihYmxpT
Km5BJ8ckUnWnyeCZ6KoYU9aC5L3NvkU0kYGfJX72Zn0Lqn705uz2CDIo5C7c
KB9qQXlOj12njpGB1dTvu+BEC+ocyoqo3EmGZu69G15MtyCjPVElKuvJcM/i
Yo70cgtivfOR3+87gOSOLs7XjBZEEXxwzNkNYKnsgdn4+lakQlvbXHoL4NWe
EP5ozlbEtP6K+0lWgJs1B21WeFpRI/n6qMVgMQjaF/7QFmhFPnzfA6ZIxZDR
OPicXbQVkaVf7e11KAZHp6ctZodaUZCkf4GaTjEoH94iXibZiuKXW9ZvPlUM
XR7Svc9O4f0erKc9ZJDgs1SFbJtCK9LQylfYMUSCB706AVJKrcgoU9eD4wcJ
5PymRv0vtyIHf8XA62kkYDrhisau4v0UVySHwklQM8QTfl6rFZ2UvyhR6k6C
4KBv1Chd3G/pthvTViQ48Lv+k5ZpKxK6sU5KQoUE1FCTldT/WtE4M5c1OkGC
ggsLmmyPWpFY5/OJqIMk8KT6Jt23w/USLumpCJDgStQeltJnuD++DG8FdhLw
qabr7XFpRTqVx/a7MpGAsqCU7eDZiqhFznPsC0WQGNvJ0erbitI0fb8NTxWB
ncaD+0cDcT8LnvSNI0WgsPav2C8E+/tw7OO+ItiUGLxj9D0+j5m+1uGuImi8
edD6XHQrsv49Wny4rQgi1hdWR8Zhq5KC7ZqLwDTtqvBSQityfWPitqmpCCT1
B5/dSG1FMazRMkONRbC0+WlzShbOL/DQ2YTzS3I2H9lSgOO1FqGPW4vA726U
xz3A93t5+d3BziLQ4pbuIZfjeipCayK9RbCXVC6zuwav795jfW+oCMb/03lt
34Dv44jLm+nfRZDBNzXS3Ir7PSXMXEwrghdlLgqSv1oR95Fjxi1rRaBkzRPm
24/PP35MXXIzCTj3fJsZHsbz279kUL+dBIo3PXqHJnC8kv1qvggJbAMNawen
cX9/pA2LpUgQV30mf4CG389PhbO9iATt6/i/UZbw/h41b7ZrkID1zHxI/1or
otyW2GBmTILTdo3ufcxtKMjPTaHpMQk+jvoY9LC3obRIuffTH0jQKHhPvXtr
G9Lw+8j8KZ0EzLrnTv/iw/nVm0otqklwv3Z5e6dQG1K8bV1xfpkEkmkWdS0y
bci1zl18xawYjCaUC5tP4Xjgk0g972J4K7IvoUkBO59TpeVLMSyEdHs2qLQh
oTSZFPpYMRQ/U5ev1WtDTM6Li+LPAKgZYodrjHHcfX/g/hgAkSkW/h/3cf2s
y3TJagBvAxKt0hr302utlM9BhisXJJNKPdvQuN6vX7fMyODsuOV9iS9efyVo
91YXMqRlj3qTA/B6ugJVI4wMvGLRJsXhbYg/9snNuz/I+O8b7p0F39tQuOt/
Z38eLwFO5alN+en4/If+SWdeKwFFl+q/uTltiPxntHDvgxKIm3Vtyibj/HWd
3u5fS+BB+6xPeivOvzwf+US4FD5y1T9N62pDOh3xQ8/OlUKjSqJpal8bUumY
jmYyKQWZQhPF5HHcb/gew5C4UliNblmMX8VxJ8a+uqNl8Oq/7Psxou0oXH/A
5oJBOfxWTPZhO9yOWOcterN9y+ES/5fEp0fbkc5s1fmi7HJgrgqZVj/djuLP
1Zh7cFXAM1G7p8vX2pGYic7qzI8KuN9/zFvzRTvSGJChjOpWQXnO4XiSazti
2u1hbB5QBSIBIjVi3u3IqFdQ2b6sCnrlt3H+C2pHMaq1jmeOVoNWxOy7pK/t
yDpdXfs6xw84p532haUZ+1Cg9tWhGvgoHl/1qAOvN/uRZC1UC6vrYyZ+9bQj
RVRzRMCgFvIyAiXSx9oR9T65YuVXLUhyP8rWX8P9nAvfTPv1E3bXSlTkiHUg
ISMjOTVaPSwoJg2bu3SgIBHT2+wlTVAUN/nB3rMDVfdGVNCGm8CdVfyGt28H
agw7G8W5uRk4G7+XxAZ3IGoTNb33ejMcMEz52PcN15M9p9I90gw3ndJ1tBo7
kE7feQ2RHa2QnZ/7Ewl3ovjGS1oqUe1gd6w8i6+sEzU655fnH+6B+zJCMW+q
OxE1wrg2TL8HdOQc/dnrO5GQdf2tmKAeOHNaxoS5qxMpMsXkHl3sAebzcVzT
050oZuaYh0JlLwRe97So2NmFpJLy9Vss+yHRWknIzrYLqYwjJeX/BqA/pdy/
SfgXcrDf0Aprw0C3aP1w6Hk3sqYkrYVZTcGRc5sY9wt7EOXuEevetFm49FnY
LH1HH7L2/HBhm8RfkAnnPFC5uw9JbbjTIn7qLwgF0Id/CeP4Q47/0MW/sPKs
zYRFvA+RjRxs1fX/QvJ1X4Nbijhf9dg7ltd/gWfdrPaaOc7P1/s38Psv9BuS
lS4X9CEN55Et9OgF+KmdvN4A+pDr33XCjMQFyFOLKLUtxz7tlb2YvQBvT9gp
Rtbj9b184vW1C3CRS0x+ZrAPBZnFbNu0uABJxYHH37H1I1c+9S3Raotgv8dQ
ZECvH0ndMvDf/WcRTDSkbvYY9yNrtvtWCQuLcNVjnV/H/X5kpMk/eoRpCQ5M
xM7WWWOf6X66lWcJWrPGyQWe/Yg7+Cq/wcklkFK3NQz53o/IG5re/3VdgvHn
XpGXVvsRk3if2uDmZfh984j5JyYKMkrvQ1u3LYMRlYdZcD0FxaTNFsvsXAa1
fSOyO1kpiEnQSlH38DKI+L6M4t6G3RfmvkN1GRq1fj5Y209B5NwwssnLZRCf
0mbruEJBFA6/GZblZcjTUgc/DQpyLYioVmFagQuk848VbmDzxB5x3rQCtwOO
dn/RwftvDLYlbV8BX6nNSXZ38fpuobOvpVdg1K5IddszClL8XttoeX8FbHsz
GBUvcNz9NHvFgxVYu4j/QXXG+4cm3ed6vAK8O0J3DnjgeN9HI3sXvF/+o9+p
AXg/wdcVwWErELMm4nclDtfbseq4XL4C4vcFFNZ9oyAhKwUWk5oVyK3nmstK
wOfLXLlR2LAC9dGrurtTcf0o7tOKv/B+59oPTebj+hHen95O4/69fX/4NOB5
bb4tdhP/PzU67eIk34z3uwASP/jpYHPrqTS1Fdu5PF98Dx18xO6+v/UL16/n
1qnYT4ecGvn/Dozg+qnTmvJydODhorKWr+B65ifTFLTo0Ezye3l5Dfc7Z1Pg
dIsObx/s39jwD8/ra9O+1Nt02FZze/0vlgFETj7EMWGE7VWxNsM5gIw2kDny
H+D1x40cn2wdQDFf0LDfI7x+cGVlhWcACXnXc1yzpcNWRamlDQIDiMIkr51i
TwduesTcrn14vXFxaLUbHRoTZG0+7cf5+Wmj4p50CNJpnDkghuOmwW4e3nTg
ytnwR1oC7+9x6d0mfzpw2liPXToxgJiKs/dZBtOhXpDtft2pAeSavqHA+B0d
Auq/DGvK47jy3jDVMDpwiHcP6J8bQIphpaK0CDqwj13seayG82/984v+RIef
7yi3l6/g/HZ1LbFYOrxSetHlrIHz6VKmsXF0YPuc1u6rjR3QqGP9jQ41Gmra
XDp4vdhZhdJ4Ovj9G2kJuY3Xkz5bbkykwxb9XU3RhthfzGPufcf5bDnX9ptg
6y7Fuybj/AKN+kRT7PR++usUOqj+N6kuZYbPV9z7/nUqHTbze9dm/4frXy3x
cEmjQ3WlkOqZBzi/37zgbjq+3yeF1eSHuJ+UUoXTGXRgbaFW1D7G8achMsWZ
ON/NX+n6U1zv3ol4yyycL3WgrN0Bxz0Hrdiy8f/r/eRzei/w+jfN3lHYmwLu
kAec8H7kG/PCOXSolF9QMHPFccnS3HBs78kg0pQ7jjv7Nq/LpYNyxBF5Wy9c
b1VUWR974+XKgsWX2AGCvEnYlYtGp5z8sHN5FCaxvb/Sc5lfY3slVezJw+u1
Q+V8ArErYr6fx97AIp3N8RbXzyya18Uuz6g9HhyC44c6o+9iexrfz+APw+d5
151qiK3EvU7643vsoeIDV7FZ4EPqvkic7+a78Sj2L3kllf6PuP+fUvNreP/U
gilKxCfsb1epRdieJ989uxmH8zlz1iyxb+ec3bbtG47bXBNkw5aSGU2sS8D9
OPDrRODzb8wIuOD7HedLiCYJYPccPdGjlIr374rY5Yvnl57cb8eUgfMFC76P
43l7H/HhKMrC9fJbjU9i6yVIfbXPxfE6TQUHfD/HDnYpHC/Adkq/GE/c3xe3
jukiXO+cx4tqfL99IoetEwE79tFQJ77/zJhm1vul2I+Ou3Xh92EQue90bxVe
rxpllYTfk8zOn83hNcR7P1DuiN/b5nA7S606bEl1I4UkOmQFV0TWNuN+enY9
f0u8160PZV+24bilBtN+/J6NAvnqz3dip57o/fYFv3d/s3/5vdisO5OdP9OB
wsod/oSC9zt6KaE5Bn+feOdJSQ9hc/tz7oimg4n7ZpP4cewTMQdtPtAh71lS
eSiNuI+XgsTnM2Dxhr7mAu5/zmjm/Bs63H2y+pdjGeejNQ22QOLzfOWgFwNb
Xq/fyo8O98xnfB9vHkTkcYXK5650OD0aJnKUfRApOh0u6XDC3x+mioW/OQcR
E3v8i/0v6FBk+GbKmBdboexS8BP8/XTr+DUNQZz/pX4y7z86jLd2j7GJ4Hgv
19vI+3QgaXq6VoniuFj5YZu7dDC/2paucBhbw+7qHz06FF+055WQxbZqFDx2
jQ6WMoVdm9Ww+02OzUvRgdzY9j3vCvZVYc01cTpst6K6mGngfoc4jZbE6ABf
9h+o0MY+EmZaLoS/b3cE2boa4f1XRcayuOhQuGzKtvgEG2WXMn6vAHeoS98X
B5xv/tfm8OgK3DsWka71YhC5Fv8JVBlYAS7LhlsZrni/Q4Gn9TpW4G7PqTgr
f+xf3IqDpSvABpxnh2OwBzdRrfHvH6M7h7iDY3E9PYmCqjcrkL14YejcV+zh
Ec+tr1bAUOqZb3QS9sOW886uK5D5aajtdg5e3/D2Mcl8Be545j1sqsX7s9U/
6ZZbgaTLJjHFC7hfHf3U/h/LICMurICWcTzHZ8PBsmUo5qR0Ax3Hk6JkTIvw
7+sW/R0lTEPItevGBXLKMszr6waUbRlCTFd4JJmCl0HBVsOxei92wMmcb7o4
P0JBp1kZ5/szZXb3L8HfyZ3co6E4bqm4/XDzIoREjVVFvseeqWOzr16E49ey
XG5E4vzd2qcKixfBJuPKDPkTNpX/6aGkRfjj4Fr/4Tv2vI1ItMcijGwYfXW9
FK+PgprVY4vQJpi+mfQHe8u+pBn/Bci+cWl9iNIw/n9kvuXi4b/gouIVnTU6
jJgMRx3//TcHwr2qnbFeI4iJ921drcEM+JWeSdX2wZ4frY26NANz38S9N/lj
L3hNPpWagVJbThnLICL/Bz9ingFT1ubAYx+w4/ZSD3+dhvjjupdK0rDnst4G
zPwBST+znL5ubG/jXY99p+D0Cc8QgWOjiMlCuGGSMgHtJgJyUTLYr25Y/q6b
gMcBKR1CJ7DbJ+4sFEzA95HOnWLy2NXzkXLvJmBviMQnOWXs4rdX7qhOAPNs
e/KN28T6tK+queNQm3io6rU7dpr7NbPIMTBvLzbf6oXtYDul4D8GLMxaW969
xLbObzjwfAwUdJ2vRL7CNlctPagzBmmbWloSQ7E7P5RQeccgxNSRUpWI/TNS
OuPNKOjtbVhe14ItrmvhHT4CnAK22YVt2OOGR675jEAJz3abJ53YkYOCkg4j
cGDznfHxXuzhLxuO6ozADG20vWEcW0bzARIYAfcfjMwoBvbUaZvU6GGQKf/0
6Na6McQUPx87GjQMY8VKR7ayYJf3ucu6D4N6lt9nz81EXO/jznvDsD2a740l
L3br6UwW8WGIt5N8eOowtl0Sp2XxENx+1HSIJo5t3iJ6MH0IOCzsRr4fxRbr
OLUaOwS2hgV6QrLYWvGps75DcEZVWW2TIrZM7yTbrSH894eBWJs29vC9Q5wL
g/C35vWgtRs2t8jWikuD0MPWZr7qgS1eyWKlMAil6rtnXnpjh3yNE5cdhKD6
RPpHf2zy0g6ayCAcbq7irXuHTTnH8fHfABh0rbt0KBF7t3HJE9IAKO28XJf1
Hdv1Y3JU9gAcuRN0QzEVm9V1tjd5AJZ69hrdysKO2/X128cBeEs588yrGFvj
crmR2wBUjj1JGmjGzuoys1EbgO9iJGmrNmwHiXmRiwMQ/B9L3lIHEd9v+Edh
AIwm35Zz9RL9f/nz89gArEyn9p4dw1akf8/dNQCUo4t3f0wQ/b+bkeIbgCpr
hd9aU9jWJ5XLuAcgZO7nguUsto/1peMbB+DowgRXBJ2oL3jy3BwF+E5Ih+5n
YPO7F3j8ocCqvcPudKZxxKSX7Ng/ToGa5Y2HqjdgD99pGeyngOnavvMLXNhU
XWWBBgqoKlhWu23Dbr2jdKCWAtIuGVc5tmMX7Y5Tr6IAg+ncHdGd2OZDoSNA
gXAWAztNUexV9liVDBy/u0O26QARJ0dLpeL6ZY1/rx3CfkXnl/5OASn3C/ZX
JAn7+774SoHQgdUTP6WI+pWeFbG4X8WcJdXj2I03WMQ+UaD6n9hzlZPY4m9D
5SIpIGk4eLrqNLboWtLgewqEFH+gXzyLzSuu9i2MAkZOnE4XzhP7Jx1+HkyB
yp6qs6VK2OPeD3zeUEBc3o2heAlb5+yZ1EAKLK7QXBTUsbPSXZVfUUDvdrIi
6Sp2Z81ijh8FSvPvr5O/jl39ZBX5UkBMQKi04Aaxn3vAwEsKBDh0uZ+6iR0X
lvzBmwLzHW8v5OlgS53UfehFgdsn1FlO3MFmgSBdTwqQQzdUZOtjs969oe9B
gQMLxV4yRtgyx2KeuVPglbaDcqYJsZ73aYobBeaypDcdu4d98mcL3ZUCOryT
VWlmxPq/ucbYxY/jfI5aYGusF6a4UEC0Rf9yygNivTKHPbbfsR1bJB5hxw89
P4BNfdNYk2SDLdRrNu1MgZuzvv6H7bDT2JvrsYs0LqgnPMV22J9bhS2Stsou
9ozYP5O3C9uHK6fu6wsivmucGdebfvgoYL8zUS9K8iK2Vr3YtThX7JirI9HY
BRKDXPs8iH6EN/PgfoVef2j85EX00xv6EdtrSuuNkA/20gH/8/i8v9U4NaP9
CD8dZGBrJFVt2/saO0/kfQueT84Wt5bIQGzFm0lkPL/dFqdDdr0l+tmxvRLP
1/0HTSsihLhvpeYhPP9xseTtAmHE+pA+AXxfWWOCYXyRRH5mcz2+z52Xum69
+0jM80j6FX8KuH59y8/7icjf8XMYvwf1exsitn7F5p/5fCeIAhnlxbeD4rHD
lbXOvKUAv6jDLq4kot8/4sdDKDA8+DuSPY2IXz9rGY4/T+fj9P0ziPem8F9S
BAXSPunv3ZJNvKfuuPVRFHA0aozeVEDMt0N6Fb93nr7sz8zl2K6d4+zJ+H2x
OznlVhJxqbWraRTYckZJ58EP4r7KBJMzKcAc3szRXk/032VOKsDv5fqMQ0IX
0f/xGfEaCjx0zblh0EPM3/zO1Xo83xQnSZ5+bKZUd/9mCgywsQ87DhP3UdKq
002BxgqxaxozxHviP6Mwjc8/P3NowxxR315WnoY/jyK5LAXz2OTfvtpLFACX
iwX7Voj7tmX/xTwAKadM9i+yTOD9U+hiAgPwKvkDPWontvXN302qA8DaY9Ku
uQdb7MiE8/UB8NxyOH2TEHZn0E1lnQF4YZZ332Y/dnz0adH7A2Ah3NakJIXN
Ham602MAVN5xxk9exPaJnOwvGYDysjb3GBVs8sbwIzUDoDgXqa+tRtRTDApq
HoAT147wgAY2dY7n69AA/v2o4vz2zgTx/XV4beMgbHBy0zplg81UtaSiOQhZ
s1PL8JjY/2XL0zuDYHpfJ1r5KbGfq3++6SCUXzv6+8YLbAeqspP9IHiK9Lo8
9MI2iqujRw0CS/XJpNj3RH5/bNn0IDDzUNdxlmKrpLz4/XEIMl7e+RZSjk3J
3/UqcQhMVivVd1Vhu/78jXKGoHQkKkzsJzb/QHZv3RC456lJXGgn5mV0c2Zt
CNYZfNNx+I0dpLuoZTwMTAkGqYPbfuP1pcmPZUagcqrjYfR27E5nMY0LI/BK
6rqkHj+24gFBBc0R2JF3IbltDzaZf/qK9QhIVoklVYthOyyxnkoeAb2Rua8p
Ctj8qSq7D49CvvDLj88tsIXubtl4dAxsI1JfbyvFpiTevKY3AaQjPqxbH07i
+VL1d/b/AbnWHXVvrbHJPB9a8d9jaY7f3vA+xo4Zf+bHNA2f6yp38jtgc792
GheeBp9HGyQE3bHTBM//ZzoNmpnu1yVCsaUSB2+PT8PYaaeIy8XYiuL2Y79n
wGiI3bCWjN0oW1i9MgO//CP3XSnDNre7obGBCj97Cr9rVGMv2U4KbKdChvNK
8a1m7HH2WBsZKjiW2g/dGyXWc9CEbamwVdVW3J1zCn++DumujVMhpoSL7fRW
7Ji/mXVUKkidSp6Y5cEWcsp4t0SFq2LjX40FsLnPnGZnnQW/jQbC50SxNdha
gw7MAkvZZT6m00T8gMmQ8SwsnBFmcr6HPb4sxtY0C16ZxX2y5tisX50+d8wC
7xE90h8LbLJuiGTfLBzfGfZc35rY3yBddHIWrJfY/8q/wG501PRmmYOJrKUJ
ehB2kH0Tu+wc9Eg0tjwrmiL+fmOJeDUH0ZNbndYD4eYf6m/mwCThxoHXJdgO
QxG0d3i9aIdDTCV22muxPdFzsLCrb09VI7b1jv/60uZg65YpM94RYj+7aI7m
OWitktj6cQybspi70jYH4V6PCg7+JtaXbOzumoO962jsZ2aIfBW+JwNzIL60
nG68jM1UnMJBnQPl0U2rKRx/sF/VVm6hwea4y19OchPu7BrgoMFPY/+rpduw
jfIsZ7hpcKOX81PbDmzy4NwAHw2MWrcrrwpjN6Z47hOhgejbWzNeotiU63FN
ojQYu/Y+nOsgtsaBNZuDNHhYu3tSRBw7xuikrzgNXpTuC7osR+S3ULnlaKDg
eu9Uy0lsqtf8tZM0YFb4Nqh3Bjtoedb1NA188g/LWisS8SZSngIN1O0f9C2f
x5bycQZFGnDJprz0uEjEI/fknadBaJr0r1BVor/QXmdlGug+fOwhdIU4z7U5
dRUa7BbPFk+8RuzPVseuSoPYbyddSFrYQobFxldokPYRiQ4bEPGFf4Y3aEB7
TttkbIyd9o0pW4sGcre+TfbeJebhdXRVmwaFXFyZHebYrjOsxjo0YEyWhmpZ
Yiv6fnfWpYFi9dPnTVZEP1bWAbdpUOnad67Wlsg3ueKpRwNW/bf7VZ4Q5+Ez
ttCngdop5c0V9sS89PzOG9AgYPvK1LnnhLdUsRvSoHE2ubHY8Q/xnrf/wOap
N84640LUn7a1N6LBzcTt4XluRL8tfTuMaRDu/eOFrCdxfudbidjdJk6GGd7E
fdd2S5rQYC+SvnDUl8ivt/iCbbRr5MB3f6K/lvWcd/F8FsO3HAogrPfVHHu0
RX36SxC2tYhmNrZYGlOzSDAxf75N89iWr7Kyo98R+92rEDWlQYq5+fvd4cQ8
H76+hE1V2u30PoKYT5OhHvZx4UYjvihif8Ozd7GfrnkoBUcT5z18kIjndZ0Q
4/5MrH+xl1hPz55kex1H7NcpStRXeBs9s/kbMT8meRre3/XhjRbvBOL9/bmX
hV2muil3/XdiXp1xZtgbDxZGuKYQ9y1DZ8e+vP6R81oaUS/NMg6f/1W/iMnz
TGI+Z5clsOsL2y8uZhPnZ/mWgOe3NdzvkF0esf6RAzFfLTsFjtkCoj9RG2L+
oRpzVCsS8X453hH3s3vz7TyzUmIeqo+U8H0ajnBEDpcT9ZIkrfB9fy4pcTGu
It6T9hEf/B4OPj906c5Pon/T2RD8Xixu9h7urCfm1V3hjd/T92NvOLWbCJf+
scDv7djkUtvVdqI+RWPLTRo8qfqeX9tJ1EfvK/B7zYs1ilLp/v98rz3G7/ms
XrXpeQoxD0GRrxp4XicdVWCQuM8tV49co0Epr5S4/Agxz6sbY/HnQaUujCb7
m1hvd9YCf178EtQ6MqaI99Zcl48/T3Ve/wqOzhDrPThW8edNU8HM/dA8Mb8h
ss4FGuinym3dwyDyB7fanaFBzu0lzkamaXw+4ckjp2jAubGA3WM94RcvWvH3
AVnvLOsEKzZlH2NRmgYiW5T+ZfFgN/5W9cPfJ8+zN6yZ8WFT69//wN83LUZV
KzsFsIP+7FsRpoFnruqC617stIXjR3fj92p6/Y/6IaJ+sMkkF34v3DyT/44Q
9cO+5bDTIKywdTxDElvKs+rxZnzebTrD/DJEvfvUMmYaJIJB97ACtpC2RfH8
HDzc+eCHoxaRn/dNun0OKiskqo7eIvL7J/fj72dBm5nyQV1spsLPHPVz0Fhl
S1YxJOIv+nMr5uDYk2e5vBbYrsuzz7PmYLHB+8t3F+J80ts6A+fA1euTW08i
dswSy4zCHHDYb1I1TibWDzHNnpqDCHOrbaOpxP53jkzJzEGm2qnYmSxscuKX
+sNzMLq1qZwZiPO+d1LhmwO1j0ysh1qI+pfSj0/NAl+uYcATOtHfxEHhd7MQ
G19xc2UNW3Hn3cjAWZCKOCLowjSD7efF5zcLl50WU302YKfJ67K6zILjhcCm
D1zYlG+Xx81nYbChmLd0H7a1/cta+VlIHt/zgVMdW2i2sn6UCj5RXkZ9V4n8
mi1MA1Qw1fyzP+U6dqN8xaluKuwuKkq7covIv328uoEKfoF3Kl+ZEPWaFPXy
qWAu9352yzNspnEoDqCC0iRT7q8XRHxgKd6XCoIx5o6JzoRnrD97UqF988lN
qp6EqbTy51S42Nu+2zcQW2O7TpsZFYTeKgzqvMWW+huifJcKq8pfv4m9w6bm
dtQYUCEr7cmx6ggiHn2f8yYVRDx5VTZ9JeahlBx4kQqMk44cHfHYRn95v52j
QtefoeavSdhkv4C2s1QIupWpr5xO5Hs0P5OjwgP2Xfv4srBjVJOpx6igUuI+
PpJDrIcC16NU+HdY87FXERFn+zAtRoVf/fkntQHb9eHLuv1UyAkRZoiWEo7o
qhKhwkMG1ae8ipin5Az3HiqoZupcDakhbN9mtJMK+83JPKZ1xDzVzep3UKGn
KfDj+hYibkxh4aFCnvfi3ZY2wizz9dxUCDljeCi2k/AiWz4nFaypldO23UT/
NiVl7FRQ+yKZdb6PqNedMrOFCgduhz7bNkD416Ozm6nAzMVQGBwi+lP/lLyJ
Cn1l91gyRv+//4DiRioUONT9cJsg6h9tWGShQqiEbOD1KcJ+bC3rqWAzGKkl
PEPsJ3uyhZkK6mEsO2dnifu+sLS0jgpi6g/6yfNEnIOqhM2yrjUuaJGYn3RF
LhMVKNlnLIxWiPkF79XELrKIPSq1RtTXi+PFDhNk+/vvH1GP8Q//hP8B7VoZ
kQ==
         "]]},
       Annotation[#, "Charting`Private`Tag$1913790#2"]& ], 
      TagBox[
       {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwd1nk81UsUAHBcIft67VzurVSSlChlpkiyJ7IUSaLNEqJIKEqyFUkSQrJk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         "]]},
       Annotation[#, "Charting`Private`Tag$1913790#3"]& ], 
      TagBox[
       {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwd13k81FsUAHAkRMmWItkNIvs2Y8a9ZkwhyhZST0i7UKlERULIliSFUiql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         "]]},
       Annotation[#, "Charting`Private`Tag$1913790#4"]& ], 
      TagBox[
       {RGBColor[0.528488, 0.470624, 0.701351], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwd13k4lU0UAHCkj5JdQsoSoiTZCTOWa7uIe5WtLCW02iUSCoWSSkiSKJXs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         "]]},
       Annotation[#, "Charting`Private`Tag$1913790#5"]& ], 
      TagBox[
       {RGBColor[0.772079, 0.431554, 0.102387], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwd13c81W0UAHCkQqKsJEWyKiuZieexuRfXNaJISGjY6kXJCKUyQlKIjERE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         "]]},
       Annotation[#, "Charting`Private`Tag$1913790#6"]& ], 
      TagBox[
       {RGBColor[0.363898, 0.618501, 0.782349], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwd13k4lF0UAHCkkkpZQwozEpFlBlNZ7s2WbBFCZC+K7IoiS1QiVJI9qVSW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         "]]},
       Annotation[#, "Charting`Private`Tag$1913790#7"]& ]}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    Method->{
     "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
      "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotRange->{{0, 1}, {-77.13791508244682, 78.55197279107324}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.05], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8069524562089*^9, 3.806952545863447*^9, {3.806953130438311*^9, 
   3.8069531530933523`*^9}, 3.806953813243287*^9},
 CellLabel->
  "Out[539]=",ExpressionUUID->"e0df47be-22ea-47b7-9905-a68d75a686db"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"d", "=", "6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{"{", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"u", "^", "i"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "d"}], "}"}]}], "]"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ATAinv", "=", 
   RowBox[{"Inverse", "[", 
    RowBox[{"HilbertMatrix", "[", 
     RowBox[{"d", "+", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"polynomial", "=", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"ATAinv", ".", 
         RowBox[{"A", "\[Transpose]"}]}], ")"}], "\[LeftDoubleBracket]", 
       RowBox[{";;", ",", "1"}], "\[RightDoubleBracket]"}], ".", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"s", "^", "i"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "d"}], "}"}]}], "]"}]}], ",", "s", ",", 
     "s"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"polynomials", "=", 
    RowBox[{"CoefficientList", "[", 
     RowBox[{"polynomial", ",", "s"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"polynomials", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"u", "^", "i"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "d"}], "}"}]}], "]"}], ".", 
        RowBox[{"Inverse", "[", 
         RowBox[{"HilbertMatrix", "[", 
          RowBox[{"d", "+", "1"}], "]"}], "]"}]}], ")"}], 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "j"}], "/", 
         RowBox[{"(", 
          RowBox[{"j", "+", "1"}], ")"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", 
          RowBox[{"d", "+", "1"}]}], "}"}]}], "]"}]}]}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"coefficientBounds", "=", 
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"Abs", "[", "polynomials", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
   "N"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"polynomials", ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "Full"}]}], "]"}]}], "Input",
 Evaluatable->False,
 CellOpen->False,
 CellChangeTimes->{{3.8066479029989967`*^9, 3.806648108206756*^9}, {
   3.8066481420000362`*^9, 3.80664822590557*^9}, {3.806648309330421*^9, 
   3.806648375629612*^9}, {3.806648428805423*^9, 3.806648434151616*^9}, {
   3.806648477337376*^9, 3.806648481877582*^9}, {3.806648562288628*^9, 
   3.806648563651862*^9}, {3.806648809878293*^9, 3.806648848122044*^9}, {
   3.806648942084214*^9, 3.806649103855835*^9}, {3.806649498252428*^9, 
   3.806649628909584*^9}, {3.806649683819895*^9, 3.806649725344377*^9}, {
   3.806693019578224*^9, 3.806693028175012*^9}, {3.806693991738159*^9, 
   3.806693993934313*^9}, {3.8066940275450077`*^9, 3.806694093298616*^9}, {
   3.806694151721579*^9, 3.806694196076663*^9}, 3.806694274764338*^9, {
   3.8067256685526123`*^9, 3.8067256687442207`*^9}, {3.806727373107641*^9, 
   3.806727373792451*^9}, {3.8067277316906033`*^9, 3.8067277488796577`*^9}, {
   3.806761587070128*^9, 3.80676160041048*^9}, {3.806950417336444*^9, 
   3.806950445192566*^9}},
 CellLabel->
  "In[540]:=",ExpressionUUID->"f9aed4b6-20b5-4eb4-95ed-f3cfbe178f97"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.`", ",", "0.`", ",", "1.818002675462946`", ",", "23.082320809302363`", 
   ",", "111.81911195344067`", ",", "264.2699712921428`", ",", 
   "327.64700661961956`", ",", "205.05738514556455`", ",", 
   "51.156843292260085`"}], "}"}]], "Output",
 CellOpen->False,
 CellChangeTimes->{
  3.8066939951044607`*^9, {3.806694031242033*^9, 3.806694094757903*^9}, {
   3.806694183709022*^9, 3.806694200624609*^9}, 3.806694276979705*^9, {
   3.806727363193686*^9, 3.8067273760662327`*^9}, {3.806727567176951*^9, 
   3.806727579311039*^9}, {3.806727733365005*^9, 3.806727751482791*^9}, 
   3.8067616056387243`*^9, 3.8067852930734167`*^9, 3.80694897078321*^9, 
   3.80695022881425*^9, 3.80695044870673*^9, 3.8069539090332613`*^9},
 CellLabel->
  "Out[545]=",ExpressionUUID->"bc5cd84c-ac6f-47b4-b65d-ff70e1a460bc"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJxF0H0s1AEYB/A7rlHW6fRiPzp2ovIWk5RUKhZ5qXmbLG8T0vWGbKXVdM1J
XmLtJuX9JaUbR+6scmLctMz7EYo7ziXceducGy1XbfU8z/bdd5//vnsYUTf9
Y7RIJJLvn/xtr5iZ/tbZoBOkf0dxM4qXEo6u/32wJL+wgXAHe3cPvy0iAsHB
0ermp0Q0eNzukVs2kQQu3Xk+LYNIBbN0G/Y9JjjgCyFlvKXlSrCehhXqYcID
W/gtzLRn8sG3e5xd81fegw35NAmZ3AJulLl19R5rA7cxi4xDlCKwau9x/Zrr
n8Baa9xtxhadYCdNZGNAbRe4K9Wxp8OqF2yaq1irXugDK9RSyZD9ALhyrqmT
+kQMptJfLcrlg+CsK4LYUvMv4NWTXHlcyjA4yUHE39U+ApbWijL7GV/BP5mD
BZZ3v4GtT+lsxDaNgT3KGZfrDSX4L3qE2WSoFGyjDNIb9p0Ab9df0hWtoykt
Bbw9hZPgq45No5u9ZWDu2ajSj6tolcJo23TeFFgQ4KHNcZeDUzzZJfxpNGPc
a6SC/R189HAqh3CYBoea9K6RxWhVZ7YsnvUDnE8JT/I3n8H9EkG5lgi96T4r
0DlhFkyqDufJDObAiS942QZt6GbrdF3aDQWY5pVo85CqBI/Z9omThei6Yldz
efg8OIznRKNvoB+wy1hjbxbANTP0AqrPIji9iB0pOYeO9p+3qPVD7xYK63yD
0Rk5FzuyotBxTs+XtySjzVJ3eOpUoTeO3Ns6/Bo9Oj81UMVF5wY3hJ2pR2us
/G+xheix/pxibTH6XZr6kngIzXGJsKwYQXu/PMA/LUF/uNP9mTWLzrM9lOOn
RCfICgMZi+j9PtekrStoCnmwMleNnhC4MCPX0UJmhZ39L/QzUz2VRoP+DRRC
Ph8=
       "]]},
     Annotation[#, "Charting`Private`Tag$1916586#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJxF0H0s1AEYB/A7rlHW6fRiPzp2ovIWk5RUKhZ5qXmbLG8T0vWGbKXVdM1J
XmLtJuX9JaUbR+6scmLctMz7EYo7ziXceducGy1XbfU8z/bdd5//vnsYUTf9
Y7RIJJLvn/xtr5iZ/tbZoBOkf0dxM4qXEo6u/32wJL+wgXAHe3cPvy0iAsHB
0ermp0Q0eNzukVs2kQQu3Xk+LYNIBbN0G/Y9JjjgCyFlvKXlSrCehhXqYcID
W/gtzLRn8sG3e5xd81fegw35NAmZ3AJulLl19R5rA7cxi4xDlCKwau9x/Zrr
n8Baa9xtxhadYCdNZGNAbRe4K9Wxp8OqF2yaq1irXugDK9RSyZD9ALhyrqmT
+kQMptJfLcrlg+CsK4LYUvMv4NWTXHlcyjA4yUHE39U+ApbWijL7GV/BP5mD
BZZ3v4GtT+lsxDaNgT3KGZfrDSX4L3qE2WSoFGyjDNIb9p0Ab9df0hWtoykt
Bbw9hZPgq45No5u9ZWDu2ajSj6tolcJo23TeFFgQ4KHNcZeDUzzZJfxpNGPc
a6SC/R189HAqh3CYBoea9K6RxWhVZ7YsnvUDnE8JT/I3n8H9EkG5lgi96T4r
0DlhFkyqDufJDObAiS942QZt6GbrdF3aDQWY5pVo85CqBI/Z9omThei6Yldz
efg8OIznRKNvoB+wy1hjbxbANTP0AqrPIji9iB0pOYeO9p+3qPVD7xYK63yD
0Rk5FzuyotBxTs+XtySjzVJ3eOpUoTeO3Ns6/Bo9Oj81UMVF5wY3hJ2pR2us
/G+xheix/pxibTH6XZr6kngIzXGJsKwYQXu/PMA/LUF/uNP9mTWLzrM9lOOn
RCfICgMZi+j9PtekrStoCnmwMleNnhC4MCPX0UJmhZ39L/QzUz2VRoP+DRRC
Ph8=
       "]]},
     Annotation[#, "Charting`Private`Tag$1916586#2"]& ], 
    TagBox[
     {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwd13c81e8XAHBFhSsRDVqUSmVVRlTOTSpJUZERQkLKqISiSMhKvkiSGSEj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       "]]},
     Annotation[#, "Charting`Private`Tag$1916586#3"]& ], 
    TagBox[
     {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV13c4FVwYAHCrzFA0SNmy5x3mPUdmViIjm4SUEZJIqAghX1SESiSRmT1P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       "]]},
     Annotation[#, "Charting`Private`Tag$1916586#4"]& ], 
    TagBox[
     {RGBColor[0.528488, 0.470624, 0.701351], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwd13k8lF8XAHBKZd8JiahkC0lIuDdJhOz7jBmMNcsk/BBZQooQKklSUhKR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       "]]},
     Annotation[#, "Charting`Private`Tag$1916586#5"]& ], 
    TagBox[
     {RGBColor[0.772079, 0.431554, 0.102387], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV13k81E0YAHCkSEUkV8otIVREipkclRy5z5L7Suxl7ZJYRW4dkuRM9coR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       "]]},
     Annotation[#, "Charting`Private`Tag$1916586#6"]& ], 
    TagBox[
     {RGBColor[0.363898, 0.618501, 0.782349], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwd13k8lF8XAHCkkuyEpFBISCpLIvcSZUsqWwjZsmTfZoYZ21BKCElZEhXJ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       "]]},
     Annotation[#, "Charting`Private`Tag$1916586#7"]& ], 
    TagBox[
     {RGBColor[1, 0.75, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13c8lV8YAHCaKpFZSj9bKkllNNQ5GYVUSBGyybz3vdc1ElERsmdCJUKJ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       "]]},
     Annotation[#, "Charting`Private`Tag$1916586#8"]& ], 
    TagBox[
     {RGBColor[0.647624, 0.37816, 0.614037], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwl23k4lc8XAHBCSUUke1lCtlCIhJnsu/viXoWEVFIhS1FZKkn2SkhEkRCR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       "]]},
     Annotation[#, "Charting`Private`Tag$1916586#9"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1}, {-1469.9988480002203`, 1616.9986800002596`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellOpen->False,
 CellChangeTimes->{
  3.8066939951044607`*^9, {3.806694031242033*^9, 3.806694094757903*^9}, {
   3.806694183709022*^9, 3.806694200624609*^9}, 3.806694276979705*^9, {
   3.806727363193686*^9, 3.8067273760662327`*^9}, {3.806727567176951*^9, 
   3.806727579311039*^9}, {3.806727733365005*^9, 3.806727751482791*^9}, 
   3.8067616056387243`*^9, 3.8067852930734167`*^9, 3.80694897078321*^9, 
   3.80695022881425*^9, 3.80695044870673*^9, 3.806953909102786*^9},
 CellLabel->
  "Out[546]=",ExpressionUUID->"9be4bca9-b0ac-486c-9df9-d006db289cb1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "\[Element]", "Integers"}], "&&", 
    RowBox[{"i", "\[GreaterEqual]", "1"}], "&&", 
    RowBox[{"i", "\[Element]", "Integers"}]}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"QdGeneralCase", "/", 
       RowBox[{"(", 
        RowBox[{"QdGeneralCase", "/.", 
         RowBox[{"{", 
          RowBox[{"i", "\[Rule]", "0"}], "}"}]}], ")"}]}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{"u", "\[Rule]", "1"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8069548932104597`*^9, 3.806954895216001*^9}, {
  3.806954997495096*^9, 3.80695510616535*^9}, {3.806955168851149*^9, 
  3.806955230435915*^9}},
 CellLabel->
  "In[558]:=",ExpressionUUID->"ea0ec96f-c265-467b-a227-a8d45d301ff3"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    RowBox[{"-", "2"}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"Gamma", "[", 
      RowBox[{"-", "d"}], "]"}], " ", 
     RowBox[{"Gamma", "[", 
      RowBox[{"2", "+", "d"}], "]"}]}]}]], 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"1", "+", "i"}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "i"}], ")"}], " ", 
   RowBox[{"Gamma", "[", 
    RowBox[{"-", "d"}], "]"}], " ", 
   RowBox[{"Gamma", "[", 
    RowBox[{"2", "+", "d"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "i"}], ")"}], " ", 
      RowBox[{"Binomial", "[", 
       RowBox[{
        RowBox[{"2", "+", "d"}], ",", 
        RowBox[{"d", "-", "i"}]}], "]"}], " ", 
      RowBox[{"Binomial", "[", 
       RowBox[{
        RowBox[{"1", "+", "d", "+", "i"}], ",", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "d"}]}], "]"}], " ", 
      RowBox[{"HypergeometricPFQ", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "-", "d"}], ",", 
          RowBox[{"3", "+", "d"}], ",", 
          RowBox[{"2", "+", "i"}], ",", 
          RowBox[{"2", "+", "i"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"3", "+", "i"}], ",", 
          RowBox[{"3", "+", "i"}]}], "}"}], ",", "1"}], "]"}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"Binomial", "[", 
       RowBox[{
        RowBox[{"1", "+", "d"}], ",", 
        RowBox[{"d", "-", "i"}]}], "]"}], " ", 
      RowBox[{"Binomial", "[", 
       RowBox[{
        RowBox[{"1", "+", "d", "+", "i"}], ",", "d"}], "]"}], " ", 
      RowBox[{"HypergeometricPFQ", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "d"}], ",", 
          RowBox[{"2", "+", "d"}], ",", 
          RowBox[{"1", "+", "i"}], ",", 
          RowBox[{"1", "+", "i"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"2", "+", "i"}], ",", 
          RowBox[{"2", "+", "i"}]}], "}"}], ",", "1"}], "]"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.806954917604446*^9, 3.806954990780205*^9, {3.80695504829051*^9, 
   3.806955109754249*^9}, {3.806955172439535*^9, 3.8069552319511127`*^9}},
 CellLabel->
  "Out[558]=",ExpressionUUID->"97a5fc6e-e12a-4352-8f88-813acddea138"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{960, 855},
WindowMargins->{{-1440, Automatic}, {-680, Automatic}},
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"619f5512-9ffb-4c56-a79b-e2b708dede08"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 333, 7, 105, "Section",ExpressionUUID->"5c3180f5-120f-4e11-9b6c-a04160ce1001"],
Cell[CellGroupData[{
Cell[938, 33, 1334, 23, 243, "Text",ExpressionUUID->"f22839e8-9d32-47d0-8eda-bda2e10543bf",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[2275, 58, 3483, 100, 164, "DisplayFormula",ExpressionUUID->"a9a1eb48-ef12-4b68-9e11-b89eced0e6ae",
 Evaluatable->False,
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->False],
Cell[5761, 160, 833, 22, 39, "Text",ExpressionUUID->"f38a1e70-bd79-4ea8-a0a8-c74e36c7852f",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[6597, 184, 2909, 73, 203, "DisplayFormula",ExpressionUUID->"85584521-efc5-4a2a-a673-5bc15b436cbd",
 Evaluatable->False,
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->False],
Cell[9509, 259, 554, 13, 35, "Text",ExpressionUUID->"06f6256a-c29f-4ec2-a7b9-b04cfba3f623",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[10066, 274, 3472, 91, 149, "DisplayFormula",ExpressionUUID->"784f5b84-fc50-4734-ace4-0817b4553106",
 Evaluatable->False,
 CellGroupingRules->{"GroupTogetherGrouping", 10000.},
 InitializationCell->False],
Cell[13541, 367, 1663, 42, 60, "Text",ExpressionUUID->"fabbf25e-4c5c-4ea5-b9cd-581932963357",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}]
}, Open  ]],
Cell[15219, 412, 6604, 183, 209, "DisplayFormula",ExpressionUUID->"3e93b7dd-d0da-4d3a-be12-94f655c0e50a"],
Cell[21826, 597, 2260, 62, 104, "Text",ExpressionUUID->"6a723a30-6706-4c9c-b565-4ca4a65cf90d",
 CellGroupingRules->{"GroupTogetherGrouping", 10000.}],
Cell[24089, 661, 7043, 178, 249, "Input",ExpressionUUID->"b1d06e0d-d80f-4258-bcdb-c036da5769a2"],
Cell[CellGroupData[{
Cell[31157, 843, 1270, 33, 52, "Input",ExpressionUUID->"fbbba7aa-c108-4f80-923a-dd288db360b2",
 Evaluatable->False],
Cell[32430, 878, 2049, 62, 72, "Output",ExpressionUUID->"1d00340f-3212-4540-bd1c-bf5ccec27bbc"],
Cell[34482, 942, 2070, 63, 73, "Output",ExpressionUUID->"273b3180-1088-4d04-bcc6-69ac8cc57813"]
}, Closed]],
Cell[36567, 1008, 911, 24, 54, "Text",ExpressionUUID->"e14459a8-58b8-4473-a829-2c74b239ead0"],
Cell[CellGroupData[{
Cell[37503, 1036, 3718, 72, 115, "Input",ExpressionUUID->"779f02d4-92f8-4572-88a3-c53328b51dc6"],
Cell[41224, 1110, 822, 22, 34, "Output",ExpressionUUID->"82b365e3-3c9d-4c49-9330-8c43ec19abb8"],
Cell[42049, 1134, 847, 23, 50, "Output",ExpressionUUID->"d5e2901f-3a0d-4b4d-8790-8d6ebe30c7a0"],
Cell[42899, 1159, 1373, 34, 56, "Output",ExpressionUUID->"5447a28e-7643-4ce2-ba6d-377ed562821e"],
Cell[44275, 1195, 315562, 5344, 262, "Output",ExpressionUUID->"e0df47be-22ea-47b7-9905-a68d75a686db"]
}, Open  ]],
Cell[CellGroupData[{
Cell[359874, 6544, 3533, 93, 19, "Input",ExpressionUUID->"f9aed4b6-20b5-4eb4-95ed-f3cfbe178f97",
 Evaluatable->False,
 CellOpen->False],
Cell[363410, 6639, 843, 16, 19, "Output",ExpressionUUID->"bc5cd84c-ac6f-47b4-b65d-ff70e1a460bc",
 CellOpen->False],
Cell[364256, 6657, 120693, 2016, 19, "Output",ExpressionUUID->"9be4bca9-b0ac-486c-9df9-d006db289cb1",
 CellOpen->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[484986, 8678, 816, 21, 52, "Input",ExpressionUUID->"ea0ec96f-c265-467b-a227-a8d45d301ff3"],
Cell[485805, 8701, 2372, 72, 117, "Output",ExpressionUUID->"97a5fc6e-e12a-4352-8f88-813acddea138"]
}, Open  ]]
}, Open  ]]
}
]
*)

