(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    360862,       7171]
NotebookOptionsPosition[    353603,       7043]
NotebookOutlinePosition[    354014,       7060]
CellTagsIndexPosition[    353971,       7057]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Principal Component Analysis of Random Walk, \
Integrated Random Walk", "Section"]], "Subsection",
 CellChangeTimes->{{3.8056892234080687`*^9, 
  3.805689251180789*^9}},ExpressionUUID->"9fa8ee0a-d523-4b1b-91dc-\
be6a56914584"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Determine", " ", "the", " ", "order", " ", "of", " ", "an", " ", 
    "integral", " ", "eigenproblem"}], "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "IntegralOrder", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"IntegralOrder", "[", 
      RowBox[{"Integrate", "[", 
       RowBox[{"e_", ",", "lims__"}], "]"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"Length", "[", 
       RowBox[{"{", "lims", "}"}], "]"}], "+", 
      RowBox[{"IntegralOrder", "[", "e", "]"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"IntegralOrder", "[", 
      RowBox[{"head_", "[", "args___", "]"}], "]"}], ":=", 
     RowBox[{"Max", "@@", 
      RowBox[{"(", 
       RowBox[{"IntegralOrder", "/@", 
        RowBox[{"{", "args", "}"}]}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"IntegralOrder", "[", 
      RowBox[{"_Symbol", "|", 
       RowBox[{"(", 
        RowBox[{"_", "?", "NumberQ"}], ")"}]}], "]"}], "=", "0"}], ";"}], 
   "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Reduce", " ", "an", " ", "integral", " ", "eigenproblem", " ", "to", 
      " ", "a", " ", "finite"}], "-", 
     RowBox[{
     "dimensional", " ", "subproblem", " ", "and", " ", "a", " ", 
      "univariate", " ", "equation", " ", "for", " ", "the", " ", 
      "eigenvalues"}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"Clear", "[", "ReduceIntegralEquation", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"ReduceIntegralEquation", "[", 
      RowBox[{"eqn_", ",", "fun_", ",", "var_"}], "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "m", ",", "eqn2", ",", "w", ",", "vars", ",", "A", ",", "eigvaleqn", 
         ",", "rules", ",", "ev"}], "}"}], ",", "\n", "\t", 
       RowBox[{"(*", 
        RowBox[{
        "Find", " ", "the", " ", "ODE", " ", "corresponding", " ", "to", " ", 
         "this", " ", "integral", " ", "equation", " ", "and", " ", "obtain", 
         " ", "its", " ", "general", " ", "solution"}], "*)"}], "\n", "\t", 
       RowBox[{
        RowBox[{"m", "=", 
         RowBox[{"IntegralOrder", "[", "eqn", "]"}]}], ";", "\n", "\t", 
        RowBox[{"eqn2", "=", 
         RowBox[{"D", "[", 
          RowBox[{"eqn", ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "m"}], "}"}]}], "]"}]}], ";", "\n", "\t", 
        RowBox[{"w", "=", 
         RowBox[{"fun", "/.", 
          RowBox[{
           RowBox[{"DSolve", "[", 
            RowBox[{"eqn2", ",", "fun", ",", "var"}], "]"}], 
           "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}], ";", 
        "\n", "\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "Substitute", " ", "back", " ", "into", " ", "the", " ", "integral",
            " ", "equation", " ", "and", " ", "eliminate", " ", "t", " ", 
           "by", " ", "equating", " ", "coefficients", " ", "to", " ", 
           "obtain", " ", "an", " ", "m"}], "-", 
          RowBox[{"dimensional", " ", "linear", " ", "system"}]}], "*)"}], 
        "\n", "\t", 
        RowBox[{"eqn2", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"eqn", "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"Head", "[", "fun", "]"}], "[", "x_", "]"}], 
              "\[RuleDelayed]", 
              RowBox[{"(", 
               RowBox[{"w", "/.", 
                RowBox[{"{", 
                 RowBox[{"var", "\[Rule]", "x"}], "}"}]}], ")"}]}], "}"}]}], 
           ")"}], "//", "FullSimplify"}]}], ";", "\n", "\t", 
        RowBox[{"(*", 
         RowBox[{"Equate", " ", "coefficients", " ", 
          RowBox[{"(", 
           RowBox[{
           "and", " ", "verify", " ", "that", " ", "the", " ", "expressions", 
            " ", "are", " ", "indeed", " ", "polynomial", " ", "in", " ", 
            "var"}], ")"}]}], "*)"}], "\n", "\t", 
        RowBox[{"vars", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"C", "[", "i", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "m"}], "}"}]}], "]"}]}], ";", "\n", 
        "\t", 
        RowBox[{"eqn2", "=", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"#", "==", "0"}], ")"}], "&"}], "/@", 
            RowBox[{"CoefficientList", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
               "eqn2", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
                "-", 
               RowBox[{
               "eqn2", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}], ",", "var"}], "]"}]}], "/.", 
           RowBox[{"{", 
            RowBox[{"t", "\[RuleDelayed]", 
             RowBox[{"Assert", "[", "False", "]"}]}], "}"}]}], "]"}]}], ";", 
        "\n", "\t", 
        RowBox[{"A", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"CoefficientArrays", "[", 
            RowBox[{"eqn2", ",", "vars"}], "]"}], "\[LeftDoubleBracket]", "2",
            "\[RightDoubleBracket]"}], "//", "Normal"}]}], ";", "\n", "\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"A", " ", "must", " ", "be", " ", "rank"}], "-", 
          RowBox[{
          "deficient", " ", "to", " ", "have", " ", "a", " ", "nonzero", " ", 
           
           RowBox[{"solution", "."}]}]}], "*)"}], "\n", "\t", 
        RowBox[{"eigvaleqn", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Det", "[", "A", "]"}], "==", "0"}], ")"}], "//", 
          "FullSimplify"}]}], ";", "\n", "\t", 
        RowBox[{"(*", 
         RowBox[{"Eliminate", " ", "oscillatory", " ", "terms"}], "*)"}], 
        "\n", "\t", 
        RowBox[{"rules", "=", 
         RowBox[{"{", "\n", "\t\t", 
          RowBox[{
           RowBox[{
            RowBox[{"Sin", "[", "\[Phi]", "]"}], "\[Rule]", 
            RowBox[{"s", " ", 
             RowBox[{"Sqrt", "[", 
              RowBox[{"1", "-", 
               RowBox[{
                RowBox[{"Cos", "[", "\[Phi]", "]"}], "^", "2"}]}], "]"}]}]}], 
           ",", "\n", "\t\t", 
           RowBox[{
            RowBox[{"Solve", "[", 
             RowBox[{"eigvaleqn", ",", 
              RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "]"}], 
            "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "\n", "\t", 
          "}"}]}], ";", "\n", "\t", 
        RowBox[{"Assuming", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"s", "^", "2"}], "==", "1"}], ",", "\n", "\t\t", 
          RowBox[{
           RowBox[{"eqn2", "=", 
            RowBox[{"FullSimplify", "[", 
             RowBox[{"eqn2", "//.", "rules"}], "]"}]}], ";", "\n", "\t\t", 
           RowBox[{"(*", 
            RowBox[{"Find", " ", "null", " ", "space"}], "*)"}], "\n", "\t\t", 
           RowBox[{"A", "=", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"CoefficientArrays", "[", 
                 RowBox[{"eqn2", ",", "vars"}], "]"}], "\[LeftDoubleBracket]",
                 "2", "\[RightDoubleBracket]"}], "//", "Normal"}], "//", 
              "ExpToTrig"}], "//", "FullSimplify"}]}], ";", "\n", "\t\t", 
           RowBox[{"ev", "=", 
            RowBox[{
             RowBox[{"NullSpace", "[", 
              RowBox[{"A", ",", 
               RowBox[{"ZeroTest", "\[Rule]", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"PossibleZeroQ", "[", 
                   RowBox[{"FullSimplify", "[", "#", "]"}], "]"}], "&"}], 
                 ")"}]}]}], "]"}], "\[LeftDoubleBracket]", "1", 
             "\[RightDoubleBracket]"}]}], ";", "\n", "\t\t", 
           RowBox[{"ev", "=", 
            RowBox[{"FullSimplify", "[", "ev", "]"}]}], ";"}]}], "\n", "\t", 
         "]"}], ";", "\n", "\t", 
        RowBox[{"w", "=", 
         RowBox[{"w", "/.", 
          RowBox[{"Thread", "[", 
           RowBox[{"vars", "\[Rule]", "ev"}], "]"}]}]}], ";", "\n", "\t", 
        RowBox[{"(*", 
         RowBox[{
         "Return", " ", "eigenfunction", " ", "and", " ", "eigenvalue", " ", 
          "condition"}], "*)"}], "\n", "\t", 
        RowBox[{"{", 
         RowBox[{"w", ",", "eigvaleqn"}], "}"}]}]}], "\n", "]"}]}], ";"}], 
   "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Simplify", " ", "expressions", " ", "containing", " ", "a", " ", 
      "variable", " ", "s", " ", "representing"}], " ", "\[PlusMinus]", "1"}],
     "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"ForBothSigns", "[", "expr_", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"plus", ",", "minus"}], "}"}], ",", 
       RowBox[{"Assuming", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"s", "^", "2"}], "\[Equal]", "1"}], ",", "\n", "\t", 
         RowBox[{
          RowBox[{"plus", "=", 
           RowBox[{"FullSimplify", "[", 
            RowBox[{"TrigToExp", "[", 
             RowBox[{"expr", "/.", 
              RowBox[{"{", 
               RowBox[{"s", "\[Rule]", 
                RowBox[{"+", "1"}]}], "}"}]}], "]"}], "]"}]}], ";", "\n", 
          "\t", 
          RowBox[{"minus", "=", 
           RowBox[{"FullSimplify", "[", 
            RowBox[{"TrigToExp", "[", 
             RowBox[{"expr", "/.", 
              RowBox[{"{", 
               RowBox[{"s", "\[Rule]", 
                RowBox[{"-", "1"}]}], "}"}]}], "]"}], "]"}]}], ";", "\n", 
          "\t", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"plus", "+", "minus"}], ")"}], "/", "2"}], "+", 
            RowBox[{"s", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"plus", "-", "minus"}], ")"}], "/", "2"}]}]}], "//", 
           "FullSimplify"}]}]}], "]"}]}], "\n", "]"}]}], ";"}]}]}]], "Input",
 InitializationCell->True,
 AutoIndent->True,
 CellChangeTimes->{{3.805687101912587*^9, 3.805687105837887*^9}, {
  3.8056872261812887`*^9, 3.805687227859086*^9}, {3.80568736057239*^9, 
  3.8056876167051563`*^9}, {3.805687664724004*^9, 3.805687665125883*^9}, {
  3.805690582640184*^9, 3.805690605733302*^9}, {3.805690644108171*^9, 
  3.8056907278463993`*^9}},ExpressionUUID->"a3e2d778-417d-43b2-b53f-\
65430206e861"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Continuous-time random walk", "Subsection",
 CellChangeTimes->{{3.805690749287126*^9, 
  3.8056907577049522`*^9}},ExpressionUUID->"9c96a281-e8ec-4545-af4c-\
bfa21973e780"],

Cell["\<\
Principal component analysis of the continuous-time random walk.\
\>", "Text",
 CellChangeTimes->{{3.805690773479074*^9, 
  3.805690773590309*^9}},ExpressionUUID->"9b97635e-3dfd-4222-9fff-\
6617474d2dfd"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"eqn", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Omega]", "^", 
        RowBox[{"-", "2"}]}], ")"}], 
      RowBox[{"w", "[", "t", "]"}]}], "==", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"w", "[", "t2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t1", ",", "0", ",", "t"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t2", ",", "t1", ",", "T"}], "}"}]}], "]"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "Eigenproblem", " ", "for", " ", "covariance", " ", "functional", " ", 
    "of", " ", "random", " ", "walk"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"eigfun", ",", "eigvaleqn"}], "}"}], "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"T", ">", "0"}], "&&", 
      RowBox[{"\[Phi]", ">", "0"}]}], ",", 
     RowBox[{"ReduceIntegralEquation", "[", 
      RowBox[{
       RowBox[{"eqn", "/.", 
        RowBox[{"{", 
         RowBox[{"\[Omega]", "\[Rule]", 
          RowBox[{"\[Phi]", "/", "T"}]}], "}"}]}], ",", 
       RowBox[{"w", "[", "t", "]"}], ",", "t"}], "]"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"eigfun", "=", 
   RowBox[{"eigfun", "/.", 
    RowBox[{"{", 
     RowBox[{"\[Phi]", "\[Rule]", 
      RowBox[{"\[Omega]", " ", "T"}]}], "}"}]}]}], ";"}], "\n", 
 RowBox[{"<|", 
  RowBox[{
   RowBox[{
    RowBox[{"eigenvalues", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"eigvaleqn", "&&", 
       RowBox[{"\[Lambda]", "==", 
        RowBox[{"\[Omega]", "^", 
         RowBox[{"-", "2"}]}]}]}], ")"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{"\[Phi]", "\[Rule]", 
      RowBox[{"\[Omega]", " ", "T"}]}], "}"}]}], ",", 
   RowBox[{"eigenfunctions", "\[Rule]", "eigfun"}]}], "|>"}], "\n", 
 RowBox[{
  RowBox[{"eigfunNorm", "=", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"eigfun", "^", "2"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "T"}], "}"}]}], "]"}], "//", 
    "FullSimplify"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"neigval", "=", 
   RowBox[{"NSolve", "[", 
    RowBox[{"eigvaleqn", ",", 
     RowBox[{"\[Phi]", "\[Element]", 
      RowBox[{"Interval", "[", 
       RowBox[{"{", 
        RowBox[{"0", ",", "25"}], "}"}], "]"}]}], ",", "Reals"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"\"\<First \>\"", "<>", 
  RowBox[{"ToString", "[", 
   RowBox[{"Length", "[", "neigval", "]"}], "]"}], "<>", 
  "\"\< eigenfunctions:\>\""}], "\n", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"eigfun", "/", 
      RowBox[{"Sqrt", "[", "eigfunNorm", "]"}]}], ")"}], "/.", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"T", "\[Rule]", "1"}], ",", 
        RowBox[{"\[Omega]", "\[Rule]", "\[Phi]"}]}], "}"}], "/.", "neigval"}],
      ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", 
    RowBox[{"1", "/", "3"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]}], "Input",
 CellLabel->"In[38]:=",ExpressionUUID->"ab3d85c3-4d0d-4150-ada7-d824d5804ef5"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"eigenvalues", "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"T", " ", "\[Omega]"}], "]"}], "\[Equal]", "0"}], "&&", 
     RowBox[{"\[Lambda]", "\[Equal]", 
      FractionBox["1", 
       SuperscriptBox["\[Omega]", "2"]]}]}]}], ",", 
   RowBox[{"eigenfunctions", "\[Rule]", 
    RowBox[{"Sin", "[", 
     RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}], 
  "\[RightAssociation]"}]], "Output",
 CellChangeTimes->{3.8056616332345333`*^9, 3.8056892582074757`*^9, 
  3.8056901591812983`*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"636d89b4-7bb9-4c4c-8d9a-f0e6b8389f55"],

Cell[BoxData["\<\"First 8 eigenfunctions:\"\>"], "Output",
 CellChangeTimes->{3.8056616332345333`*^9, 3.8056892582074757`*^9, 
  3.8056901593335257`*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"679b4da0-8f97-4a70-96ef-ff3206242373"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV1Hk01lkYB3BbUU1ky0imrEVapvRG5DuNLUtvoWiRIltmQiIpwkSTLaaM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       "]], LineBox[CompressedData["
1:eJwV13k4FV8YB3AkJFlLKImEVChCkpeUKBTZKnsoqUilVLIkSbayJFEqIrJk
L2UkSz9LLnezExF1753kzpSy/I6/7vN55jwz533P95w7o+jpb+vNx8PDY8PL
w7P4e8B7orNu0t6o9Qt1RMUkwojfVC5gSFYHlFWWKFTXuoP2k7SMMtm98PLn
wcv3awPgYDuzNFPWDtiNd7Ku1YaBo9fv9/dlvSDhbfYm99pEGNC8bRonexFk
pSqMJWuzIGvVoagY2Uiw16Bkfn9XAuFCZap3ZJPB/1/XbbvqOnA6+rT451Q2
2FsPeco6dsLyhXDn/euKIY6nzWL4Xg9stOFMfLxbDrv16OUjFcNw+fNOSOO+
AWaySM+Sjq+wulxikJcXA4Euw8TqwAmoHDFt6zCsh6NDygo6qiyoP5255iir
AZpDStxP3MSBUNktVni2GaoytFsCNKeAb6ZAfM3GFpC4Xbe55N4v0F1wrzxS
1AY/UwaepLyeBkuruoh91W1ww/lXTl7FNJx4pHBIr74N6qiVgm/eTEOi3uA3
OUYbtLgr9nd+mIZJ/+OyI3NtEJ9n+2a0cxoyhu2vB1i1Q6ThfNvtqWngrT+w
J47VDiGq8/ntGlxoi9T53KTeAYKu72e1n3LBQKyV796ODhA4sLVkNJsLeQ89
9I4bd4BqX5FiYh4XbhbFZ+H2HWDXk2I4VIzGd08EyoR3gEtit4lDLRq/OXP1
aWYHzCWLLM/t5cKeyYgSgT0UWOZv9LZDnIBgjc8tfvsp4P3KQ056JQElF2TH
KJYUSCwRVj26moB188WyjxwpcDZiyJQuT8CM5ECE5lkKqLAPhuSoo/GGevZO
aRRwVcq9kWNKgELij5mXHArMXhy0XX+BgFqP0Jel0xTQn6kJbblEgKu21NGa
PxR4J8F8c/4KARkMg+o2vk7oUraxqwohQEY+JgiX7oS5uztlFKIJkMxXm9aB
Tlhp4BDrnkHA0gZvFpbQCQ8JsjavnoDslJlHn5I7gZb5aHy6gYC9J+MOdj7s
hISKTHHDZgIihCvyR553wocHwac/thIwf5jfd2l1J2xnjWwpohHwZ+DZ2IHh
Tqju88ubHiPgx++hQbpWFzTtj/A3FCCh8mRC/QHdLvhZZ3/isBAJYUyjF9iu
LvBpLPrkLkyCdFXm2ZdmXVBDyxgPEiVhT9Dx2evOXbBkRt/nijQJ6VyGrHJ0
F5QNUbdQNpLg7RU1lxbXBe5pZpIFqiRo0XZ8WZHUBUXqml4Rm0hoKkvO+53Z
BX/WbLdU2UrCVKCtXmtZF2RbdCqb6pBgPtVuFzjUBYWHf1RTTEiQ8gjR//a1
C2Yi7U0DTUkYpGxZ6/y9Cxxevtkhvo+EiyV3R/cRXeAv6m1jYk7CE3+LQNnl
VGgflne5Yk0CyW5IqNOlwivXV/E7j5HwweXihR2GVJA/lnf16XESYts3OOab
UOHqQGXLUhcSlAoj1iVbUiFxYWPqRzcSrM4YF570pMJujgpNypuE7O81LaLx
VLA96v9ewJ+Ecw8ObTidRIWzbhuOaAaQoLd39FpjGhVUfLb72Z0noSVTeOv1
51TwzShQTL6A6j18NGGymgrPN2k9n7xMwts51re9tVRYNTZgRl4hITI/zDjr
IxWExe/4LQSTIMOfN+XwmQpnjLX1BK+TYFRFHmkYpQLhEERlhZIg5BXzSmGS
Cp3LC64OhJHQJb5u6TUOFRzOPXvaEo7W4/S+ym0zVCjQNjuXfhPVK58s80SU
Bp5Lr82L3Sah5+a2geCdNAimbR2wjSPhmVbjDroRDfINLwQsjyfhzIBTvNZe
Gmw7cy68DplHLwy+WdOgZWHV2vWJJKh8//zUzgv5md62ivsk/Ez1/FvsSwN1
+R3FNkmoPlPSdrk/DTqtpfO/I1tlyvPXB9NgRmujtGQKWr/DZ3w0E2iQ8Xe2
QfcBqm9uoTYmmQbiPhmqVciC+Umrxx/SoCMgQEAnDeVtSc2njGwaeO3y1d/w
kASvEmvFPy9p0NVw6m4KsobLSPCRYho0htke409H6125bLPwWxoUqWb5MZFj
TmTe9MZQvYajhbsekWAnvq2/roEGV5if/TKQJ3yd4i530ODynxPHjmSQUCrN
Guui0aBHaCrmJfK1j6FGGr002F3O1p1FFpXPxb9+pcE4wcf7IJMEY4ebA6OT
NIhp2eDWixyY4NY6wqHBAXt6odxjEhi8MrnDf2jwTu3T2vvIQru4yUNzNLAw
nzH8D9ngIiVikI8Oua3pVnPIj8ejXftF6NC2U8rY+QkJFAVvyz4JOmQdHFC8
jcx31MSgV5oO7mLz00XIOvfl1XrW0OGVYkAlFdmndWZV93o6qN/R8CWQ0/gZ
S5gb6RBfqSOyMgvlc3fpFF2dDmmRN55oIs8GxQ/RNOmwUl9ogzmyRsnpdqoO
HXpCP6e6ILtPmtV07aRDx8XPf/2R7ytteNlpRIeJh0sPhSI3HF9IpZjSQa3/
fNJdZDK5L7LDnA6P70t8SkZW+1wV+NmKDqdvjLLSkY8JJru329LhTcs472Pk
WOMA6zZHOnwSWSO46NpgS8NWZzqMmIbNLo7/Waqm3uJBB68e6ZHF+ymx+GX+
86FDRdZQ1eLz7DZ+WfrJjw6HmH0hi/OJcn0/3RSA7q+8QicAufrBwy+Nl+hw
O/1S72I93ymXOhqu0sGtfPX5xXrXCtu+/xhKh5+O5O/FfliZahTUR9LhL22l
/2K/blwXfvjhDh0sxoIYi/0sqRiPqotHz3+1XoOGPMKpv4gl0UHxjXRQMfJK
tSeetWl0uMHnWrS4XmYe1w6/z6RD4/d/jMX1vJLuaPTuGbr/bhLXQO4XEZd7
+4oOvidlpxfzIGrGEnzzmg6Mb4cGFvNiHPqJqKqkQ5LqfJUTcvZUWGdFHcpD
8xejPpQ3hroLVt5IB2sltR+LeRTy2llY1kIHvm1C0TbIZxhT0a9pdDBj1yTV
oPw+FvscVNJDB4Ox53xnkCnm+V7Fg3T4vdHaUxZZp8bTuHCCDj7Z0tzTaH/M
PqH+zpulw4uKFs/Jxf3WUzyWy8uAUI1VR8OR3SVjqS8EGHDsT5SxNHJD5N7i
bHEGKA/Ljeqi/RvrW+GTpcwA766yK0dSUf+NC6OXqzNg2HmKbEbnwX6ZnPwg
TQZ8ONHfr4/M15zMsTRgwJ5U6WGxZBKClS8GzRxigI/3+6b791C9//zSvOwZ
EJfHf+s7Oo90qCfedhxjwJcXWIER8s/wI/M53gzQ6Jrf3o/OL5+h7VG21xjQ
3PlxM+suml+let77MAbI9jdpqSIrxSu1qEUx4PdltSeuMSQMGEqKLiQy4H7+
7er6aJSv9KmUghcMkPvi+MXtFgkm9iU5/F0MaNXWUOeEoH5uyWv2ZzIgeI0N
HUfn9eySrMnefgbYfFnFYl9D+StN2Pr6GwOIjk0uQ+h81xD3r3CZY0Dyw7W2
Dy6h/LVubaxUY8IvkdVFx8+QcPXZxm+KGkzYJklXVfYjgRksvyxOmwnX5IXF
J33R/lNbYXXCiAmPg55tOXWShGVRLJqYHRMqbLZk7PJE+8+44OupUCYwdSNu
6jmS8C77x6PLkUyQT9qZO2RPQoTQliNRd5jwUEawNNIO5Y3y6sPzJCYEheeE
NNqg892t6PFgLhMUllr/UrQkwSHktZMdhQlX53JDzIxJqHhT1QaK3ZC4oz0F
VNB85f/ctFbpBnkpCu8tZZTXcP1dLpu7oVbjw/FmJRLazN+8vLqjG6ox7949
CiR8Zb6NqrDohqzglGWrZNB+Id8bbw7shpOcgZMqy9D/w/aGcumP3RDc3z47
P0GAj876rHufuoFD+3esYpwAJ93rd0U+d4N/4H61U18J2GWg48nX0w1NrCqJ
j0ME8O3JFuNwumEgNkvdmkFAgk3k6Ua5HvhzP7b1DXq/yg/Yu/5iYA9kLizN
mkxD72uBWcvxyz1Qrj33QiOVgLiLs6RvSA9o3dFQD0giIOBKebtbdA/0FS3L
nYgjQC9M+drBxz2QHWV+uziCgIYEfoZSSw+snZg1T/EjYKio4W6nYi/YjNer
NhgQQGHzs7ar9gL73c1TeXoE1G3ZZ5m8pRfMplvt7ugQkJXfKOKo1wv9Lye2
mWgQ4PmiKa7fshf+ZG8WuaNIwHjmp4Rvl3vhb+nh18GCBLBj25Lm2nvh9TIF
lxEKF/6dpj3adLUPUt5VjeJHuWCn63JPI7QPynnfV5s5cOEV73iUdmQf3Dj+
tCndlguuab/P747vA8NdyxIMDnLhQ6Ocuc2zPjDyuTLsZMiF2+s9uFda+sCi
TfWP+DouSDHYlp/k+uFbkerTwKFp2GwiOO9T0w+00nf75I5Nw/5niidfrx4E
a26Cx4pVv+CyvJvSF+chkAjXW5NW8xO2sOyXM62GYTeb6S57hwNSYj+FGv4O
g1ProX9WEj+AH3tUvCHjCzxc9eEGPfUb+OnU9Cw7OAL/PYoc3PNgFAosPLNq
yRHIvnJkBJ8aBOKHnPh46iiMHYpx0ED7qOLI/iXJe7/C1rh/xess2iDU/NaT
8vGv0Fq4db+MQBUoDhzofn5rDBT4avx2r8vGDPQik2W3j4NWt5qCIbsJc17X
McNLHQcTyTbXc5VUjGiJGwkI/walAbbpJ4L6sTR+14u2yhOQuXvFVUWtEUxq
sOIZX8MEFEJYU8bkGLY0JNxu5/lJyFE1EFhfO4nxvHQtHpH8DkmDhY8uSLOx
wPTiOMn67zDhtCmlSfcn9n5ztJDEuR8wPbPdOeX1FCZxIHBLhCgL+s1ONkv9
+IVlfRBbbiDBguwVKseFf/7CtHYWTk5JsaBKRWJ8jvsLs1abeOEhy4Iad+PB
vvlfWIyAq6KJMgsmyr+bXJCcxvg/WkjzGLAg/sp+VbGd0xi5S5HnhjcLdmtU
C5M3p7H+rRRq8DsWbH6s3+cgzsWe/JAIWYKxwGZH/SGjlVzM8+URlbgP6Pqm
k6SSDBebVGZeyWpigVwjgzmqwMXINYPyzRQWdKze0m+qycUkhFknV46xIO/9
dOB1Ky5mNi44W7SCDX/XdWu23eZiJY9B+asrG0KwYtZ/01xs+uq0oIcHG7S+
ag5MklxM1zH3x8AJNlQl2swJ/OViNWJiZcxTbCibaG/R5yGwprBBk9ZANmSm
iCZcFSGwPs8Qt9IoNmgri3oEKROYgGpNelgRG/YYsj0sbQnMYon/jbkSNuQ0
F9yQsCew2CElz6tlbNC9d6qW6khgEmkxmy5Ws+GFpGfOIRcCW7vsWPXJejbw
NIgKbjxFYNt//KFbM9iwTs/z074QAnMp1pWQn2fDidOMDuccAqs89keUwsMB
TF9waCaXwEQF3orcXMIBX6sDEUn5BFbnvFtoUogDpaonbr4rJjAl4b0L5VIc
8FwI8xp7Q2DjXjZsy00csDsFFvfbCeyc3Jn/rttxwIQxhNv/QvU2bm3WdORA
lqNsXSSXwBTO4w0jRzngom0lU0ISGKU5sM7cjQMi8fvcZv+i+V4Krlp5mgNv
kviM/JaQ2O+OqJxXoRxYse8/7lMpEgu79TS8P58DjvEWq85vI7EVlwUPeBRy
4My7oWBJbRJLP3VWcryYAyf8nlJKdEis7ODO53g5B3QrPx75qkdi4xKdDXwY
qve8Z76KEYkdfMwjtInKgYIIF1+ZAyTWneBDKaRzwFhliBF9kMS8wtvStndz
ILpBQ5u0JLEbXmmbDAc4kHvIv6r5EImVqGsdPPSNA0d7xCf32ZOYdJVb/KV/
HLjgK9lc5EZiz/MaHf7OcSA+nyLMcScxrfTNCqE8OICXn4G6J4lZhPwujl6K
w9PiaOeHXiR23TSh85EYDre9anJtfUlspKN2Zf0GHAQ8NutuCyQx/w/KA2Yq
OIw2GijDBRKbLY3JaVXDAY99+s/iIomtSnXQpW/FIZI54u0QRGLmzhzHCT0c
bu47qHzgKokVTsg/ErXEweRPh3pmOIlFZ95yH7TGwXCpgGhSBKrXlr2xyAaH
/U1Oq27dJLG1796VWDni0CxdnOByi8RiEo43xXriMDxUqzEcTWI+ez/edfbG
4W7vJY2qOyS2Z0bdZsspHDZtELeJiSGxGc+/fa1ncfge6jqvHEtip3QfTgkH
42BbmEpsTiCxvT94qnqv4VDw9oHQV2SFrFPX82/g8FXq7O60RBJjLNMXPBCJ
g/YHWRHiHontG2CsvZOAg9xnU4OwZBJbf99oxOk+DmouBU6yKagfZi9y1VJw
eJ7Dl1aEXF5yafundBz+lcsFt6eSmFLkSnPBFzg46FvX96eR2Lz+9RXMPByK
nWLHHB6SWA97tOtFAQ4Bsjyb2pETHctczF7jELFCX7woncTOiKzZIF2OQ0Yp
vUzmEervh4iJsUocKvqOXw5FXlC3vXDrHQ47WH0uJhkk1jv0Rt8ew2EhpTws
A7kyWXFeuR6HFHPtj9PI5+Z/Rjc046Ce8e1FaiaJHShzsk5uQet1mNd8BHnj
qTopr3YcXHXuCKk/JrH+zoTHS6g4zPOUfStEro76fYJKR9etjQS+Iyfvctv0
vBuHkGThvUpPSCzgZxMnsA+HdZqiTx2QD+ZolO8ZRPNTNpZH7/OYyrHUYMkv
OLA2pFWXIfOJzRuNjOKQGS16oR958KM3f+k4DgMOGZa8WST29kr7f+GTOFza
vWufEnLq1h0JNiwcfFPGnAH5/EiGnSKOA9cjNckJ2fIBv9zUFA6xhy0mzyKr
WZ4ZquPiMFL91wV932D8vLTsxN8ozxm5U7HIwxW7Trv/xaE6zyo7Ffnd6eea
WnM4NG3/cSkD+YHCcmJhAYeiXaE+6PsK+x+iNDD4
       "]], LineBox[CompressedData["
1:eJwVmXk8VO8Xx5WKUpRU1ha0ifhSSeKTErJEIUshUhQiVFpkiZJsISGilLRI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       "]], LineBox[CompressedData["
1:eJwVmHk8VO8Xx0sqJCVaSKVSKcK3pLQ4QvZs2bNkqSQhS0JCSbayhChbSMiW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       "]], 
      LineBox[CompressedData["
1:eJwVWHk8lN8XLqmkQpIWFCqhkmRL5VEkhVIpkT1p0/KVFpVESJa0ULK1ociW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       "]], LineBox[CompressedData["
1:eJwVWHk8VO8Xtkak7NlKlELIt4WUnLJkFxUpZcuSyi4lyRIqS7JU9iyRlMie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       "]], LineBox[CompressedData["
1:eJwVWnk4VV8XJorKnAZRUvgJSSgSlikkCpEhQwkpokRRQjKTKUSZGgiRzCls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       "]], LineBox[CompressedData["
1:eJwdmHk8lN/bx4kiiSwJaUO+EqVoUXEpQiISkVDZSvYl2beQZEuIrElI9j3i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       "]]},
     Annotation[#, "Charting`Private`Tag$11355#1"]& ]}, {}},
  AspectRatio->NCache[
    Rational[1, 3], 0.3333333333333333],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->Large,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1}, {-1.4142135623730883`, 1.414213562373094}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8056616332345333`*^9, 3.8056892582074757`*^9, 
  3.80569016002456*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"9d30826f-51ec-40a2-9044-ab53f449c482"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Continuous-time integrated random walk", "Subsection",
 CellChangeTimes->{{3.805690778331122*^9, 
  3.8056907839714413`*^9}},ExpressionUUID->"d79f531c-1f27-4671-a941-\
bc1ea125e65a"],

Cell["\<\
The integrated random walk is less straightforward, but we can apply the same \
techniques to obtain the eigenfunctions in closed form, and we can obtain a \
univariate trigonometric expression whose roots give us the eigenvalues.\
\>", "Text",ExpressionUUID->"84b2ece9-c3c5-459e-9c9d-768ea5854c40"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"eqn", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Omega]", "^", 
       RowBox[{"-", "4"}]}], ")"}], 
     RowBox[{"w", "[", "t", "]"}]}], "==", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"w", "[", "t4", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t1", ",", "0", ",", "t"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t2", ",", "0", ",", "t1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t3", ",", "t2", ",", "T"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t4", ",", "t3", ",", "T"}], "}"}]}], "]"}]}]}], ";", 
  RowBox[{"(*", 
   RowBox[{
   "Eigenproblem", " ", "for", " ", "covariance", " ", "functional", " ", 
    "of", " ", "integrated", " ", "random", " ", "walk"}], "*)"}], "\n", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"eigfun", ",", "eigvaleqn"}], "}"}], "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"T", ">", "0"}], "&&", 
      RowBox[{"\[Phi]", ">", "0"}], "&&", 
      RowBox[{
       RowBox[{"Exp", "[", "\[Phi]", "]"}], ">", "0"}], "&&", 
      RowBox[{
       RowBox[{"Tanh", "[", "\[Phi]", "]"}], ">", "0"}]}], ",", 
     RowBox[{"ReduceIntegralEquation", "[", 
      RowBox[{
       RowBox[{"eqn", "/.", 
        RowBox[{"{", 
         RowBox[{"\[Omega]", "\[Rule]", 
          RowBox[{"\[Phi]", "/", "T"}]}], "}"}]}], ",", 
       RowBox[{"w", "[", "t", "]"}], ",", "t"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eigvaleqn", "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Exp", "[", "\[Phi]", "]"}], ">", "0"}], ",", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ExpToTrig", "[", "eigvaleqn", "]"}], "]"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"eigfun", "=", 
   RowBox[{"eigfun", "/.", 
    RowBox[{"{", 
     RowBox[{"\[Phi]", "\[Rule]", 
      RowBox[{"\[Omega]", " ", "T"}]}], "}"}]}]}], ";"}], "\n", 
 RowBox[{"<|", 
  RowBox[{
   RowBox[{
    RowBox[{"eigenvalues", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"eigvaleqn", "&&", 
       RowBox[{"\[Lambda]", "==", 
        RowBox[{"\[Omega]", "^", 
         RowBox[{"-", "4"}]}]}]}], ")"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{"\[Phi]", "\[Rule]", 
      RowBox[{"\[Omega]", " ", "T"}]}], "}"}]}], ",", 
   RowBox[{"eigenfunctions", "\[Rule]", "eigfun"}]}], "|>"}], "\n", 
 RowBox[{
  RowBox[{"rules", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Sin", "[", "\[Phi]", "]"}], "\[Rule]", 
       RowBox[{"s", " ", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", "-", 
          RowBox[{
           RowBox[{"Cos", "[", "\[Phi]", "]"}], "^", "2"}]}], "]"}]}]}], ",", 
      
      RowBox[{
       RowBox[{"ExpToTrig", "[", 
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{"eigvaleqn", ",", 
           RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "]"}], 
         "\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "]"}], "//", 
       "FullSimplify"}]}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{"\[Phi]", "\[Rule]", 
      RowBox[{"\[Omega]", " ", "T"}]}], "}"}]}]}], ";", 
  RowBox[{"eigfunNorm", "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"s", "^", "2"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"eigfun", "^", "2"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "T"}], "}"}]}], "]"}], "//", 
      "FullSimplify"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"eigfunNorm", "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"\[Omega]", " ", "T"}], "]"}], ">", "1"}], "&&", 
      RowBox[{
       RowBox[{"Tanh", "[", 
        RowBox[{"\[Omega]", " ", "T"}], "]"}], ">", "0"}], "&&", 
      RowBox[{
       RowBox[{"s", "^", "2"}], "\[Equal]", "1"}]}], ",", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"TrigExpand", "[", "eigfunNorm", "]"}], "//.", "rules"}], 
      "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"eigfunNorm", "=", 
   RowBox[{"ForBothSigns", "[", "eigfunNorm", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"neigval", "=", 
   RowBox[{"NSolve", "[", 
    RowBox[{"eigvaleqn", ",", 
     RowBox[{"\[Phi]", "\[Element]", 
      RowBox[{"Interval", "[", 
       RowBox[{"{", 
        RowBox[{"0", ",", "25"}], "}"}], "]"}]}], ",", "Reals"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"\"\<First \>\"", "<>", 
  RowBox[{"ToString", "[", 
   RowBox[{"Length", "[", "neigval", "]"}], "]"}], "<>", 
  "\"\< eigenfunctions:\>\""}], "\n", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"eigfun", "/", 
      RowBox[{"Sqrt", "[", "eigfunNorm", "]"}]}], ")"}], "/.", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"T", "\[Rule]", "1"}], ",", 
        RowBox[{"\[Omega]", "\[Rule]", "\[Phi]"}], ",", 
        RowBox[{"s", "\[Rule]", 
         RowBox[{"Sign", "[", 
          RowBox[{"Sin", "[", "\[Phi]", "]"}], "]"}]}]}], "}"}], "/.", 
      "neigval"}], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", 
    RowBox[{"1", "/", "3"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.805661805396037*^9, 3.8056618056046143`*^9}, 
   3.8056876883209333`*^9, 3.805687952601961*^9, {3.805687986716124*^9, 
   3.805687988013824*^9}, 3.805688522322714*^9, {3.805688628644779*^9, 
   3.805688630380583*^9}, {3.805688753351282*^9, 3.8056887556594133`*^9}, {
   3.8056888123014107`*^9, 3.8056888137749853`*^9}, {3.8056889089487123`*^9, 
   3.805688912452649*^9}, {3.805688949028841*^9, 3.805689007816753*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"ad2719b7-b1ef-4a92-af3c-7ff696290ba3"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"eigenvalues", "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "+", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"T", " ", "\[Omega]"}], "]"}], " ", 
        RowBox[{"Cosh", "[", 
         RowBox[{"T", " ", "\[Omega]"}], "]"}]}]}], "\[Equal]", "0"}], "&&", 
     RowBox[{"\[Lambda]", "\[Equal]", 
      FractionBox["1", 
       SuperscriptBox["\[Omega]", "4"]]}]}]}], ",", 
   RowBox[{"eigenfunctions", "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", " ", "\[Omega]"}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "t"}], " ", "\[Omega]"}], "+", 
         RowBox[{"T", " ", "\[Omega]"}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"T", " ", "\[Omega]"}]], "-", "s"}], ")"}]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"T", " ", "\[Omega]"}]], " ", "s"}]}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", "T", " ", "\[Omega]"}]]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"T", " ", "\[Omega]"}]], " ", "s"}]}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", "T", " ", "\[Omega]"}]], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"T", " ", "\[Omega]"}]], " ", "s"}]}], ")"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"t", " ", "\[Omega]"}], "]"}]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"T", " ", "\[Omega]"}]], " ", "s"}]}]]}]}]}], 
  "\[RightAssociation]"}]], "Output",
 CellChangeTimes->{
  3.8056617530159187`*^9, 3.805661811726569*^9, 3.8056626412162533`*^9, 
   3.805663252219796*^9, {3.805687964887457*^9, 3.8056879729358*^9}, 
   3.8056889809483128`*^9, 3.8056893601823797`*^9, 3.8056902516810627`*^9},
 CellLabel->"Out[49]=",ExpressionUUID->"b663633e-e495-4f2c-8365-1ddd44726fd6"],

Cell[BoxData["\<\"First 8 eigenfunctions:\"\>"], "Output",
 CellChangeTimes->{
  3.8056617530159187`*^9, 3.805661811726569*^9, 3.8056626412162533`*^9, 
   3.805663252219796*^9, {3.805687964887457*^9, 3.8056879729358*^9}, 
   3.8056889809483128`*^9, 3.8056893601823797`*^9, 3.8056903044751177`*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"06f97131-5d75-4685-98f3-46cccf20d817"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVj3k81AkDh5Ha6dhxlIp1RI4Kk4Ra4VupWKLkiiS3Uom0m1hEpuQus4Oy
bsrVuMYdVqQUuSt3DI3zpwOR/N7eP57P83n+fKQdrpxy5uPh4Yn7yf9t4Mxt
qx0313EvlPBY9aJfi19XzGNQVA3PJ8QW2vcwdfYmxSUUiR4BWWTmm6FSosMR
lw28Lm8M8dHOWNbcCx3D5reF/4qaQVXkYnEvrVtHNlwig5SyQpvaGsWvph90
lg0cY+3lbdEfrXX93WeuzkRwZ7090x5dxT20pcVZHUunhaf3RZ0wcyu1Olpx
XqdeV6z0WYILEoucK8Spyzoq27Xzv0pdgLhao3fDSV4k8NllyaVdxG00iHI+
84MyHJRqIe+OKz3Dj+ymKagYam9+ZuaBi6zu0D0Hf4XHSScDG6Yn3I0V/8mc
E0T/7ju6EaLXMH5uUlJKbjMYSVtr5c78Cb59KQd5yK0wEMjWqk74C7eurIv+
wi+OkpnX6oTUDeQrFzzzN5DGJVvbwjv2PihauWVIF9gOmRaCti3NF32pYyZh
E7KIzBPeYSLvD7cm4cPhwztwVCI9fdw1AEKBpeeCyF3wf/5A8D+zm7jGTnV0
V1WGmoZShBUzEPHTvLoC0ypIFjlxO1Q0GAG+3quNt2rAtzm23qIiGMouzlsD
/PfBgj7Et/0MHeOxSrdTiP3YMOcZUJlwG1635DLZnw/Au5PhPSV1FycG7AuW
tQ/BNLy/pKz2Z8fX9b4UPwzaEfm5YPtQ6Jlf+riOVxecolJPibQwiHaGaI29
PwKTmB43Y/lIlE2c3/jptT6UDLdniTVG4p4Xw+/42z9AWXXp45hrFOYcRpc3
fzTAufKVghqzaGj2jnbObzaCyM5o2mnmPTzV+BLF7T2JQEqRwl1RBtb2CHws
XjHHLr17IYUeDAj03E/aXW2BdvqV8d5GBsidovLdNy0hu0oph/bXP+DjWxLJ
ELDC8x/ptM52Ji4P/tMCUxts+MJUlwqPB+nZeGdtuT3Ye/5k6o/EgzrOd56q
6gBbD9MFT80HcKru2paZ6wDWtEB5PfcBzuo+Oh2R6YhT3BAtt6MJ0OB/dkc9
zxlx/T667JVEJPmpitWtdsMhcav0AfMkGHi+i+2PdcOE9b7VlLwkSAY/GQxR
vAjJqRuOecrJEC81WRdpeQlXLmjI8fQl4/vdI1eN6twh7MR6nLE/FfeiSz5o
fvLEaasU1uyndEwytQTXZ14H0Wu2LlUsA11FJ0cdeb1x25bibKqbgRb6Xqvz
Z71R5HhFrISRgYNlL5q9ttwA1V2b7rsvE0yLiar7MT5oCHpvvcbvEap/9OkP
5vhBNVdojTglG4pPXUc20oLwktZg16ySDQu/TV9cXIJgV+Bd6W+VjW/95THU
pCBElAx6fMjOxm9q0nZnhG6BW5vXm2mUg3FGA3Vi8RYSu/4o2BOTixHfEGpH
Dx3ryUAbPUkWjuYnfIrovYu4C5a2SsdYqP2xO0BAIhSynUp2Qu4sqG7lyHyw
DYVO1lvH3qcsNGTT7lwbCUV5FpNdSsuHT3ZzlfVsGKZNp6oMW/Kxt+ngY3HR
SJg/jn3l9Wshkl9EeIiZ3oOcyQz3WVgxJGIEvplZMCEWoKfpmlKMs8rucveD
mRDMSw5bV1qMUb9mgR+FTCxRTGkmw8XIWUlZZSMYi9baUq+B/Wy4+inXajfH
wkclcOXbKBvbi1RNwk7Eo0Vg0ybawVKcUx6fl/0rAddbfkfc13L4jvnU8Gak
gEpjj76kVKBvKSSjsyYF6REq4d/FK6BgaNRa0ZOCtuMK722PVoDjcWiiVjAV
iq82eckxK3BiTfdkkV8qBhuJzMJ9lQg+m7V675k06P2XQW32qcLjUU1GsGwG
thQLDfDy1sDXSV9hmniMkmHd12+06nAg3l1deFMB6tz+/c1qqh7FuYL3T6ME
c/LaAnmXG0EPl3F4mFQJvsUcwd/kmnBanznC4P8PGqRdiemT1wgNze4zPFaP
18FqLc93vUFcgPmoV3EjpKInF7NmWuGk+6q87MkrTC4MDnSptOOZ0a4Db5Le
IH2isoka2YF04xu80ULtoEo8IjicTtgojr+zc+lE+AW2S7JsN8xfyPUfy+3G
/MEczvmAt5h/cbLyifZ7XFOtL9787B2cmK011RW9GHxSH9Ym3YPgnctduvQB
fHfrfLjTpxdUa9blhdwhKB76ZcWlsg99POqNTynD0EuVdi3YMoAtpmplzWEj
uC5xTuaDzSB4jH834lvhQGnKfP1boyGI3OzQYHmMYaPALKV+aQiRuRuyx9Zx
wV/zkLU94QO8eB1WnkeP46Ja5fu1hsNYa6ng5KUziZw/HJKr54cRPybPGZ+Y
wtykmOAYcwR1qiqtSwEzYJvqrWIc4SCx059iJjmLAH16UvEYB9V6PYm02VlI
9xu8S6OPol3Q2q+n5hM09wUzRFXHMLPj2KUdaZ9hI/lmkbdjDKZ/h64Z8v6C
uaaIYY/Aj6i5at+5zeEr4vhtr52S5eLulpaW/dpz2DjATuWr5yJHhskvKDKP
1X6BZr97joMjkU1X5lkAT5Yta1h4AiNTmSNOfQu4+oAVIVw3ATVntlDlq294
qhhCEXKfRLqOm+aR0kUIGVxVCqJOQW5GLsY2Zgl9yq0dN6qmwD7oLW4Z9B35
iZDl2E6D5Hq4ZNov4yxLQ0hiZRrHIW1dqPUDN+kpgX3ZM7B/c2HGfdcK8rgS
D6nHCRhyfb8bU0iE/Eu3GzAm4LnsVqW8gYTTqWm5JyYEEh1D/DYIkhCvqso3
siRg5KDP07SFRGjUmefhDgTUp9i/HFUgcV4j/tO6GwRqWrZJHDhGQiZ4k/4v
mQTCu/dZKwSTWNn/969vHxOwk42RXBNC4v30SHtmDoGYssVhThiJaMuis8cK
CFAHRy+mxpAgd53yolcRUEpU8JdII9HXFpW4qoPAnG5r2sY6EmW3Fxw7ugi4
W8Se/9xAgnHg3M60dwSaqPbKbS9JGGbQig8PEDgu9r0kso1EhXfzy8Dxn3/h
h5rWfiDBVFaPMpkisBAjEsXlkPAcTjCTJggU7p4wbeSS2HH80mDtVwIyEYz+
4FkS/Lyd6dELBKKE3VIdv5IYYh9ws1sikFwE18PfSFS5pe1W+UHgiL2IkvQy
iVip9XMkSeCy8OQsSZL4HzNaqFs=
       "]], LineBox[CompressedData["
1:eJwV1nc8V/8XB3Cr0iKkoiSFVJKQ+gpHSQhFpMisNCUikkoKIaKMJHuk7C2j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       "]], LineBox[CompressedData["
1:eJwV1nk8VN8bB3BLiyIhKbK0SJFQ2cryEUqRJCpKSomSIlEpKsK3JKkkQpES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       "]], LineBox[CompressedData["
1:eJwVl3k41N8Xx0lKFFnKToiQrb5KaTlCKBQhoexZsqskKZIsJUlIokSJZKdQ
ucg6doqyzRBmxjaYNevv8/tn5nk9z33u+55z3ufc+5Fx9rtwdRMbG5s79vP/
/7NXST21ZKuTm1IrOC5vU/m+WU/MHy+qCboKsWx3+og1/71JTS8T1YducF08
1L4VTUjsvX9L4Rz4fRhgG/kuhow7BkozRC3hmMj7AcOafWhvnOT7DWkbENH+
ck4v+iBaPevywknBHr5rvmE8ztFG05E/G5xSnMBhJPfIoKQusnZlfk8UdQXn
ZPOcqixD1KAn9uVHuhu00k4+hjFTpCF3opgm7Qlal4++cPG+gNI3OebJZ3uB
clLYjJX+RcQ1HpF1UcEXvrJtcdsbbIuqCb0dPyz9YdHf+2PoVgfkb+Z69nJK
AIjVaKht+eeERtSj9Z6I3oD3RE6TBi93lPRGpFbe7iYEryFNksc1dJbv4/Ga
9CAQsuWQ4Hjugz7Ptx+iSN8GgdsnXnw7HIi87e1Lo51C4LLTpo1a3htItpOi
tif7DlDOuzyaX72J4gsEFM0V7sF0fH1xoHgIOi357h3ZPQw8+U5LZRqHontN
aTvrLMNB5Zqv5btn95DmYZUnNin3ocDugKNf0X2Uuet81CPRSOirNXw2txaF
7nS8aLhYHQkmz801wDsGXXxI2CRn9xB8xRwGlSZj0XZ6QNjX9ChwFqqVe8uI
Q8E/k4JnpWOhNOt04Z22Z8gibuRzZW0spE7JJwZ/SkRq+gr0SKdHYKeX0p2a
+BxNlH0JkMx+DI0HHVvUfJOR+fPBa+cU4mGr+/ukPc4vkYqxXJ5Yczysqnee
yPVKQ1wc3sQp96dQzH1AVDnkFXKoWi9Blglgir/dtzUnA+1SSlC7lPIMujJK
8kwl3qL7XGX7YkWT4DFX6wVz2RykbPgsptQ/CcqE+qu0hnNQ70M/8lBzEqzx
BpoNpn5AezlU8tWCkqFo5xrVQCwPNa29U/vZmwJOiey+zic+oe3UlEPScS+B
OXbwzXh4Cao4cDPF6O9LqJ1pYSwtlSB7fwtmgHYaSIkf0jZ0K0VFc3xVDaQ0
GFE8uVJuVoYukGKOXzudDlkC7Lm3NCtQ6kiIXsX6awgIWJnff7gKnZKweTdq
9QYsvBS2f/lahaZttTi5Ct5AUM1OppduNZKave1SoJoJxmZ8JSYWX5Gf52F5
tuFMaHiWs/tbxHck4FqU+/5IFri9610J5KlDl2zeFi0svgPPTbZtEZubEGXI
kjtL7D0U91w6UXuhCUXZc1210HsPMUXbJj3eNqEyFz+xz0nvQXEl/b9/0Ix4
fU88vKOVA6yuwy4cES2oMeKP7Za7H+BvTgBRWbQNHfzEv0WC6yM85WY7nmrY
jXg27l82lCqC/Uf33u3S7kfy5vOkH4/L4X2+cqx15hi61XkUUmlV8Mea0u0t
S0bC5fyj7OwIeoI2yRrRKehy3IrlxG4EkjsG/H5yLaAs18m2JhUEj7kfC67v
XkAqu6qqHl9CoGKdOXT8vwWkG+SYvKsYwYuCxvNuXgvocLp1TpJ6LVj50les
BxeQk33OldzRWoj541d4sHQRRZ4Vf/mSXAtjT71G3NAiyjmc8PMRrRbea2Yu
P2tfRLO8IcY+3HVQwXSpbJ9aREHI9OjBw3WQHqlu3iu2hOL20IW+PamD7O3t
73jvL6HP43rtXcfrIetHs/LP01TUb3R/8YlhPUh5/liLM6ciRmHNbpML9aBr
ELv12BUq0rpz1KnFvR6q/Poigm5QUaWgOqM2sR5WTgtd98yioip9sT2lpHrg
C3E7eXCVir7lLFxPSvoBHpvVkqZzaGh4u9rLC29+wHjqxwXVEhpaDfSq2fnx
B1jKWla7fqWhEzDF9QT9gE9X+xw+ddFQzcBQxsPpH5AUbXE/i0lDiKu5OUin
AbIrXtVInaaj+msZ4jazDdAgxnFm4xcdlZG9vOwZDZB/NVhu8ygdvfPQ/urC
1gjtx2fKVifp6KHbgK2vUCMYvvzW00KnIyNn/rQHxxuhMsmKrV2IgbpsHooU
xjXCHNPYOMiMgWp/W3iUpTTCOXURw1JrBiq2lq2szGyE3yrK18bsGSjRCln/
KG8EQS2JzaI+DHTR/F/K7+FGUHPtfTUbw0DDRj67OFSbwHHi9z6pGgbqaD52
lUurCXYwFStiGhioxoC7YsepJnChnyVO4hjojf4HSxGrJrD/KyYePMBAzjpj
z1XvNkHFZb2ZZQoDkbSsBC51NEFX/be861JM9OeznPOVgSZ4MNO4vnkvE+EO
LZU4jzWBTceniBglJsr/76m5D70J2k3NV65qMpGvemtChGQzXBH0Wbh9hono
Cif4CnyaYVfYM2G2ACY6Oa7b/Ci4Ga7p5xF2BTFRVIZRmMeDZqhVMZ0Xu8NE
u4UsKXIvm+H5DuqXpUgmOszu1ZXW0AySuSWqv18w0b1v/tHBXc3g9yhXzz2d
iZpuBcHFwWY4J+PnNJnJRNbz94v4F7D1B51eFOYxUfBQ6tMY8Rb4HXpP/kY1
E9WmvDZ0U2gB35PipSE1TMR14d2G3oEWUL1owOtfz0QvW4r8NgxaoKAnVGwf
jomqK5rOBwW2gEVBL67xNxNtCmjfanm3BRar28R1h5norEovOhDTAnWGz7kK
8Ew0lDWiPpfRAmEfOTPOTTHR6lMan2trC1DTKrbVLjGRvvFy86mfLfBhbiyh
mM5EcVvYwqXxLZC6+13kUxYTSd7lWRiktcCTjpxXIutM5HaEP7dyowW2m1LL
6tlYqJC62zGFuxUosXOydhwsdPKabLf5nlYwDG+jXORioSh5xRj1/a0QsmCi
V83NQp0EVZ0dh1vh6tMvv3l2sJC99dHiFuNWYISaVNzmZ6EwfbMEuNUKRHxC
QZgoC7VsWBlJRrTCeD8z2lKchXZ+tWNbiWsFN8v994QlWSjzgLv/56xW4Nt6
+pP7HhYizXorJhW0wrbnYUM0GRbSyA0kBFS2QpmV+i5/ORaqlbpnptrZCrp5
ji80FFiIa/ABF8+fVhiQbh24uY+FzJJja0l/WyEj7YZAniILpZo9DW6ab4WP
TpF6OCUWGuNJ1nj3rxUEhFTc/yizkHJzGun+Zhw05Jbc7t/PQoERmZkOfDiw
8PO5VafCQtUnci6dEMPBl524y2mqLLTpX/5OcXkcbEvQV3BSYyHxDl0qqOPg
HAEcuNVZSPPtn1+uR3HwpPAQLhtjk5v+lbF6OFgZuemqqsFCV89sfVVoioN5
Pfv9HzC+J/n6bp81Dvbn2krwH2ChlEVNR5YTDuQaJzS9MC5qbNOV9MaBrlFk
YAXGLS+d5XWDcLCzt7OXgvGYz7+t7uE48GS4W4gdZKHlUwnTjx/hIO04+5Im
xoK793UUJ+HgrrTtJ8BYZfp70a/XGO/QCdfG+HSNZeJyLg5yPeK95DG2T5y5
IV2Gg7woNW82jIPcIqz1v+Ogplg4vA3Te6otqu3ZjINUufPvozDO5S2WiO/B
gQkf6c8BjGvHDTZKh3Cw5wWHRAcW35/PI2MDkzi43NPteQnjpUc3GlYpOBBu
jqvrw/LD48DzQWYZB6TrETKA8d7/smINNrfBu0bumDQsvye2HvX24m2DTelx
1Eks/xeHus4liLTBiZZQZxmM/YrcDlTItkHJdvs+E6xeMQ/WBAdV2sBNok7f
A6tn1f79f+ROtQG/WLKcH1b/3o26r0bGbbAg4RNvi/ljuu/Sax+rNvgmmEw7
hPlHIjTK5YtnG4D+8cJve1nokJmkwfD1NlhnT9xwx/x3bm+5Ivu9NjConjDk
kMX83j42dzaxDUJONVdtk8b8lhnc7ZfeBpWz6WM3MH8X3+ArS8ppA58zK6td
mP/HJU4Ej1a3wW5cEM9FERZaWeiz5Whsg8Nbz6yF72YhocZrJxS72kBKgZfw
SoiFDHxSNwX+bYMm7htBb3eyUN53ahzn9nawb24fmtnKQvXPHvkp726HfYrU
MymcLDR4VebC+T3tUKd6J0cD6+ftvOeFX2q2gzXZV/kQ1v/+9h/fqlxpB70Q
OYe7VCaKPXgq0ty9HVJsNE99WGCirC2/3YIC2sFoe5xA3RwT9RVyqtQ+bAfG
ttjIBiI2PzccP1sUtoNb+I4y7iEmMjGtjThd2Q5ERoVg4wATubySPq9V3w47
srdy+f9kogStUaJYfztInvtQ+KKDich+dqLja+1gJZDNo4aYKJ1gFepv2gGK
pX6zt94wUalahZGzdQcMrbBWjr1iopZQoV2WTh3A0JguXkjB5r9IX4HWzQ5I
DlLlV4lnonPmZvj19A4Yl979Zxqb9+z1Z3WfzHaAlMZdqUeWTCSy8yNvGKMD
yi8aWtucZyI1+21D/myd8Kap1UL0LBPZLjdftxTqhIBf8NYLmKj84On34sc7
gfo3s8cGu4/csoHr4+NOcJjS7bRfZqD2SM3OJuUuwOftnZV+xkDafG2bnh3q
AlsRI9fAWAbKfemkZafTBVd3HHMsu89ADwrjMylWXbB9jw6TLRBb/5sUKHK/
C8Qpx9TbzLH1+zOErw10gflQr8ceXgbSJUcUb9HthuPagd6M23R0W60T52XY
DctfY6T2+tNR8XXRyW6TbthGVuA/5UZHUutFoq+su2G1rLnP6AId/RMYiVD3
6QZzSn5SghK2/riW1aXUbnhqs+Sx9RcNSSfM/Mub74bDIRy5LdLYe8UpLK+U
2g3G5H8fKoVoyP4/QZuvrG5wZCfNpW2jofR+7cr2TT1gSL3ucZhKRSKSj4Io
u3vAs0J7orWRigQ+KlI1oQf2it4I8fSgIs6Gq7PoaQ+8kaOH1WUvoRkmfvSX
Ri/EDb/7+pG2gD67P60/e7gX5EuUKUcmF1D4wMkcdKwXRheb71f9WkC7v2T4
5Bn0Qpbkfsazz/9/b9qthl7uhWMBaXfe3lpAabR+0b0xvbC/M8cgbp6CjBY7
LAPxvUDIxidwDM6hd9NfcbzxfSAvxL+acI2MeCU/UCYmfkIsoyEjvACP4jwr
3DL39sPHO9vObSa1IIZO/oRH2ABIO9Kts2rq4MbBhvLdP34Di0j2tNUbBnxh
w+MemUH46pHs5P6TCN1zm2cP7huEaBeeZGkWEXtnnDZJUhkEvbrmxnpxEmR+
bNxurTUITVNTH1qdSeCc0/Rk2GQQtm25qtFPIcFURstT4q1BEP30Ja2bcxrm
4tqfr3UMQhJdeTp8zyyMtm2n2fcNAo/tBXfHU7PQyW1qWft7ENIO9Bvvc56F
wpgOoQd/B4G+bDtyLXsW/CM7k7n+DcJd2rd9TXvngHan+4Xg3iFIajPCVcjO
w8q1n6+UQobgs92fDEfOBbA8fOWZWtgQCLdxmakLLsAn9qmo/yKHYLrj8t/F
PQtgn8oMOBE/BAUafg8vHF+AukYxI/OsISjiEH8bHrgA0XucaMG4ISDj9mVH
Dy+AYP+cSYvYMFSJr4ut5yyC99sg3Q7pYYj8XXL8cNkiNHhvaPXuHYZl2Y2d
TmgRgjj45YbVhmHwrEBh/MAi/NHQ/EfRHQZJF3qD0dYlePM45L2w1zD0RAmM
aLguwf5TW9fdvg5D1Mv1iBRBKhR/zN/3u3YYiEqqMgwpKmgKmZmfaRoG63LC
pL4yFY4TU9/t7xkGu5s234p0qHDuibLxwtQwnMLbPq/ypkLgH9PU2wIjMKF0
rSW5jgoM3aW6aeERiF1sufa3jQp3PqXM2EmOgMWyd6Z0PxUiw/AnTyqOgBx3
XZbLNBVS5AMmN50cAUGzZ4KiAjSoCkg6GOc5Amdjq60P2tPg5NCRy2u+I5D5
RujYVXca1OuPPPS9MQLBE89Vo/xpgBNW+GMWNgIL07tlEiNoMPz9S9iu5BEo
rVD16XlPAzbuofbXtSPgW3RQnkiigWGWjHuJ8Cj4XnEoO+lEB81UXoUmiVEI
67TmLnGnw574lYlBmVEwsythE/Slw/LtX86bVUahKmWo8n0IHQrMY+2tdUbh
2vTOAc7ndBBkX7Ra8xgF9UeKtE+1dGBjjggJ+I4C9+KYsnATHWZncX0K10dh
dYPx1b+NDk2/35mb3R0Fllj+yOIvOtwuvmSa/WwUZHpPVeyfpgPeoVb/TPUo
LEjxPg3hY0C7VQGHPRqFDy++l/0WZEClcVp9YMMoHLF3X5YXYUCi1g2d9M5R
WAw0G3uyhwGn+RSPU8ZHQUSovy5RgwEHOXetcJBGoTDHLstTkwFSK+zVInOj
EE0IeqJ+hAGsqSEtXeYoaL8oDo4BBuTXPP0vmQcPBw79tPU1ZUBqeehS3k48
hC6eN/xuxoDIj54lNbvwcBl/SHnFggH2KXrqJGk8VIfswenZMoDfl6l8TBMP
wbYeh7jcGLDuMkE+fxQPjdm9Lzo9GDBt05PrehIPrxmV+AdeDGg4na8Qb4SH
nszbIl/9GXBL0kF27DIelFvlVu1CGOBspnFx2AkPuDsmOvGhDDj3gP3RgBse
tGzEthbfY4ACOXuxwx8PZVPiwvURDBCQuCnfehPbfyb3SmkkA9bOGdg0hOBB
p/mJTGIUA36Wk2qrI/GwKzJFYs8jBtQSq2gVsXhQuXzDvPMxFr/YY8WSeDzk
L0tueD1hQES4asKHVDyY3OmovZnAAN+y9R9ZGXgYFprvHXvGAJupLmZGFh4u
TPLZnnjOAA2TQIekT5heHX9DfTIDJML0nj8tweK393k/m8KAraVCzY8+4+Ht
pToWZyoDliYmlx9+xcO3Os/vvC8ZMCr8Re1+LR6y2jqXtqQxAHc2xjm0EQ/8
za6p8xhX3LVJuYXDQ+TeTwWNrxiQWayMC+zCQ86NAwfj0hkQ93dlzecnHjo8
nsjrZjAgeHfHAc8/eHDuc40mYuxy5vVV11E86OV6WIe+xvIZ6vfS4S8eRNes
ktneMEC7SKfDloTFv42hcwNjhXF+9otzeNirKGU7gDH/rr+a5kt4MPtVRFDK
ZMCqYbmHCRMPf4pTf3phTAp5mG64igenu72HMjCevrjf4y0bAb7scdlcg7Hj
guAmaQ4CzGZf1unEuD929VU6JwFc/xshd2BsLDd5SIyLAENSfOzfMa791tH1
gpsA3n8Uo15hfPjiZ89dOwgQ+c/7tifGnyivOZ7zEaD9iPKQAsaysdEZOwUI
IHrja34fdt5UWX+teCECnMiPnvHDmPfbpR4eYQKMs216tYLFH2l1yitWlABm
1XnVQRj/m1fi3CpBAA3gNh7D8uUbI/AmUooAxqJfTY5hPCGzcmSTDAH20Rxq
I7F8d1u2e6/JE0Cb3ZxtCquPwXz5ljuKBFDRkOlcw+r5LTojk6VMgAeX5nZy
Yvyh2vcnVZ0AY/Nb/o1hfpCwtPYNOEgAfuujmV8wvyTOARdFkwC9+QdqQ5MY
cG8P//HpowTYZf3D9xfmN1rVv1/uxwnwMzFrwwPz4zWLcb/JkwRQjuzbMRvP
AKuosmyCHqZ359iHWszPKrNWPAOmBOw9BLRsrB8qLU3QIzMCxP86WBGD9Yve
d93rJy0IoHPaaJdtOANs49WH3l8iQITPma/1dxgQq7Et/4YLVj9hq5H8AAYI
vdywV3QjQHBfyi+6L+Y/dobAsAcBpGUeh6l4Y/v3jofo+RKgI2wn1QHr/6kb
384K3Mbqubf/Pd6GAYEjpeuNdwggHxcW/PQi1p+n80pv3yPAedMUQRVsnggJ
p4iNPSBA6vK7ov0m2Pmq/KaL4gnwSVp4SP8Eprcm+8j0HQFMioSFxsWx+NxE
T7J/IICSbPs2R2EGfOnkWyrPI4BjaDd7mwADOt+s2kgUEaBRNGKbxzZM71S/
0kwVAW5yqi/U0OlgGxXbGtNFAHfusF0TODpMzYfdPd5LAI7kWkPNRjoEWAcd
WPhJAMK5jKYARIcYRZeX1oMEeDRHrSkvo8Nn3HFPhUkCVPKqq9u9wu4DvgWu
hmUC7LnmO6OG3Se93x9Fn1kjgH45r2S7Ix0SveW3dG0QwHf3ioWNLR0EcLYc
g5vHYFvJn0k9U4wfNq5ReMdgn6S2ku1BOuxcSVsSlxsD7nnV3qf/aLCdeHr4
uvEYyJuEHzUMpUF7MsH2n+kYWA/xfaZcp0Gc/p0/98zGIDf2FSXGiwY8WcX9
sVZjMAEFZU9sacB9RbznjcMYBJ92PzKmRQOuvoXGtutjINovKf2ZQoXN6FWR
XPoYMJ0ucZ+xpMLgcX0j/OsxeJPWLH/sDBWKqmcJaW/HgJVyy1niJBVsP58Q
EPgwBmW6f90/7aNCSQH+BlvpGFDl1Ws5lpfAPl1Oe6R5DIrornWpr5ag8nZ+
Qwp1DDh3Ugc/9C6Cl+bXP9uMx0HK3M2HKLAAtd2/PlWajsNAtKGwzuYF2OWz
EOZuNg7646IFu2cogN7LKzRajYNlY1sCtYgCgsIJgeGO4/DjcOgPvyMU+PrP
lYd5cxyKmJ4fYvTngQfxnpjIHAdn+yPhzDOzkH/GObOGMQ7XffrNiHwkoM+I
7ZxK+QsnXN8+K2sdhQoLQ44k/QkQkJUdLt5ogDCjh2/KpyaAkeF7yeF7HZIZ
Ofs7++EkvAvNUOOyGkLaWpFJogenAN/hEuY3NoX6nUUPZ2hOQVvm37lUdiK6
Hl84sEdrCnotriQUyRDRp8nfYorHp6A/pILnnRMRSSWpvj1sMAURkjtFPhCI
aNNif4GF7RRoR7o+3xgkobaPSs1PIqaAd9/+k6a108ijv8aD/+EU6DbnLM+O
TKPNmyy5k6On4JxN5e+glWl00uaeaXrcFJByeV8ZHZ5BxVv7+j6mTEH+g/n3
Yx9nUJJrKKH54xT8LSAE/Ho6iy5Ldf1j75uCL5xKnHuN5hGvaGDF119TwFdA
5xO9Oo/qBHcF3Pw9BUMhqXyL9+eRwjY7EmlkCpSPKYWd+TqPKNSp/i7SFMiq
i8u8VKGgiNb1soz1KbCybZ7s2LyAcm+o+R5VJgJRP/PMsf4FZOvXo0RVIcI4
4+W5tvEFtOPajclP6kRI8j6vYkxZQIEO1Zf3HCKCiC3HKTGuRXTsrIHxVh0i
qA1sCqUdWUSd0vaKv6yIUCV9sjn+xSKi456M+98nwvKACXmb0RIa5vnlsfqA
CIYXhtM6zJdQvYkEJTqKCKorHqz7dksoofPjyuvH2HmQYvI33yWk3Nss1JFM
hL7fru7BSUvI/g+7odJHIpSaeMtxjCwhfbEzHeWfiGB+seh9x+QS2m+XYKFT
RITvmUnnY+aXEGtYytG6nAi8zwuXOzaWUCLh2O2HNURIN/XseylDRU3Em/lj
vURw0hodUXGmok+K3w/4/CLCymrKCYYnFT333FzJGiACW1q2cVEAFTnOJDbw
jRDBgZtitRBORcvzRSMniEQouWx8ueA1FakzyHxpK0T4oPpYcscAFe3WOpAi
v04EK9kksc4RKlq9FSxRwkYCgumq9b0JKsL926LUwkmCMiH2kE+LVOS6JqfL
wHxfqMeVe5KHhlI329+4sJcEoZ3txw4do6F1F+FDPQrYd5ZR1ThOh4Zcf3TT
zyuRYFMCr4CZAQ1pROjdMlUjgfd7Y5qiOQ21bCiGGB0hgVXb6AEhNxpScxjX
btYmwQm+pCh5LxpKqnm1cvoECRw6w44q+NOQ413eu3q6JDiGSt/Tb9MQc5ka
dtKEBFeu/eNpj6Ohy7YFOt/PkUDEIabJ+hkN1Ve5sR83x9aHj3zpTaah+OA/
EUcvkoA1Qtuf8pqGFBg1DzUdSVATzv77QhENXVyMfax8gwQ8ZaFWbzpo6JuZ
nkleEAnkD2RfluihIdni1e2Kt0lw03abZcxPGpr39YuXv0cCMZc7HKpDNPRw
1vLZnhgScIx/ZeQSaWjamPfCm0ckcHpzkT9jmobM8psFpJ6Q4F6g3FrYHA1J
XNNOEk8kQfjm7KMCVBoqJ0q/2J1OAsHtY2PuazQkZvjHOvk1Cfa/dJXp3aCh
8JxEEaG3mP4Yftf+TXRkcpUzjT+HBJd6bu3M20JHpQ01tgm5JMhZ3LGzk4uO
RPYGi/Plk4BWG/9ljJuOJsan07cXk8DLpnbxJy8dndV9d+VxKQn8o07fK99J
R8Vvr0hxV5DAUsU+J0KAjkIdu99srSbB6C+/79O76GgcxTpGfSNBydnUnEhh
OjKS1pPhRCR4IVEmvUOUjgRHK7I2NZBgjjf9M1mcjuK33737pYkEJvWlXTaS
dMR9TP+SdysJVE3drCuk6CjKk+c/mXYSfDzmdHZVmo42pfbu6O8kQc/klfdq
MnR0r+kl6VEPFo+/wlUTWTpapjn+gJ8kWOpMirKSo6MgOcXXtH4S7KtP3HJ2
Lx0tmVOC8/6QYO+Q6LiSPB35hn+2sB8mwd+Q/3bTMZ4uvKsmiCeBZh/rTb4C
HbmN6G9rGSOBDjEx1HQfHY3xbJ8InSCBaJx23iDGl7X7ag4QMT96HpGzUKSj
3x5pL6fImD5rgvgZY8sXTjdezZLgbUwujVOJjrobFc+bUUigdnTFQAdjExpF
iXOJBHs2XIevYtwi+2VzNQ3rr6y7pUEY65vfw/sySdBYO9sUiDEKO10tt0wC
xVZPYVuMtQu3J/9eJYEL27e3Khh/Hu7ze7JBgup71S7TmP5BnldndTeRQVvD
xO45xoVHneWZm8nw6Kd71D6MlT2U2D5tJUPeuuDfHCyenJSFQUduMqQKufvx
Yyzb+KVi1w4ybDkfreSO5SODei8Bx0eGzsqPfLlYvkRkDbzCBLD91IT3/MTy
m2S2w0BzFxlWr8jazGD5jyt4tZIhRoaN0uqTQ1i9uIad+y9IkmEFa9KyPXQU
ya1csnUPGRZdrpTfwup7x73SLUCeDIHsi4W1EnTESA47paBIhlyr8cHTmF8C
GwwkhpTJIDVxae9nzE/XZH716GuQgWv7TZ5Lu+lo6nz6p38HyTDVxP8hVoiO
nO+5RBceIoPVqszlHMyvNkOLx0WOkWEh8QjfW8zfRsm8uTOnyXDn71LkK046
avjxKyLTiAxBoQED8hx0pLOUfsXKmAzldzVPvmKjI63z+wWRGRlGBcQNDVew
+bDN6F6iHRlwJ8fgHYWGsrT4bAztyWD3/bFq9CwNSbn1/7fqiO1ncVTNikxD
u3+4kq+6kSG9T8GzdJyGOO/etzwaQAaV3zfbA7B5Ub44+w9dJwPBi+vCfDc2
H90uvTEIIoPBp4w3l7B503BefdriDhmOZ3YlMRppKFJ2JMz3IRniaGNM6880
pPnCSJ4eTYaL7c0duqU0NMFTjrvziAyx78b8xQtpSJ/+aFfsUzLUPFSSTXlP
Q5tbjuRnvyRDK/eEcclzTP/4OzPldDL892rxPfdTTL+Ej1H8mgyz8pa/zB9h
+mlTOjXZZAit2VKVF05DD3yS+n8XYPnW0qwK86ahTYIL7Lz1ZHDUtJtpxOZ7
abTdh6QGMkQNfzVY06Yh59UmE/FmzD8/fBJkD2HzdzLjhWI7GZaNUhmHlWgo
otJYVa+fDN03zxlG76QhdvsPl4KnsfMr/yU3D1ERW5590bjANDwW1+IYcsXu
v9kB3ze7psHlepmk4mUqitMwV7ssMg1VWWdcHC2oSLhSr+CX5DTkLk6FJ56i
IrVmxfwWxWkwzFe+vyZBRZcnl3IKT07DnzKdt0tdS6hKJvp1yLVpkNt+qzFU
YQndu8pmr+UzDcdbtn88Io7d13m3JWl+07BqIOlA4FtC3Rre6T43p+G6sYIF
lbWITTrzNMfwabAx1eRXxC2i3fbiKQYp08AluTmq12MRBaYVPRGon4ZveRPK
di8W0JfVtOj6hmlQXwk5PRq7gFbto+4HNk/D347NdedCF1C03JWbve3TMDB5
n8V0XEDpn7ivJA5MQ8HdD9reSguoseaqisDcNDxYUL/b6ENBIn/F2/hFZmCx
Pjc4LGYOfd8fw8XvOwPRc2Z8x6zI6PBP4Y5E/xmwtjv6bPg/MioO/fBM6PoM
PIluu+UkQEZZHU1iIsEzUFIpW76ri4Ri/DhVpSNmwKxeqELJkIQulEWYq6bM
gNERIUfeg0RE1L6bdqYG03P1NTxFnUD8ZwNVInhngeZD91HZR0DDqt19t7/N
gmxrjnw9Wz0qfg17J+zn4Mwl35yS6E64UnSYX3J9DorWFeNnHSYg/OHb+8Mf
5+HqFgPFcLdFKCBJvuI1ocBD5bsCwQYsiMl46Dh6jgK3Dt56bH6VBa4X5uQL
zSmw+NGrbX8kCyS+fSs2tabAlw2rmPE6Fjx6atcU50yBrWmOFpdO/AOPwy8X
uW9TgHvxooOj5jLIRgoZbc2hQJpWfkCt7CqsHwndMZBLgWQy8WfuqVX4M/e3
NyefAocnfa89c1yFBOuyKwYlFPAyp0i7vF6FDeUL1x9+o4CH3QEXLrE1GO55
+pqjjwJGFpz8l/jXoTKK6dL3iwJLydKXdDXWIemYg1L2bwroMnTyVc6vg/F7
tXLdUQoUzMX7sT9Zh+rgjtb7ZArgTo0Y53NtQIrqoafmsxT4lrXekbxvAwLG
0y1lKBQoP9F8IdxgAxRNvPG1NApQojOcrCI3YDP7z3cJTExP5sU0ZG8AoeLY
NcdlCtxh33lDuX4Dvl3LVtdYw/Zrr18TGtuAF9I89I0NCkT/fBi9sbEB/wOe
Q09D
       "]], LineBox[CompressedData["
1:eJwVl3k8VO8Xx5UWKZLU11JZk4REiOQQSlmyVrKEUJaSJVGEsmUJJST7WlFk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       "]], LineBox[CompressedData["
1:eJwVmXc81f8Xx42GVEIohERSSeprROoglYxKEUoKGZmRpNCwQ1R22SNkRiji
bSsj69rjXuNe417z3vuhEr/P7y+P54P7Pq/zOuc9ziVu4XzNio2FheUkOwvL
/39qW013Vs8YnlXktH3mW6heuemc0AOioDxYc3vln7D+V/VfUmx8saAmtLqc
17hrLIIm90m+fCx1GY74irzc/1QO6bT1FSUIGgDLvfQdz86cQZKhIhkbYiaw
x6fycFzbBbSmbRljLmUGpcLRleGWV9GsH6HePNocBAzTre5r3kBG91Yq3wne
A2njaKYgx21Uf06orC7eGtDQAWrhDQskJ3GmkCF2H3S5H399EWeN4tnuZh9M
sweVTekxwzr2iGPcJ/WGlBOceTVj9k7xASondbXVGTyA9FXNQtN1V/Tg6j1t
02gXqDo3evPf2iM0cjzw3GtBNxD4uC7tk+CFIpP2Vh+89Qg+pi+rW4q9QNq7
PqlWxbvDh3jn7g5OH1Q636qwIPYE1O7wmzqdCEAOZmZFgeZPQfJBxoPLDkHo
wK8F2f1pniD4SVjyZk0wCsvjldaXegaJ2yYzDL6Fo/Mi6ekzNs/BeEyo+fex
t+hZ43vuGoMXcKmvSm5X6Dskryjz2iT6JbjZD8yfdopCyfxXAoIF/UDYuPuY
048PyLMtpv5GuR90qxBFq7wT0A1/EpvELX/gs0vTkYcktIPp8rwiPgCaH3nX
ij9MQR6ESA+a2Cv4Wf3H8o55BroeOlL6tfoVpDelLQfZf0SymlJMP/Ng4NlG
6nzkmYkmi8tcRNJC4KG3f7JLbjbSjxi0uywVBo79Y1aD+vlIRkciW6gpDEZZ
Q8y2vipAHOwOUxSbcOBLa8a6LQrRnW/rn5HBGygbfLb2OvMz4j/8RtY4+i0I
8PT6DF/9gl5yFB96JRgJb36zXXslWo6OXHwbVPQgEmK+vlzhZZSjLn/nmaGm
SBCutqtyba1AkuwyObLuUbBD65zNB/9K1PgvXZbQFQ3kGdr+B6HVaAc9WkEs
NA60es+6DpjVo9iRp+dK1hNhfEZkQ2W2FanvM0kfNUyCHff5pbS82tDsTaXN
HHlJEH+Mh3hr1y8kSntimXcsGQQoWZHBp9qR833FgyzDyZBfbLbFqKUD8d4r
yMo4lQq61Z4hOdCNjE1SChaX0kGML7NN370fLQwZcKYKZYDrO6n8LU39KMCM
w+r6uQy4FfIO2PcOoGJLZ6HSyAx4xRx89at8AHE5nfH3VPoIUZB8N4R9CDX4
DNzc4p0JK9cFnEOTR9DJXJ4t+zg+gR9Lxg/BF2No+8ZL04uiBdBj1bl/atsU
ir1vZCZzoQB2ppl9T1GYQpIEmbs8TgVwyU35403zKXQ2u89yqLIA+ss1rjR8
nULfsqNLymQLYcXf+4GzzTSau077rvOrEHa6yNSm1c0gw6yYloc7i6Ce3Ht4
kxsNxd/20bUWLwKZE9l8oYk0NM7r2GasUAQpJ6zOsv2kIWdvjfYzt4vAL6vL
skxkDr26Nte1Na8IWjOHk5Qa51DlmsbgB91isKNpWkntXkAH9een60K+AKf5
lz+1rYtI6PlFFZuUL3A5Lv3pgfFFxJ2XHMJZ9gUMbsvOOa0soj8c12X1x7/A
1VtDb9vEl1BHddnD0VMl4Bgko/7+0RJ6KvdyfZVcAoLC6e4Kgsvo1y4+Plm1
Mti1N7Ar4zId1Z1xtOo0LAOVoZ4ucXM6+mrfWOpmXwajJhaJPg/pKK3Jw6Qi
ugx+6j/MWoqhI4/nI4lac2Wgrf2e7zmRjg4sfDxs+f4rmDbTCJL3GejxL2WI
ZXyD3rNiW4StmIhLtoT8k6McGq3bRZtdmSj9tVzo333l8PBmdvKtF0zUqXto
wOx8OTBOh547+IGJjrbwPTwYXQ7Cn2U7LrczEbFp4WORUgUUFI/oDJ7AkPsh
e71JnQrY/2VULfEMhnYEUuj8dyvgx4OuKxqXMKR8YUTtSVAF6PMfOnnkLoYi
6psHYaACRDIfGj0KxdDFmgyutqffIZHo/354FEOj+8VL1sO+Q7zl4y/vpjHk
9iL+llzad4i0GyFLLWMoBSKyIlq+A98jMcGZTSvob+ULjZv7KoHL7UVcp/QK
eieyNh0iVwmL9suaj06sIGnvx+GVmpVwvFlYElNeQYaqTsP7HSthXjyVJ1x7
BRWU33KfqqyEVR27JiG7FXRBqG+fYFclKMwZyGS4rKDhJ9fqtCmVECOsytz+
ZAVtU77Enc9VBdYlYvpOgSvIskzxk9udKlhb7o3yTV1BfwSKrn58WAXe17Z7
z2etoDfux1b6Aqvg6NaKHQoFK6hSQVLzdGEVtCb0tRlUrKA9X3hGWVkR6Pz4
7TPcuYJMQ/8aTAogcBKUzHvbt4JS75FbGmUQjGvGWAiPrCAZ/m/fQowRKJxn
3Zk7tYJc51LlnJwQ5NRMdxbRVlBZQ2jmVT8Ew3F/al4vrSAN97tR/IUIptst
fqA/KyjosvaO1QYE5kunigQ2VlCblLzv4BCCd+LKTursqyiX6vu1nb0a/E4m
cfBuX0W/+lbp1VzVoFogUFXGtYqW6hyPFwlWQ3PMEF2OdxUpxht9jDxeDb+P
mEYk7F1FJkGtY/4q1cCXUNn3RngVebmpizw+Xw2vpb/qG4muosS7pca2V6uh
wKtyYXH/KqrRPRppcqsaTggWJd+WWEWTp5Lbta2rIeHm3PWEg6toy0H+7aou
1dDtr/y74NAqOswTfOGYVzXUd3W/iDq8inT/rb8UDayGq+4OQ3pHV5HTzMPK
Xe+q4VyO1J9+mVX0tmd6lSWhGmLLY38pyq6iLzW35Zczq6GOrVXb5vgq6s3r
cp4oqobj66rmdnKr6HfcxRxCZTWsag1tUjuxivYFfKc0/KiGkoxth6dxPut6
4kBZdzVYsybWWJxcReZmH29njVZDuvtYbQHOftrCcXEz1TB25Y14O84fFd8Q
ghnV0MMx2FWN888Dm7m9Nqph3xXzVj+caVxPdRw5a4DCqrpJGGeuv/MBZvw1
MC5Hf+CLxzsxZVl7ZX8NnBPy3VaF6zPo7v+ndrQG5g/damjG9bsjPeWTijXQ
Sb0dn43nF5dT6yahXgM3hccCbh5bRd9jlAr5dGtAIDjPewT3Z9Q3l7rZqAae
Smw8OXlkFbE+ED+0Yl4DrRN+j0ykV5GkabTFtEMNSHfctbsmtYouaG1PHHhc
Az/mDl0XkVxFofuZfN9f18DpGM45abFVlL/D7mpebA0UdYVF3d+3ijpXR0MS
02pgT2D7fi/BVSTQ+YPt5bcayE290C2wexUpV54561pfAwbznszEXavINLvo
iWV7Ddjdtl9cxfst5WX84nlyDZR3Wtgf2LSK6h15ZJQWa0B02/rMEt6vFJMA
G+m/NcBIfXI24i++H04+GOXkqYWrWeL2OssrqHT8XGu7ai24nIj58xbfL71a
L5deX6wFz0sYy/b+FYTlVwnoXquFQE2bGKOuFaTkqWz+w6YWghWGfO0bV9DX
3cex6ne14PxfzMiz3BXU/8RB+HlCLfh+kJ2MzFhBq8RstTNZtbC37Uz6s8QV
dCpXMuRbZS0M/XfWsS18BX3TFNpfNF0Li7sZLCYPVtDgJ6PzD+i1kFUXl7/T
Fj8fuKPsZNdrgeWYukn0nRWkMrKr5NPuOphK5mqXuLyCyh9t1k47Wwf23sGP
5A6voO8fFx9GRtbBa65zjcJ9GBreIRt3LakORm8cZPK3YmjN1b6K+1MdhAg4
MierMXQGKByvUR30Cx3LY/2Eoaq+oQT/2TpIOWw7qfQUQ4ijqcldrR5EZVe4
s3gxRHLaNCevUw+J7/dsrGzCEEuPOi/dsB4u5NStiKwwkVrKd1Nn+3pQHn92
jzbIRNXKRUs20fVwUZhZG5XMRLV2CcImtHqwMekIlpNkouIZe3szrB7ChLY2
bebH7xdblQpLlgbwyo6cLNvMRP7WfTed+BpgWMdIvJjCQFoWPO99VRtALVdb
jSOTgdpN/PfmhzZAHhY0ryHOQMNajvzsxxoh2wgbLl1bRm1Np604lBohuIxW
dHNmGVVd4CzZqd4IohE3BkZ7llGSZqbBXsNGWM9KjA7KX0YWamMRx7wb4TPT
9aaV2TKaVjLkNW5rhG9xQlzmX5cQU+rMrjzHJpCxHS43vLGIzo5rNAV7NIGr
lJTltTOLKCBB67mtbxPQ3K6xHJdcRAJ8BgsScU2g9HtzLc/EAlJktW9/X98E
VduyfF/xLyCPodjwIOEf0FDAq87nPIfWwhm77v38ARZvJcB/ZQax/c7hFj7Y
DCIHViVp7uNIceNu6fX8Vojb5hFNuvkNtfrJ/2o80g63NIQS9fn7QWVXC9tb
hXaoeE3u1orqh6w4c6Vbau1Qt9A5spV/AHzzw5IXDPHfO3RcGtg9CCr90657
X7ZDtddkQi7XMGQdTdhj19cODWaxacdXiaAx41O4RaMD/oyzn2r5OQFPZH81
21/sgOlXvHxamyeh8KEguUO3A3KeqTbHqk2C6HqB4AejDrA5nNpXXDoJv3lH
fI47doBBrwhXXTIZClWVDI1jO+BXmcvokP0UiL2h/s6e74DvzvffVAzOQpX5
8+wiegdcVDcjqe2ggtl/u00qVjtg4UgSe8QZKsT3qnxtZeuEzy+izeKTqLBX
JNh9QaATfma3flE2pwHvJ2m6PHQCh1ld+LXBOdhcb0VD4Z0Q/CLcvu/qIqRH
/f7wI7ITTugduMZnvQiaNq91OuM6oWjM2P6k5yL4cJZ8Gk/rBKe23HiejEVY
v7rp/uavneC1crTfaGURVkdSydqkThDyLDOeiFoC6gpxtEeuC1YkJdo2vi1D
qU14rbZiF9yqGHsW0roML/rOfkSnu+Dos4Pjc6PLIFCW4Jh9oQsWvv3Zr8hO
Bw33W2tepl3AejdCr+MSHd4zegUlg3CutVzlbKeD1b2Af7Gvu8DkrcCxxVE6
yBEUxnZGdMHtsnMt2fN0aCyOzFpJ6ILIb6lVcTsZsOR6TamluAu250ku2l5i
gNZSm4ErsQvEOjKOZn9lwG5z71NTk12wcZkk2NjAgNEOmX2ms11Q68UdWNLF
ALfCkInzzC6QM6Y82E5jQJLzJVfB7d3w4dlq3Jt9TLAjrhqGcXdDaVhD5Flp
JshfyVJmF+iGu/xfzlT9x4Rm2a2sc/u7Yax86tRJbSZgc/Xh1YrdsB4vc27W
jQk1t90eKqh2wzPLDiGJ50wIbZMw+qTeDRX92dMyr5hwIM9HNFK3G75+8eUt
jmeCnoNano1FN7TWlFoF1jBh7/DCm2Gbbriycqj4fDMTxnWS3PQdu+Fhxwlj
QhcTPI6unz7t0Q2TPMbmFhNMSJ+taOYK6wZWhvMbYMPAKeaKhF1EN5ge+6Ry
exsGSpoTng2x3bDw9qu7LjcGzQmcx7zSusHGM80hSQSDSO1E/76sbjBSfb+d
XRIDs5UToyfz8fwG47acOoLB0lWT8Jmv3aAwyE3kV8Sg/B9tSrOqG+oNstOr
TmPg9+mFWnJdN5jwvY4+pY7B3k1ZSzd+dcNcd0Z3kg4GZ8uw6/UT3ZDz+kmM
ihkGHPeCc8VmuuEJr3iKvQUGXdyimz3nu4FvefCVozUGVnbnS0/87oaPjUcG
JhwxkN0zwPV6vRvWdDhOGLtgsFrnYDPNToAAx0DtBDcMQkUi9yZxESBN5UR2
3FMMbjQfcvmzmwBVlC/jV70xEHtc8dNQkAD62qGN/c8xmJa4cuCzKAGW6geu
nPDBoKhj/OkOSQLoSh54etMPAy9v926bwwQwz9dVNwjA4MIRTpk6WQL8PZKW
IhqEAXdfgp+oPAF0aJ0x315hMOB7YuSJMgE6e6f2HwzBIFWuQaHnLAEu295Q
MQ/FwGHEOExOkwBsVUtjjq8xUAymUUIuEWD3+0V+nTAMWJRewNRlAn7e0gir
ODdP7I7VMCCAvPqYyONwDCLeZC4mmBDw98GxxQacTc+cvvTbjAD81AgdMs5S
s79SDO4R4Ie1klwPzovRFn8K7hOA5XxSYhTO5eewa9ud8fxFSmKkcPZbfJVj
7UaAUyoN+4LweHoJIptqnxBAPebZ8XJcn4D2Z1OR5wQ4M7rc+R3XT8I0Szz8
CNBmGb3lDZ7fp7T+nYRXBOCUUOv4LxgDt6sO1sfDCWD29fDJLNyfs/82qoIj
CRB5a+H4HO7f1k8ReyhxBOAbCG9j88eg48ahB+pJuN/BDrtmcP/fs1f8iE8n
wC29S3+SXmBwr/Cy+Go2Abo8dSMOPcPrf3v8yfUCAtSR1onPPTGoKd12lLOc
AAznF7mpjzAItkzwtUIEsGDTU3Z0xcCA+8RwdT0BsJd1ERzOeL3vG79+3E6A
sryx9s82eL0FaOQuAgH2GsfWIEsMPOuen5UdxPuhRSAl8Q4GXCKZC5OTBHjK
rNJrv4GB2g3fkYkZAtTykKweXsPANfxOy/g8AaKej+bN62HQy7o3k7RKAEeR
8gU7TQwSKUFmwzt6QEdhXcXzOJ6vmJXuEE8PsPALdAwcxoDNRF1lUKAHlEP4
xnbh+8265Td///4eEDU+m8q2F8+30K6tW74HdJVix9jXmXB35kJFl3IP/Hyp
ECm2woR3BySyO8/2wBetveK7F/HzJ3LIr12rB8acLqy/HGNC1RNd1RbTHvj4
XPvCi1r8fDknm1Pr1wO/Tdd/b/dmwjMvzriaVz1gduged+5DJhSWUAKqw3qg
gSHCkLRjAp90kkVVbA8I6grapdxgwvAObqHy3B4Y9nm6s+kYExx6l4I+E3rA
5uEW9l4CAxJ3/XIvHOiBMvv++u0/GdCh9elewWgPePqxhAlXMkC+wkItb7oH
qluvh/1MZ8BaUvdK1loP3DHZUmXuyoDQ+yXWyZK9oEOMfhCzhQGzanlB24/0
gnkiD+v5FTpc3Jvxyf14LzjmGOQ0TdGBrSlyXlelF2JeH+7W/UGHJ5Ju7r+v
9IJhc9axm4F0sCaeDLjm2Qs/f66JJ/9bBnXDwoxNXb3gGs0sm2hZgkSZrCbn
vl7Ib2RjepYtwRp78szgcC8cCHwsMZ+6BF+Lwo99nuqFd25Fm82fLIEst3PJ
7X+9YO+OfvhLLsG+lmMNpdJ94K7xPob+cBEwtZxJ2+d9cKfAdbfV0hx8T6d+
eOzXB8I2yYKCdXPgwyFzPeBVHyhuFnaKipwDro7cmrSIPhjYbmU2rTgHUnfy
E0cz+wAJZ/9meUKDG96fjQ06+uDJmsVlHfoslHwrawXxfrCcXqr6WTsFbifr
vwjU9cNF79RnZeMkIObXh3SKD8LIBSkOzph38NeO8OHw0yGoVxzLOLiDiAwU
b7+VfT4E4VpXGPLPiSiXlRLwn98QdGpbhHIuE5FZ7IrLmbAhCDFt+OhjT0I1
DUJa+qlDwDt4eAfPlTEUuN+c4dE8BGdyS+XFuSfQ7t453R9Cw+C/LWKLxmMK
ckhx12gTG4ZcNsmL1rkUVO+wodQlOQxWP6aX7o5RkDs7j8Sw7DA09vSw9GtP
oQE5+d8LGsNQ+abqQa3wNEoKeZqxx34Ymjl82RVKZtBR9a3r1hXDEBFj825z
PQ0Vfso51F89DD85m8xPrdCQPN9V/UuNwzCW5lcqc2QOqU7Fph/tHIbpQrVT
xuFz6PLrIzqLlGHg1Skrzr8xj1wH9GKf8I7A0461HWv9C+ibS+TJ0PsjUPVS
mzfDYAmdHTpl+s9pBFYOEUKW7i+hWs0Rfye3ESg1a3Xd+3wJNe+RGrj6fATe
bwrqYmQtoeHKsuf8USMg9jdibvzPEmLhHGpNrB6Bmmz6eaeYZXQxVdzm855R
SLSWS95fREfysVxSjftGwdxd1Mmwho72h/2dHBQfhQ5DaV6rDjr686THYpPM
KAhRDe355ukoT/+VmZHaKFybnTEuPMRAu1mXDP/ZjsJ/0z7VDREMxLIywsfr
NAq/jMXOfkhmIBqtuVvq4SgsssvMXcpjoMb+dP2r3qPg7aj14mQjAz0pNNZL
ezsKU8e9Fo5hDES8U615qXwUAub6QsovM1GrYR67GRoFxT+HwvaaMNFXnfe1
rvWjwOegan3ZkoneKbmpxf8ahephdh31x0x0fpe06sL4KMh4EkfVE5jo5Gb+
v+zTo3Cayedv+pGJRP+ylu+dGwULEzvnywVMtEoZUtJYwT9P12srq2ainKrw
/6K2E0FssHw6cYyJYr94LWdzE2GT7Ptplxkm8vt0/3MVPxF2lonmCy8xkVn0
uePTYkQ4VB5zlb7BRDxOK0dOyxNhJLbD5bMwhtYtJ2euKBOBfkRDWPkAhmZN
OrPunSXCiXvnxGKkMVR/PkcqTIsIDGOlrb3yGHoscufAmCkRTDGyoJkOhiyu
yt0YNifCxaFAb++rGLrsyxrcZ02EgHanADdDDEnNpC21PSCC7XG9ezNmGOLd
9+jgz0dEcFgWlraxxNC/yxdM6p8Swf3dqNN3GwwRvkxXl/sRoRx2W885Y6h6
6huj5BURJJ993PrzIYZyhEKkP4cR8XvoAZfXYwz5vDj2JjOWCNOnuU/YPsOQ
U/F6XWoCEf57cV0t5SWGTCjtKwmpRIhI//jhsx+G5HRd70TmEqH9xfP9xsEY
2vf8XET4Z9yvsSqYD8XQ1iK+puBSIqT7vYy+FY6h5UnyH/8KIijHmO5Pfouh
0T1lsi+r8c/vOj5QEYGhZu0gC68GIpz5Kl6ZH4WhEm+T6MfNRNghn/nDIwZD
yYVHml3bidC/xWtVMA5DoRN//zkSiHD8/cdL795jyEOg7cT9ASIMazz+NvYB
Q5aXEq3ujRIBnQ86z5GA++nlHHdnggg8w5XUzYkYUilQa7s5TQRZpQufBnGW
GudhvTFHhEbfuOcBSRji4Z+Q118mQgbtid22ZHyev/jFVneFCIPx9PuWOE8/
9Y+/uEYE8xpT70icZ28ctU1hIYFxsGF6PM53F3ezibGTIPzoj1FPnHtfrX2I
30yCvOFpmZM460iQFYQ4SFDTrxCO8HjV39vaYzhJcPX24y2SOCveKL3Pv5ME
41ko4g6uL3chkT1iFwk2/bY75Yrnc+BVYAI3LwmqAsWwW/EYij3wQCmMjwQx
QW2/9uH5c3037ty+hwQsBwvqv+B++Rmq278SJIGqh9agRCyGfs8f3rx1HwkI
wTa8dtF4vYN4k/xESWCtJ/kgMBJDk+J/T7GJk2BbBAnzfIehDoNWh38HSfBD
5WrY7GsMXZj/ssVTmgQGj05l3gvB0PfAhOTVIySgEF79LgnCUGa5E4F+nAQ9
Qv9uj/rg/WFg5ORykgSknylPS55j6N0ccCzIk+DEvhKypReGnu3nUZ1VxvXu
NEIXHmGI8e13j40qCTJPlqh4umDI7vq4M/ksCdKX94sGOmLIMKA4jXSOBFHH
p5UPWmFIhma4vU+PBFy2BYme1zD01UAXBV8lAZzbb7+mi6FzlRoPz14ngaX2
pyq9ixi6GXZ8KMOYBCc/5By1OI2hV3LbctwsSRC8ZzTwujiG+OI2zKStSSC6
tZ1hIoT3HyvGO2yLx2feMDixG1+/a/zpOScSPLxgJn19E4Yobt+1eZ+QIOmR
P+XeJBO5jhStN3iSYEYgJ5MxxET/zmcXPXmG+xs8RzTsZiK+PdFCY74k4Hez
3witYaJz35xnC8Lwv58x3N3xgYmS/x0I1ksngTzxYVzFRSaSsRY8y5qJ+1PP
puygykRlv3Ytf8kmQcmVT6kLckz0K2nNZF8BCewbLik6C+Lx1HsPU7/h+W2l
iRtMM9DNgFc/g9pJEGJCudXqzUCU+efeql0kSPvKQixxZiAXI/cTiwQSzLsZ
Eh+aM1CQtGWc0SAJRjwudjpqMlBps+p9KTIJEl3Tx0w58Ptg1yJH/R8SxH0y
EdIMoqOuyuDAS//w/PWspNM96Oidw8Et7Rt4/3xKECbZ0hFv8032wU1j8Nz9
gxRNC2f/hn8LXGPA4hHAbbyVjrj/vl8WlhiDxeM/Bd97L6MdU+eHH+qMwdZN
ry1yri6h1ijSzd96Y7DXfPltg+oSCtX0HHh2dQxKr3n8RNJLaHtqYe8rwzEI
+uFCNmBZQpy3hTuT7owB2+36uc35i4ije7Gh5eEYZFWMj6ezL6JN6EOBRPwY
9ClIUkdOzKFBVU0tYuIYjG0/FVWyTkMF5TTS+5QxyMgI5r7cQkM3S8/w8maO
AWG4RqXOkoY+5xHdWIrGwChi5VvzWyoyi5dQGWkagy9xQn+KxmfQ1yc59dF0
XP9VG5FDtyjIXr5iYJvOONz7VfyQy28E5VyySK7CxoGb4xDXRE8GMKlC3JTo
CeBSjExq0yZBZMJUU3zcBBydk/XPDyLBf1e+PL8ePwHZw0r8Do0kcCnSW6hO
mQC922kSnupjMOfx4teH3Ak4luQaOagwDuTNlFD92gmoonlkyuyZhB6xz9sq
5ybgmj6tI/Er/n7r9K55uDgBi1ZyosJLU7DbV/vJEfoEDG8fV7x3eBr0KRPT
MasTYAct0zfjpqEtV+CHK/sk9HKuqrS5z0CDsleAtOAk5BTtdzc7RIWS6xfZ
IzUnYcY3RWq36TwE6Xz133dxEnK56I6bgufB9NxhjoxLk/COpb7pe9k8sP23
fWfp5UlYtL5m9pJ3AS7ztgv0G09C+lrb6NWGBZjuuHFkn+MkcLas3SeFL4LQ
ZWv99KhJ0PmmGDbctQRz5/u6ZWInob+zkGWVvATVZ7RulLyfhFfdzgLLq0tg
fezIrcakSbjkkJX4UnQZinfM35vOngTLaC0DTttl0G155CFTNQl/2m9+TWcs
w3Mt/6QvlEmQFsxYFqHTocvM1lRuZhJELJVe+7EyQPKRjmAudRKW9gxeb9rF
gOYUnoi0xUl4e/PHBukoA/j+JgS8+zMJZS5NghYWDMjKK3V8wEWG2L0+9wN+
MOBPXdwRGjcZ2ApTrdPxeUVv0GvKZjcZes6770kgMWB5yznzO3vJMCCrDKKr
DFC9225w+QAZUm7utLx9kAkdvNOnZRTJgIVYlld6MOHA4ZbVzFNkaNBteeXt
w4RHkF8icZoM4wO9fQKhTBBycDsurEaGt/6suT2JTLjXwCLBqU2GrM1s933w
eax0aILor0sGPY6NOztamLBtuTGe9QoZ/s1vM3TuZkK+6GuB39fJcDFKfh1N
MGH1sSDn9G1cf111VTAbBtpha42Wd8mgMighMLQNg4R0oi/Rggzvnn1YY+fB
QKMz41+vDRmkYt9qEkUxCD1ycqnBhQxNEt8elJ/CYFSNP1/djQwGAfPzbWcx
OGG0alfpToYdrlxJ3/D5tde3avKLJxlOc7faC17FQHxEuz/NnwyKygoff9/D
5+3a0wWGQWSY4s5jytthsJwpE7A1hAzFUiE71fF5u9aVS97+DRmmZ/0cWzww
OGK8wSkSQYayF+Kpl7wxiDizOPYrigxyl6U8Yl/i8z5HV/jJD2TY9qGKnPkK
g9a5WuvJBDJcs/jtYPsaA4Xu4jPRyWRQ4qe6/X6Dz9df0/m00nC/Ziyxm5EY
bEmMov7OIMOv03GzoTEYOPkG1OZkkWEu7qBO+HsM+mwfx93OIcPmXg5eiwQM
sv4zuVhTSIa65rbvHqkYcAtqiz4sJsPqVHb093QMnqyrMCVLybBe21nb8RGD
8Ymjrb1fySDxn9qZkizc/5/70oIqyOAbbchm9wmDovydT1WqyBAw2Me1kIOB
UOT6VVo1GUJ9l+9o5mHg82ThUGIdGYqKFen38zGgmpHWrzSSoVPuQ+OdAgwM
NDt7WH+S4eN9r/6DhRh8P1ybW9xCBqGn8Ye+4yy5q9jX6hcZvspKFB/4jNeT
kXZzTycZjLYmPjXBmTEQeeJnNxlIp1ie3cX5NvLn8Owlg0Z+aqUSzo3p7kSZ
ATJEcWiqEPH1ZINtSkeHyGCZyMG8gXO0s/HrN6NkEH76dCER17NhcOmexhgZ
coxeHS3D9dqqqJxmTJBBOyU4Jynv/99nHOX9SCHDA3tlV+NcDE5t3jdjNIPH
dy71GcP9SJ7dUb2NRgZWjiCSSjYGHB3/oivmyaAs9T78XiYGLiXzjo5LZIi/
fDbSLAODwfdETTEGGdLDjtKl0/D+fdEh3ImRQczt2ee6ZAw+WdUs+/wmgw77
N4JsIobPdUU/5dfIsDe31sLuAwZP5dKSKetkiD47be4ei8EEf+TjWFYKhI0O
9V+LwuAL6dHBtS0UeCS9qO0dhsG+Ruu1vG0U0FN3NmwJxsA/x6j7zg4K/JR6
gs0EYHDDXfllHQ8FPHZoiMU9w6Dq1hHjR3wUuFsd+O3wUwyk1IWPH9pDgX2+
VrtCHmGwsv3fcPA+CmTe0NlTbY/B3aW5YlUxChRsZyFGWGPwo3c0eF6cArto
Ga9PmWMQm1J96tohCqz7OLczDDFQUfKLFDxJAW/eMC2VM/j+sxBUTJCnwGV2
65VtShg8DMvv269EgVM+11k/y2GQS+4XklalgCbvQSN/CQxEI4+lKF6gwFL6
7gdaWzEoR7Ua5VoU4DRcvUnYYIIR1WjyjA4Ftmxh5Ty1yoQ3Gj6Hzl+lQMX5
qPmAaSawLfXmXb9JgRapUg/NJiYk7nO40meKr7/44fCbKiac1mJdunmHAmLZ
5kJfSpjglnRU3uIeBUK+z677pTGBovei/IETBVh+JFboejOh5dPhptc+FHgw
deiE32Em2PZW2fL4UyCLs8vUVJQJm9gMOKMCKXDTGMN27mbCWZNnevGhFDh3
V6X1318GFG7t7v4UTYG54CPmvK0MiLznRWr6RIE37xT1JawYYCra/pu1mwIZ
mKpvhCcduARdSyp6KBCgEpHqakeHmt38Lo/6KdDO9uaktAkdpLbdmp4eoUB3
TvCZPYp0WKBTetunKbCWlaOxbX4ZfH6uFyesU2C/8kGtuzeWIctN1kn5yBTo
B70U3MK5BDedOw/TZabgv7DndHbGIuy0cyPnHp+CxBeruSMji+B6p9x0v8IU
RFdx+hz8vAintS/obFWbAhO9ErEdNxbhl5iZdI/hFASO3V6vPbkAzObX4w9e
ToHGJ8n0M7to+L3fY7vmOwXyXuYzLqNUqNXdtxAYMAW3dG43u+ZR4c2vT38T
Q6ZgBpvoH9KmwpGuJr62qCnYJTESZug7C2YDrBcPf5qCzdaGv05Tp6Fx6lHO
WNcU9O7NHngVh9+Dm8zcrklOw5RGrV//zhHYPVqSylY/DXcZEqw7+n3QZu+X
BsouM7As4ZS3Q4SEvizRfqOHM3CR/uYCxYCE7lkbJ13A3x0G4pTNiaEkVH/l
+Ox1zxn8ddJy/uNfEvI7MPLcyX8GvF58+bezfwxt+nEqJy1uBg5uzcsbfjWB
2HYvsnLVzgDPBtks5hcFFQXeyoysn4EyYcJjW9YpZLHWqCvcNAPbekMyOeWn
UC05IUa6dQaOW5l/r46dQj5fdY6d652Bh4Hxk9N3phGrWaaxx+wMwPvhwO7J
GcSSbVYwzjsLm0o7atwbaaiR1ueUxD8L45QZjbsYDYXK6cua7p2FHlvVuk1S
c2jP13N5PSKzsEehecPLbw7JNknn/JCeBTuRLhXRs/PIlLz8Mf/sLPD+uC5W
n7aADhx2sLZXnwX+hWubj7QvoGkH8kFpzVnYYu4gqflnAT1k9KWnXJqFZ116
X38eWkTB7JWpkQazMGkdH3zJcxF9Ew9MfGo3C5aBJbFEoSX0zIrFTMlxFv4q
ParcJ7uENLOfiDCcZ8E2P3hKTn0Jdcg5xDs+mgW/O6Q3I9ZLCH8Rvr/7YhZ+
rTvLnitcQgJmwtEXomdhWX3MZO/pZTScEmnIHjcLFh9/fCjUWUap5J381R9m
wSO/QkTEdBkdc2SJVE6ZhTrmUVVXr2Wk6UV+K5M7C0bcms4cFcvI9X3Ba97a
WVhSuH2y9jgdla29D6ytnwUtAjagc4aO1swCXro2zYL90H8bWdp0FChx+1FX
6ywk9wqeHrlHR/G5nLff9eH5iE/2Ho6hozEu7IbG4Cw4skc26aTRkZTL2NXl
4VkIU848rlZAR4UKXzWvjc8C4+D5maRGOmqospLhnZuFMu/kXCU6HXGK60vV
LszCCwNdltl/dHTVV3W/6zJeT2x00BGffwYv7ubrWpmF4YotxTP7GGi+o/rv
W7b//5/0LyX/HAP9918uU30zFUx/7bCZ1WUgj6iYhaWtVGApL4zADBmI/abT
hP5OKjhbyIS+sGGgvRPCLTx7qXC9eL+acRAD3T6/taFGiAoR/V62Am8YKDVz
ucpFhAqzR6OfpMcwkIzDz6LOA1QQsyP8Of4Rn99+fcl9eZAKflUXzx7Lw+c1
ueSPJ6SpEG3Az/OnmIHUme7v3x6jgmO+zi62GgYKMLKIVJejwn9qJO4zTQzU
+k0vbOkkFRxmpC5fbGOgG88kffRPUcGzVkDmZz8D2W3tus9zjgrFsz9uvZhj
oIL7lZY156lgfaFI9L9lBmK0ZN120aJCZOmlwC8YAz1/81y/U48KQX3mmyU2
GKh+2U7n5VUqrHuV/97FzkSchjfOn7iOzw3nXfRbtjBRpOAx5bfG+LnjmU3L
3clEA557/1O/RYV30jSebm4mEh1lP7Z0mwq80bvMmnYzkaXaglTKXSoc/TlS
+0qAibJSB/frW1KBqPLspBA+/85tahRitaZCyOSjJA9hJjpp85nvsy0VVHUy
19JFmMjjZzyXuT0VzgZfO5MkxkSVR4M4eJyo8NmU39BGnIkUCXva3j3A9Xd0
BU4cYKJCr8y3fA+p4GH8nUVekokOH1S6Ef2ICtlbUkqNDzJRaluj0F4PKnBP
RyfrSzHRPvcbxLinVDjP8bdE9BATRYlS0oS9qdDs5jKPcOZqemSb8BzPH8jq
CtJMFOS8+ZiYDxU6XgZlPcOZdW/UUrIfFaRMCULxOD+tliw9EEgFbDXo7Wuc
GbZfnqa/ooJAaN7m6zg78miCVCgVGq69eUDD16d862bPCqPC+LvGFhOc71pY
/jj8Fq9PnAzPB1zfACc9NCeCClbfyCqFuP5rxT76x6KpUHHR9Fwcnl/LLV6B
glgqoDj1gzckmEhzU+qg3Acq1LCEDVFwf6pyTyQVJVBhqeGFuc5+JlIyrLGU
T6bC24PJRb6iuF//rkqXpuL9e+lbc/g+JjrykURTysD78Rwpw1kI92dl49Hp
T/j6Zpwxn/iZKDopXKUylwqV1JiPm/H67tIS2zhbQIUHAloO8nj92eLOBml8
ocK5jOPcOzmZyFP9l259KRVynx6aLcX7hzFzm+fCN7weFbUu8nh/Tal4v79U
RQUjBUe/T38Z6O7Ejjst1VSQfO+yM20F378h8RJ6dVRwz2ZXc6bj/T9ckXv1
B95/PTXJPrMMdMFfx6WrmQrfNAXaf5IZCB0bUjBow+NPamVOkhio6NmfKqMu
KtBDEoyjehno6KFg3wECFWJlBOWPdjJQerug1q0+vH47pKoiWxgoZr9yp9kw
rpctizyOGMir9vGEFQXv5zTvJnt8/zLttmZNTVNh5lTzzaQkBnLaHeNwn0qF
RaJE8cdYBjK/V8p0WKQCv7llnVwwrm8Lc6vbHyqEqS5NnLRnIB5tVxkfLhrU
R9XyMyQZKLlm13YVHhpc1HtzMVqIgeSU82aWdtNg6YMZdRM3A12Wnv5oLkiD
88SR4ot/6Ch4i5m4uiQNvPeTgu610tGmuksCLCo00Kl2fbTFho4iVKYYZao0
OL2PEfrIhI4OFPl1OwMNzoiWUj/r0JFaCnpD1KRBtEt59Tv8/PZ+rrAdXaHB
lOHLLIyxjLDT4izPrGhQNCoTbuS+jPyLq0YVbGmwZ9ebgDSrZcR31LRyzg5f
r1aGUWmwjP4Tinl6+wEN1hXyX5mdXEYPVncwVT1pkBIcz69PXUIzX1Zn/r6h
QZDHeR9ugyU0fKyj+8l3GvgZHMUKWBdREpXHmx3RYCergP6//gVkkX1d6nUN
DR4Q7sho5y+gGck+j+RGGmywVPHTjRYQJjwq0tRBg7UIMffAzHnEw0mz4SPj
+l/7T80ozaELlK1r+Tvn4J5sIUNKbBZtS7+UcYp7DoT4t9qLUWdQq3nI5Vre
ObDdKfj+V+kMuj7CldKzZw52/nGRvKY3g+4S+C+sic/BT4uq7Uz3aeRZK/Hm
kuIc7OgyvDb5nYIKE0Fy0mwOnGw1ZXT4JxD9KX2rufkcrOso/G4fGEeKRpnU
Ecs5CLfJKBBIHEcVu3YV99nOwYmLYkuzB8dR44tR9RbXOfiwauhVenIMDVl4
3ykKmIO+/TvOyvmMoi2HKt6/yJ8Dj7xC263Wveh2gSKPyPoc8BypeVxDLEYv
/FNeDn+ah1OVqiGN4eOQNy3ygUt3AQTJdXk3x+gQlOB/d/TyAqRoOBwK4WHA
vWtzB/P1F+CjaOeBanUG7Pv+vVDPaAGqG1f3KKUyIDj8VmOoxQIU7UqwNLTE
39+KcUucTxbAZnaz7CkKBgf8+LS2flyAPlWrk4S537B+ymtnX9YCWEs0cJuK
/oGBuYmujzkLkL+zWIh8+Q+8MSq+feHzAiz95rf9U/AHNo5ce+j/fQGfP35t
lXP9C8Od4Yns3Xi8i9JHyrE1+BqwYtndswBPeX8Z6R36B5Gn7xxO61+AQd9/
bSSjf6CTIftFY3QBjmmXO3N8+wflHm0/X84sALfVuTwTz3WIPqYQrk9bAFaL
OJjPWQeX8XgD8YUFWNnDMe4zvA7Sug7EasYCvI8iX8g9swGbWAnpb1YWgHy0
mU3daQNIJaft7v5ZgMJ9JTU9iRvw3S7tuNw/3L9iFh+79g2IEdvO3NhYgOcK
BRobGxvwP4j4LXM=
       "]], LineBox[CompressedData["
1:eJwVWHc81e8XT/lmpmSEFiVJikopqiMrREZm2aOSpJCkZK+MJKQisimZIesx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       "]], LineBox[CompressedData["
1:eJwVWnk4lF8bzlKpRJZsoSxJklRKIk9KKJKtkMjWXvafUtklOyHZU6JE9i3i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       "]]},
     Annotation[#, "Charting`Private`Tag$737934#1"]& ]}, {}},
  AspectRatio->NCache[
    Rational[1, 3], 0.3333333333333333],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->Large,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1}, {-1.5124045668680923`, 1.9999999438161027`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8056617530159187`*^9, 3.805661811726569*^9, 3.8056626412162533`*^9, 
   3.805663252219796*^9, {3.805687964887457*^9, 3.8056879729358*^9}, 
   3.8056889809483128`*^9, 3.8056893601823797`*^9, 3.805690307191669*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"9eacef96-e250-49e3-a0c5-cc6e9f033e0f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definite integrals of eigenfunctions", "Subsubsection",
 CellChangeTimes->{{3.805690802491428*^9, 
  3.8056908469338303`*^9}},ExpressionUUID->"69a8645b-400c-4610-95c0-\
d3242a4130a2"],

Cell["\<\
We will need an expression for the integral over [0,T] of each eigenfunction.\
\
\>", "Text",
 CellChangeTimes->{{3.805690851505158*^9, 
  3.805690908824251*^9}},ExpressionUUID->"2260c057-c3fc-42ae-b988-\
9162ebab53ac"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"eigintNumerator", "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"s", "^", "2"}], "\[Equal]", "1"}], "&&", 
      RowBox[{
       RowBox[{"Tanh", "[", 
        RowBox[{"\[Omega]", " ", "T"}], "]"}], ">", "0"}]}], ",", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"Integrate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ExpToTrig", "[", "eigfun", "]"}], "//", "ExpandAll"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "T"}], "}"}]}], "]"}], "//.", "rules"}],
       "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"eigintNumerator", "=", 
   RowBox[{"ForBothSigns", "[", "eigintNumerator", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"eigintDenominator", "=", 
   RowBox[{"\[Sqrt]", "eigfunNorm"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"eigint", "=", 
   RowBox[{
    RowBox[{"eigintNumerator", "/", "eigintDenominator"}], "//", 
    "FullSimplify"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"eigint", "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"T", ">", "0"}], "&&", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"\[Omega]", " ", "T"}], "]"}], ">", "1"}]}], ",", 
     RowBox[{"ForBothSigns", "[", "eigint", "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", "\n", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"eigint", "/", 
         RowBox[{"\[Sqrt]", "T"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{"\[Omega]", "\[Rule]", 
          RowBox[{"\[Phi]", "/", "T"}]}], "}"}]}], ")"}], "/.", 
      RowBox[{"{", 
       RowBox[{"s", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"+", "1"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Phi]", ",", "0", ",", 
       RowBox[{
        RowBox[{"Last", "[", "neigval", "]"}], "\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "2", ",", "1"}], "\[RightDoubleBracket]"}]}], 
      "}"}]}], "]"}], ",", "\n", 
   RowBox[{"ListLinePlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"neigval", "\[LeftDoubleBracket]", 
            RowBox[{"i", ",", "1", ",", "2", ",", "1"}], 
            "\[RightDoubleBracket]"}], ",", 
           RowBox[{"1.6", "j"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", 
           RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "neigval", "]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "Thin", ",", "Dashed"}], "]"}]}]}], "]"}]}], 
  "\n", "]"}], "\[IndentingNewLine]", "eigint"}], "Input",
 CellChangeTimes->{{3.805689041539501*^9, 3.805689078099031*^9}, {
   3.80568912106689*^9, 3.8056891320666857`*^9}, {3.8056891645246067`*^9, 
   3.8056891647322283`*^9}, 3.805689207580351*^9},
 CellLabel->"In[56]:=",ExpressionUUID->"e288f959-5262-4cfd-adb3-ece1ca708f01"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVkmk41AsbhzGWse9jqYNKliiy9EfJU9GprCFkS0LHLqVUQkdaJErSQqu9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        "]], LineBox[CompressedData["
1:eJwV1Xk41NsbAHB0KTKyZ0mUst/E4JvkvofULbKVnfYmkq10SSWJkhbb/ZEh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        "]]},
      Annotation[#, "Charting`Private`Tag$750561#1"]& ]}, {}}, {{}, {{}, {}, 
     {GrayLevel[0], PointSize[
       NCache[
        Rational[7, 360], 0.019444444444444445`]], Thickness[Tiny], 
      Dashing[{Small, Small}], 
      LineBox[{{1.8751040687119611`, -1.6}, {1.8751040687119611`, 0.}, {
       1.8751040687119611`, 1.6}}]}, 
     {GrayLevel[0], PointSize[
       NCache[
        Rational[7, 360], 0.019444444444444445`]], Thickness[Tiny], 
      Dashing[{Small, Small}], 
      LineBox[{{4.694091132974175, -1.6}, {4.694091132974175, 0.}, {
       4.694091132974175, 1.6}}]}, 
     {GrayLevel[0], PointSize[
       NCache[
        Rational[7, 360], 0.019444444444444445`]], Thickness[Tiny], 
      Dashing[{Small, Small}], 
      LineBox[{{7.854757438237613, -1.6}, {7.854757438237613, 0.}, {
       7.854757438237613, 1.6}}]}, 
     {GrayLevel[0], PointSize[
       NCache[
        Rational[7, 360], 0.019444444444444445`]], Thickness[Tiny], 
      Dashing[{Small, Small}], 
      LineBox[{{10.995540734875467`, -1.6}, {10.995540734875467`, 0.}, {
       10.995540734875467`, 1.6}}]}, 
     {GrayLevel[0], PointSize[
       NCache[
        Rational[7, 360], 0.019444444444444445`]], Thickness[Tiny], 
      Dashing[{Small, Small}], 
      LineBox[{{14.13716839104647, -1.6}, {14.13716839104647, 0.}, {
       14.13716839104647, 1.6}}]}, 
     {GrayLevel[0], PointSize[
       NCache[
        Rational[7, 360], 0.019444444444444445`]], Thickness[Tiny], 
      Dashing[{Small, Small}], 
      LineBox[{{17.278759532088237`, -1.6}, {17.278759532088237`, 0.}, {
       17.278759532088237`, 1.6}}]}, 
     {GrayLevel[0], PointSize[
       NCache[
        Rational[7, 360], 0.019444444444444445`]], Thickness[Tiny], 
      Dashing[{Small, Small}], 
      LineBox[{{20.42035225104125, -1.6}, {20.42035225104125, 0.}, {
       20.42035225104125, 1.6}}]}, 
     {GrayLevel[0], PointSize[
       NCache[
        Rational[7, 360], 0.019444444444444445`]], Thickness[Tiny], 
      Dashing[{Small, Small}], 
      LineBox[{{23.561944901806445`, -1.6}, {23.561944901806445`, 0.}, {
       23.561944901806445`, 1.6}}]}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 23.561944901806445`}, {-0.9996488615480892, 
    1.0006399372450459`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.8056634643087063`*^9, 3.805663500224921*^9}, 
   3.80566358372499*^9, {3.8056638555621853`*^9, 3.805663875447373*^9}, 
   3.805663909862224*^9, {3.805663952248934*^9, 3.8056639732701693`*^9}, 
   3.80568919384396*^9, 3.805690316563499*^9},
 CellLabel->"Out[61]=",ExpressionUUID->"a8971e11-c50b-4424-9a1a-1ebfc5ec0c22"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"s", " ", 
      RowBox[{"Cosh", "[", 
       RowBox[{"T", " ", "\[Omega]"}], "]"}]}]}], ")"}], " ", 
   RowBox[{"Csch", "[", 
    RowBox[{"T", " ", "\[Omega]"}], "]"}]}], 
  RowBox[{
   SqrtBox["T"], " ", "\[Omega]"}]]], "Output",
 CellChangeTimes->{{3.8056634643087063`*^9, 3.805663500224921*^9}, 
   3.80566358372499*^9, {3.8056638555621853`*^9, 3.805663875447373*^9}, 
   3.805663909862224*^9, {3.805663952248934*^9, 3.8056639732701693`*^9}, 
   3.80568919384396*^9, 3.805690316566945*^9},
 CellLabel->"Out[62]=",ExpressionUUID->"4f77f477-15c7-4bd0-b744-a75f40a27974"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bounding Probability of Coherence < 1/2", "Section",
 CellChangeTimes->{{3.805667225558626*^9, 
  3.805667259164178*^9}},ExpressionUUID->"a165ee07-ee06-46bb-99c9-\
1789c837c884"],

Cell[CellGroupData[{

Cell["Coherence function", "Subsection",
 CellChangeTimes->{{3.8056872979780188`*^9, 3.805687304333837*^9}, 
   3.805690946021755*^9},ExpressionUUID->"e90a49b0-f8e3-42bc-81c4-\
51e2a98a7dab"],

Cell[TextData[{
 "Coherence is a scalar measure of the alignment of a number of phasors for \
the purpose of coherent detection.  In this section, we consider only the \
discrete-time case.\n\nWe suppose that the true phase history of the received \
signal is a linear combination of eigenfunctions with independent Gaussian \
coefficients.  The receiver\[CloseCurlyQuote]s phase model is a truncation of \
this true phase history to the first m principal components.  The phase error \
for each sample is therefore given by a sum over all the ",
 StyleBox["truncated",
  FontSlant->"Italic"],
 " principal components, i.e. those indexed by m+1 through n."
}], "Text",
 CellChangeTimes->{{3.805690952183453*^9, 3.805691344878889*^9}, {
  3.805691499870433*^9, 
  3.8056915071672363`*^9}},ExpressionUUID->"110beb83-f89a-4f43-8de4-\
207e4eb59407"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "X_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "n"}], ")"}], 
    RowBox[{"Abs", "[", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
            "X", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
            RowBox[{"Sqrt", "[", 
             RowBox[{
             "\[Lambda]", "\[LeftDoubleBracket]", "j", 
              "\[RightDoubleBracket]"}], "]"}], 
            RowBox[{"V", "\[LeftDoubleBracket]", 
             RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", 
             RowBox[{"m", "+", "1"}], ",", "n"}], "}"}]}], "]"}]}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}], "]"}]}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.8056873078923903`*^9},
 CellLabel->"In[85]:=",ExpressionUUID->"787e58d1-758b-4e4d-ab35-c8b8b7511b2e"],

Cell["\<\
We seek an upper bound on the probability that f[X] drops below 1/2, \
signifying loss of coherent integration.  We will establish this by showing \
that f[X] is a sub-Gaussian random variable with parameter corresponding to \
the first truncated principal component, and obtaining an approximation for \
the mean of f[X].  These two pieces of information will allow us to apply a \
standard sub-Gaussian tail bound.\
\>", "Text",
 CellChangeTimes->{{3.8056909333566236`*^9, 3.805690934680787*^9}, {
  3.805691364933806*^9, 3.805691399192914*^9}, {3.805691491914847*^9, 
  3.8056914932193193`*^9}, {3.805721262427321*^9, 
  3.805721412519772*^9}},ExpressionUUID->"24d854b3-d593-42f8-ab6e-\
ff6abde83d2a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sum", " ", "=", " ", 
   RowBox[{"Inactive", "[", "Sum", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"reindexRules", "[", "i_Symbol", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{"i", "\[Rule]", 
     RowBox[{"Unique", "@", "i"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"reindexRules", "[", 
    RowBox[{"{", 
     RowBox[{"i_Symbol", ",", "___"}], "}"}], "]"}], ":=", 
   RowBox[{"reindexRules", "[", "i", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"reindexRules", "[", 
    RowBox[{"first_", ",", "rest__"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sequence", "@@", 
      RowBox[{"reindexRules", "[", "first", "]"}]}], ",", 
     RowBox[{"Sequence", "@@", 
      RowBox[{"reindexRules", "[", "rest", "]"}]}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"reindex", "=", 
   RowBox[{
    RowBox[{"s", ":", 
     RowBox[{"sum", "[", 
      RowBox[{"_", ",", "lims__"}], "]"}]}], "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{"s", "/.", 
      RowBox[{"reindexRules", "[", "lims", "]"}]}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"inactivate", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"sum", "\[Rule]", "sum"}], ",", 
     RowBox[{"Sum", "\[Rule]", "sum"}]}], "}"}]}], ";", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"protect", " ", 
     RowBox[{"Inactive", "[", "Sum", "]"}], " ", "from", " ", "getting", " ", 
     "double"}], "-", "inactivated"}], "*)"}], "\n", 
  RowBox[{"unpower", "=", 
   RowBox[{
    RowBox[{"s_sum", "^", "p_Integer"}], "\[RuleDelayed]", 
    RowBox[{"Times", "@@", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Replace", "[", 
        RowBox[{"s", ",", "reindex", ",", "All"}], "]"}], ",", 
       RowBox[{"{", "p", "}"}]}], "]"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"expand", " ", "=", 
   RowBox[{"{", "\n", "\t", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"sum", "[", 
        RowBox[{"e1_", ",", "lims1__"}], "]"}], " ", 
       RowBox[{"sum", "[", 
        RowBox[{"e2_", ",", "lims2__"}], "]"}]}], " ", "\[RuleDelayed]", " ", 
      
      RowBox[{"With", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"r1", "=", 
           RowBox[{"reindexRules", "[", "lims1", "]"}]}], ",", 
          RowBox[{"r2", "=", 
           RowBox[{"reindexRules", "[", "lims2", "]"}]}]}], "}"}], ",", 
        RowBox[{"sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"e1", "/.", "r1"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"e2", "/.", "r2"}], ")"}]}], ",", 
          RowBox[{"lims1", "/.", "r1"}], ",", 
          RowBox[{"lims2", "/.", "r2"}]}], "]"}]}], "]"}]}], ",", "\n", "\t", 
     
     RowBox[{
      RowBox[{"sum", "[", 
       RowBox[{
        RowBox[{"sum", "[", 
         RowBox[{"e_", ",", "lims1__"}], "]"}], ",", "lims2__"}], "]"}], 
      "\[RuleDelayed]", 
      RowBox[{"sum", "[", 
       RowBox[{"e", ",", "lims1", ",", "lims2"}], "]"}]}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{"sum", "[", 
       RowBox[{"s_Plus", ",", "lims__"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"sum", "[", 
          RowBox[{"#", ",", "lims"}], "]"}], "&"}], "/@", "s"}], ")"}]}], ",",
      "\n", "\t", 
     RowBox[{
      RowBox[{"sum", "[", 
       RowBox[{
        RowBox[{"Times", "[", 
         RowBox[{"head___", ",", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"n_", "?", "NumberQ"}], ")"}], "|", "n_Symbol"}], ")"}], 
          ",", "tail___"}], "]"}], ",", "lims__"}], "]"}], "\[RuleDelayed]", 
      RowBox[{"n", " ", 
       RowBox[{"sum", "[", 
        RowBox[{
         RowBox[{"Times", "[", 
          RowBox[{"head", ",", "tail"}], "]"}], ",", "lims"}], "]"}]}]}]}], 
    "\n", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"distribute", " ", "=", " ", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"sum", "[", 
       RowBox[{"e_", ",", " ", "s__"}], "]"}], ",", " ", "i__"}], "]"}], " ", 
    "\[RuleDelayed]", " ", 
    RowBox[{"sum", "[", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{"e", ",", " ", "i"}], "]"}], ",", " ", "s"}], "]"}]}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"niceindex", "[", "expr_", "]"}], " ", ":=", " ", 
   RowBox[{"expr", " ", "/.", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{"#", " ", "\[Rule]", " ", 
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "i", ",", " ", "j", ",", " ", "k", ",", " ", "l", ",", "o", ",", 
             "p", ",", "q", ",", "r", ",", "s", ",", "t", ",", "u", ",", 
             "v"}], "}"}], ",", " ", 
           RowBox[{"Length", "[", "#", "]"}]}], "]"}]}], "]"}], " ", "&"}], 
      "@", 
      RowBox[{"DeleteDuplicates", "[", 
       RowBox[{"Cases", "[", 
        RowBox[{"expr", ",", " ", 
         RowBox[{
          RowBox[{"s_Symbol", " ", "/;", " ", 
           RowBox[{
            RowBox[{"SymbolName", "[", "s", "]"}], "~", "StringMatchQ", "~", 
            "\"\<*$*\>\""}]}], " ", "\[RuleDelayed]", " ", "s"}], ",", " ", 
         RowBox[{"-", "1"}]}], "]"}], "]"}]}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"doitall", "[", "expr_", "]"}], " ", ":=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Replace", "[", 
       RowBox[{
        RowBox[{"expr", "/.", "inactivate"}], ",", "reindex", ",", "All"}], 
       "]"}], "/.", "unpower"}], "//.", "expand"}], "//", "niceindex"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"LimVars", "[", "i_Symbol", "]"}], ":=", 
   RowBox[{"{", "i", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"LimVars", "[", 
    RowBox[{"{", 
     RowBox[{"i_Symbol", ",", "___"}], "}"}], "]"}], ":=", 
   RowBox[{"{", "i", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"LimVars", "[", 
    RowBox[{"first_", ",", "rest__"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sequence", "@@", 
      RowBox[{"LimVars", "[", "first", "]"}]}], ",", 
     RowBox[{"Sequence", "@@", 
      RowBox[{"LimVars", "[", "rest", "]"}]}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"IndependentQ", "[", 
    RowBox[{
     RowBox[{"expr_", "?", "NumberQ"}], ",", "_"}], "]"}], "=", "True"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"IndependentQ", "[", 
    RowBox[{"i_Symbol", ",", 
     RowBox[{"{", "}"}]}], "]"}], "=", "True"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"IndependentQ", "[", 
    RowBox[{"i_Symbol", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"j_Symbol", ",", "___"}], "}"}], ",", "tail___"}], "}"}]}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"i", "=!=", "j"}], ")"}], "&&", 
    RowBox[{"IndependentQ", "[", 
     RowBox[{"i", ",", 
      RowBox[{"{", "tail", "}"}]}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"IndependentQ", "[", 
    RowBox[{
     RowBox[{"head_", "[", "args___", "]"}], ",", "lims_"}], "]"}], ":=", 
   RowBox[{"And", "@@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"IndependentQ", "[", 
         RowBox[{"#", ",", "lims"}], "]"}], "&"}], ")"}], "/@", 
      RowBox[{"{", "args", "}"}]}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"eval", "=", 
    RowBox[{"{", "\n", "\t", 
     RowBox[{"(*", " ", 
      RowBox[{"Summation", " ", "of", " ", "dimension", " ", 
       RowBox[{"zero", ":", " ", 
        RowBox[{"evaluate", "."}]}]}], " ", "*)"}], "\n", "\t", 
     RowBox[{
      RowBox[{
       RowBox[{"sum", "[", "e_", "]"}], "\[Rule]", "e"}], ",", "\n", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{"Trivial", " ", 
        RowBox[{"summand", ":", " ", 
         RowBox[{"eliminate", " ", "one", " ", 
          RowBox[{"dimension", "."}]}]}]}], " ", "*)"}], "\n", "\t", 
      RowBox[{
       RowBox[{"sum", "[", 
        RowBox[{
         RowBox[{"x_", "?", "NumberQ"}], ",", 
         RowBox[{"{", 
          RowBox[{"i_", ",", "imin_", ",", "imax_"}], "}"}], ",", "tail___"}],
         "]"}], "\[RuleDelayed]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"imax", "-", "imin", "+", "1"}], ")"}], "x", " ", 
        RowBox[{"sum", "[", 
         RowBox[{"1", ",", "tail"}], "]"}]}]}], ",", "\n", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{"Kronecker", " ", 
        RowBox[{"delta", ":", " ", 
         RowBox[{"eliminate", " ", "one", " ", 
          RowBox[{"dimension", "."}]}]}]}], " ", "*)"}], "\n", "\t", 
      RowBox[{
       RowBox[{"sum", "[", 
        RowBox[{
         RowBox[{"Times", "[", 
          RowBox[{"head___", ",", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"KroneckerDelta", "[", 
              RowBox[{"i_", ",", "j_"}], "]"}], "|", 
             RowBox[{"KroneckerDelta", "[", 
              RowBox[{"j_", ",", "i_"}], "]"}]}], ")"}], ",", "tail___"}], 
          "]"}], ",", "lims1___", ",", 
         RowBox[{"{", 
          RowBox[{"i_", ",", "imin_", ",", "imax_"}], "}"}], ",", "lims2___", 
         ",", 
         RowBox[{"{", 
          RowBox[{"j_", ",", "jmin_", ",", "jmax_"}], "}"}], ",", 
         "lims3___"}], "]"}], "\[RuleDelayed]", 
       RowBox[{"sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Times", "[", 
           RowBox[{"head", ",", "tail"}], "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{"j", "\[Rule]", "i"}], "}"}]}], ",", "lims1", ",", "lims2",
          ",", "lims3", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Max", "[", 
            RowBox[{"imin", ",", "jmin"}], "]"}], ",", 
           RowBox[{"Min", "[", 
            RowBox[{"imax", ",", "jmax"}], "]"}]}], "}"}]}], "]"}]}], ",", 
      "\n", "\t", 
      RowBox[{"(*", " ", 
       RowBox[{
       "One", " ", "factor", " ", "in", " ", "summand", " ", "is", " ", 
        "independent", " ", "of", " ", "one", " ", 
        RowBox[{"index", ":", " ", 
         RowBox[{"hoist", " ", "it", " ", "out", " ", "of", " ", "the", " ", 
          RowBox[{"summation", "."}]}]}]}], " ", "*)"}], "\n", "\t", 
      RowBox[{
       RowBox[{
        RowBox[{"sum", "[", 
         RowBox[{
          RowBox[{"Times", "[", 
           RowBox[{"head___", ",", "e_", ",", "tail___"}], "]"}], ",", 
          "limhead___", ",", 
          RowBox[{"{", 
           RowBox[{"i_", ",", "imin_", ",", "imax_"}], "}"}], ",", 
          "limtail___"}], "]"}], "/;", 
        RowBox[{"IndependentQ", "[", 
         RowBox[{"e", ",", 
          RowBox[{"{", 
           RowBox[{"{", "i", "}"}], "}"}]}], "]"}]}], "\[RuleDelayed]", 
       RowBox[{"sum", "[", 
        RowBox[{
         RowBox[{"e", " ", 
          RowBox[{"sum", "[", 
           RowBox[{
            RowBox[{"Times", "[", 
             RowBox[{"head", ",", "tail"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "imin", ",", "imax"}], "}"}]}], "]"}]}], ",", 
         "limhead", ",", "limtail"}], "]"}]}]}], "\n", "}"}]}], ";"}], "\n", 
  RowBox[{"(*", 
   RowBox[{"Abs", "[", 
    RowBox[{
     RowBox[{"Sum", "[", "Times", "]"}], "\[LessEqual]", 
     RowBox[{"Sum", "[", 
      RowBox[{"Times", "[", "Abs", "]"}], "]"}]}], "]"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{"absSumUpperBound", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Abs", "[", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{"Times", "[", "args_", "]"}], ",", "lims__"}], "]"}], "]"}], 
     "\[Rule]", 
     RowBox[{"sum", "[", 
      RowBox[{
       RowBox[{"Times", "@@", 
        RowBox[{"(", 
         RowBox[{"Abs", "/@", 
          RowBox[{"{", "args", "}"}]}], ")"}]}], ",", "lims"}], "]"}]}], 
    "}"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.80566713190423*^9, 3.805667140382739*^9}, {
  3.8056872632560596`*^9, 3.8056872660839643`*^9}, {3.805691354315111*^9, 
  3.8056913616230183`*^9}, {3.805691408360919*^9, 3.805691440404232*^9}},
 CellLabel->
  "In[180]:=",ExpressionUUID->"918de53b-7e72-4183-89a2-3e250d3f0889"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Upper bound for Lipschitz constant of coherence function", "Subsection",
 CellChangeTimes->{{3.80566705581182*^9, 3.8056671083574*^9}, 
   3.805667308365692*^9},ExpressionUUID->"9ab0fbbb-f4dd-48cf-a34c-\
5b8bcf9de58c"],

Cell["\<\
We need to bound the gradient magnitude of the coherence function.\
\>", "Text",ExpressionUUID->"cd064aa0-3321-4909-ae16-9ad96db47432"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"n", ",", "m"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"vars", "=", 
   RowBox[{
    RowBox[{"Inactive", "[", "Table", "]"}], "[", 
    RowBox[{
     RowBox[{"X", "[", 
      RowBox[{"[", "k", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", 
       RowBox[{"m", "+", "1"}], ",", "n"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"gradient", "=", 
   RowBox[{"Activate", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"f", "[", "X", "]"}], ",", 
      RowBox[{"{", "vars", "}"}]}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"magnitudeBound", "=", 
   RowBox[{
    RowBox[{"Abs", "[", 
     RowBox[{
     "gradient", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     "]"}], "/.", "inactivate"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"magnitudeBound", "=", 
   RowBox[{"Activate", "[", 
    RowBox[{"magnitudeBound", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"KroneckerDelta", "[", 
           RowBox[{"j_", ",", "k"}], "]"}], " ", "e_"}], ",", 
         RowBox[{"{", 
          RowBox[{"j_", ",", 
           RowBox[{"1", "+", "m"}], ",", "n"}], "}"}]}], "]"}], 
       "\[RuleDelayed]", 
       RowBox[{
        RowBox[{"ReplaceAll", "[", 
         RowBox[{"j", "\[Rule]", "k"}], "]"}], "[", "e", "]"}]}], "}"}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"magnitudeBound", "=", 
   RowBox[{
    RowBox[{"magnitudeBound", "//", "ComplexExpand"}], "//", 
    "FullSimplify"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"magnitudeBound", "=", 
   RowBox[{"magnitudeBound", "/.", "absSumUpperBound"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"eigvecKnowledge", "=", 
   RowBox[{"{", "\n", "\t", 
    RowBox[{
     RowBox[{
      RowBox[{"Im", "[", 
       RowBox[{"sum", "[", 
        RowBox[{"x_", ",", "lims__"}], "]"}], "]"}], "\[Rule]", 
      RowBox[{"sum", "[", 
       RowBox[{
        RowBox[{"Im", "[", "x", "]"}], ",", "lims"}], "]"}]}], ",", "\n", 
     "\t", 
     RowBox[{
      RowBox[{"Im", "[", 
       RowBox[{
        RowBox[{"X", "\[LeftDoubleBracket]", "_", "\[RightDoubleBracket]"}], 
        " ", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
         "\[Lambda]", "\[LeftDoubleBracket]", "_", "\[RightDoubleBracket]"}], 
         "]"}], 
        RowBox[{"V", "\[LeftDoubleBracket]", 
         RowBox[{"_", ",", "_"}], "\[RightDoubleBracket]"}]}], "]"}], 
      "\[Rule]", "0"}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
         "\[Lambda]", "\[LeftDoubleBracket]", "k_", "\[RightDoubleBracket]"}],
          "]"}], "e_"}], "]"}], "\[RuleDelayed]", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
        "\[Lambda]", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}], 
        "]"}], 
       RowBox[{"Abs", "[", "e", "]"}]}]}], ",", 
     RowBox[{"(*", 
      RowBox[{"\[Lambda]", "\[GreaterEqual]", "0"}], "*)"}], "\n", "\t", 
     RowBox[{
      RowBox[{"sum", "[", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"V", "\[LeftDoubleBracket]", 
          RowBox[{"i_", ",", "k_"}], "\[RightDoubleBracket]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i_", ",", "1", ",", "n"}], "}"}]}], "]"}], "\[Rule]", 
      RowBox[{"Sqrt", "[", "n", "]"}]}], ",", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "norm"}], ")"}], "\[LessEqual]", 
       RowBox[{
        RowBox[{"\[Sqrt]", "n"}], "\[Times]", 
        RowBox[{"(", 
         RowBox[{"2", "-", "norm"}], ")"}]}]}], "*)"}], "\n", "\t", 
     RowBox[{
      RowBox[{
      "\[Lambda]", "\[LeftDoubleBracket]", "i_", "\[RightDoubleBracket]"}], 
      "\[RuleDelayed]", 
      RowBox[{
       RowBox[{"\[Sigma]", "^", "2"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Pi]", 
          RowBox[{"(", 
           RowBox[{"i", "-", 
            RowBox[{"1", "/", "2"}]}], ")"}]}], ")"}], "^", 
        RowBox[{"-", "4"}]}]}]}]}], "\n", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"magnitudeBound", "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{"n", ">", "0"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"doitall", "[", "magnitudeBound", "]"}], "//.", 
        RowBox[{"(", 
         RowBox[{"eval", "~", "Join", "~", "eigvecKnowledge"}], ")"}]}], 
       ")"}], "//", "FullSimplify"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"LipschitzUpperBound", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"magnitudeBound", "/.", 
    RowBox[{"{", 
     RowBox[{"k", "\[Rule]", 
      RowBox[{"m", "+", "1"}]}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.8056756952248096`*^9, 3.805675695845208*^9}, 
   3.8056872898970947`*^9, {3.805721171314268*^9, 
   3.805721174826117*^9}},ExpressionUUID->"2447c12c-c00f-44ea-b8fb-\
f642610d9e7a"],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", 
   SqrtBox[
    FractionBox[
     RowBox[{"n", " ", 
      SuperscriptBox["\[Sigma]", "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "m"}]}], ")"}], "4"]]]}], 
  RowBox[{"n", " ", 
   SuperscriptBox["\[Pi]", "2"]}]]], "Output",
 CellChangeTimes->{3.805663996121142*^9, 3.805667211699404*^9, 
  3.8056756974538803`*^9, 3.805675737945221*^9, 3.805689471935717*^9, 
  3.8056903178346167`*^9, 3.805691370416791*^9},
 CellLabel->
  "Out[165]=",ExpressionUUID->"51be32a3-91a1-49fc-9c1b-f8846b9644f6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Approximation for mean coherence", "Subsection",
 CellChangeTimes->{{3.805667040512354*^9, 
  3.805667049090624*^9}},ExpressionUUID->"2dde48ad-84f3-411a-86ba-\
24563f2924b6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fMeanSeries", "=", 
   RowBox[{"f", "[", "X", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"abs1p", "[", "z_", "]"}], "=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"ComplexExpand", "[", 
           RowBox[{"Abs", "[", 
            RowBox[{"1", "+", 
             RowBox[{"a", " ", "x"}], "+", 
             RowBox[{"\[ImaginaryI]", " ", "a", " ", "y"}]}], "]"}], "]"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "0", ",", "2"}], "}"}]}], "]"}], "//", 
        "Normal"}], ")"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "1"}], ",", 
        RowBox[{"x", "\[Rule]", 
         RowBox[{"Re", "[", "z", "]"}]}], ",", 
        RowBox[{"y", "\[Rule]", 
         RowBox[{"Im", "[", "z", "]"}]}]}], "}"}]}], ")"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"accurate", " ", "to", " ", "order", " ", 
    RowBox[{"O", "[", 
     RowBox[{"|", "z", "|", 
      RowBox[{"^", "3"}]}], "]"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{"fMeanSeries", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"fMeanSeries", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Abs", "[", "e_", "]"}], "\[Rule]", 
        RowBox[{"abs1p", "[", 
         RowBox[{"e", "-", "1"}], "]"}]}], "}"}]}], ")"}], "/.", 
    "inactivate"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"fMeanSeries", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"fMeanSeries", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"g_", "[", 
         RowBox[{"sum", "[", 
          RowBox[{"e_", ",", 
           RowBox[{"{", 
            RowBox[{"i_", ",", "1", ",", "n"}], "}"}]}], "]"}], "]"}], 
        "\[Rule]", 
        RowBox[{"sum", "[", 
         RowBox[{
          RowBox[{"g", "[", 
           RowBox[{"ExpToTrig", "[", "e", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}]}], "}"}]}], "//",
      "FullSimplify"}], ")"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"fMeanSeries", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"fMeanSeries", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"g_", "[", 
          RowBox[{"Exp", "[", 
           RowBox[{"\[ImaginaryI]", " ", "e_"}], "]"}], "]"}], "\[Rule]", 
         RowBox[{"g", "[", 
          RowBox[{"ExpToTrig", "[", 
           RowBox[{"Exp", "[", 
            RowBox[{"\[ImaginaryI]", " ", "e"}], "]"}], "]"}], "]"}]}], 
        "}"}]}], "//", "FullSimplify"}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Im", "[", "x_", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"Re", "[", "x_", "]"}], "\[Rule]", "x"}]}], "}"}]}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"fMeanSeries", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"fMeanSeries", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Sin", "[", "x_", "]"}], "\[Rule]", "x"}], ",", 
         RowBox[{
          RowBox[{"Cos", "[", "x_", "]"}], "\[Rule]", 
          RowBox[{"1", "-", 
           RowBox[{
            RowBox[{"x", "^", "2"}], "/", "2"}]}]}]}], "}"}]}], ")"}], "//", 
     "Activate"}], "//", "FullSimplify"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"fMeanSeries", "=", 
   RowBox[{"doitall", "[", "fMeanSeries", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"fMeanSeries", "=", 
   RowBox[{"(", 
    RowBox[{"fMeanSeries", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"X", "\[LeftDoubleBracket]", "i_", "\[RightDoubleBracket]"}], 
        
        RowBox[{
        "X", "\[LeftDoubleBracket]", "j_", "\[RightDoubleBracket]"}]}], 
       "\[RuleDelayed]", 
       RowBox[{"KroneckerDelta", "[", 
        RowBox[{"i", ",", "j"}], "]"}]}], "}"}]}], ")"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"eigvecKnowledge", "=", 
   RowBox[{"{", "\n", "\t", 
    RowBox[{
     RowBox[{
      RowBox[{"sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"V", "\[LeftDoubleBracket]", 
          RowBox[{"j_", ",", "i_"}], "\[RightDoubleBracket]"}], "^", "2"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"j_", ",", "1", ",", "n"}], "}"}]}], "]"}], "\[Rule]", "1"}],
      ",", "\n", "\t", 
     RowBox[{
      RowBox[{"sum", "[", 
       RowBox[{
        RowBox[{"V", "\[LeftDoubleBracket]", 
         RowBox[{"k_", ",", "i_"}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k_", ",", "1", ",", "n"}], "}"}]}], "]"}], "\[RuleDelayed]", 
      RowBox[{"2", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "^", "i"}], " ", "/", 
        RowBox[{"(", 
         RowBox[{"\[Pi]", 
          RowBox[{"(", 
           RowBox[{"i", "-", 
            RowBox[{"1", "/", "2"}]}], ")"}]}], ")"}]}]}]}], ",", "\n", "\t", 
     
     RowBox[{
      RowBox[{
      "\[Lambda]", "\[LeftDoubleBracket]", "i_", "\[RightDoubleBracket]"}], 
      "\[RuleDelayed]", 
      RowBox[{
       RowBox[{"\[Sigma]", "^", "2"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Pi]", 
          RowBox[{"(", 
           RowBox[{"i", "-", 
            RowBox[{"1", "/", "2"}]}], ")"}]}], ")"}], "^", 
        RowBox[{"-", "4"}]}]}]}]}], "\n", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"fMeanSeries", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Replace", "[", 
        RowBox[{"#", ",", "reindex", ",", "All"}], "]"}], "//", "niceindex"}],
       ")"}], "&"}], "/@", 
    RowBox[{"ExpandAll", "[", 
     RowBox[{"fMeanSeries", "//.", 
      RowBox[{"(", 
       RowBox[{"eval", "~", "Join", "~", "eigvecKnowledge"}], ")"}]}], 
     "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"fMeanSeries", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"fMeanSeries", "//", "FullSimplify"}], "//", "Activate"}], "//", 
    "ExpandAll"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"fMeanSeries", "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"n", "\[Element]", "Integers"}], "&&", 
      RowBox[{"m", "\[Element]", "Integers"}]}], ",", 
     RowBox[{"FullSimplify", "[", "fMeanSeries", "]"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"fMeanApprox", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "+", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"fMeanSeries", "-", "1"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "\[Infinity]", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", "\[Infinity]", ",", "4"}], "}"}]}], "]"}]}], "//", 
    "Normal"}], "//", "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.805675635489753*^9, 3.8056756368539*^9}, {
  3.805721176678836*^9, 
  3.8057211780459127`*^9}},ExpressionUUID->"d1c619bc-8eac-435e-9667-\
89020c94f64e"],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["m", "3"], "-", 
      SuperscriptBox["n", "3"]}], ")"}], " ", 
    SuperscriptBox["\[Sigma]", "2"]}], 
   RowBox[{"6", " ", 
    SuperscriptBox["m", "3"], " ", 
    SuperscriptBox["n", "4"], " ", 
    SuperscriptBox["\[Pi]", "4"]}]]}]], "Output",
 CellChangeTimes->{3.805664008732625*^9, 3.80567571033218*^9, 
  3.805675765014214*^9, 3.805676425346493*^9, 3.805689478437872*^9, 
  3.805690319965809*^9, 3.805691373340592*^9},
 CellLabel->
  "Out[178]=",ExpressionUUID->"e5441de2-4ff8-4cb3-8083-71468ec2f5b7"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tail Bound", "Subsection",
 CellChangeTimes->{{3.8056673301718063`*^9, 
  3.8056673340687513`*^9}},ExpressionUUID->"b6c5143b-fe0e-4e89-b528-\
7030a35b752f"],

Cell["\<\
We now have the pieces to evaluate a concentration bound for the sub-Gaussian \
random variable f[X], where X is a vector of i.i.d. standard Gaussian \
variables.

In the case where fMeanApprox > 1/2, the probability that the coherence \
function is less than 1/2 is at most\
\>", "Text",
 CellChangeTimes->{{3.8056813066813087`*^9, 3.805681308190481*^9}, {
  3.805681397548657*^9, 
  3.805681510095523*^9}},ExpressionUUID->"247336de-e4d5-4e45-a5f5-\
f4cb15dea2c8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"incoherenceProbabilityBound", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"fMeanApprox", "-", 
            RowBox[{"1", "/", "2"}]}], ")"}], "^", "2"}]}], "/", "2"}], "/", 
       RowBox[{"LipschitzUpperBound", "^", "2"}]}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{"n", "\[Rule]", 
       RowBox[{"Fs", " ", "T"}]}], "}"}]}], ")"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.805676343591239*^9, 3.805676377368479*^9}, {
  3.8056770890384912`*^9, 3.805677090189694*^9}},
 CellLabel->
  "In[179]:=",ExpressionUUID->"b2235601-7551-485b-9864-8cb3a698bdcb"],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"Fs", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Pi]", "+", 
        RowBox[{"2", " ", "m", " ", "\[Pi]"}]}], ")"}], "4"], " ", "T", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"3", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["m", "3"], "-", 
            RowBox[{
             SuperscriptBox["Fs", "3"], " ", 
             SuperscriptBox["T", "3"]}]}], ")"}], " ", 
          SuperscriptBox["\[Sigma]", "2"]}], 
         RowBox[{
          SuperscriptBox["Fs", "4"], " ", 
          SuperscriptBox["m", "3"], " ", 
          SuperscriptBox["\[Pi]", "4"], " ", 
          SuperscriptBox["T", "4"]}]]}], ")"}], "2"]}], 
    RowBox[{"1152", " ", 
     SuperscriptBox["\[Sigma]", "2"]}]]}]]], "Output",
 CellChangeTimes->{
  3.805666655246407*^9, {3.8056763313325453`*^9, 3.805676348137498*^9}, 
   3.8056764309480352`*^9, {3.805677090847731*^9, 3.805677098274514*^9}, 
   3.8056894826605787`*^9, 3.805690320226104*^9, 3.805691377718678*^9},
 CellLabel->
  "Out[179]=",ExpressionUUID->"90dd1aa4-9961-48b4-852a-552e4d828ee4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Physical units", "Subsection",
 CellChangeTimes->{{3.805675657867766*^9, 
  3.805675661822146*^9}},ExpressionUUID->"a30922fc-b56f-49ce-b2f7-\
8598786233d7"],

Cell["\<\
The integrated random walk process evaluated at time t may be scaled to units \
of radians by incorporating a factor \[Sigma].\
\>", "Text",
 CellChangeTimes->{{3.80567567111342*^9, 3.805675687811042*^9}, {
  3.805675985062677*^9, 3.805675995950602*^9}, {3.805676415801112*^9, 
  3.805676419351326*^9}, {3.805692186693584*^9, 
  3.805692233514402*^9}},ExpressionUUID->"a2644d50-4a19-416a-964b-\
7080862a16e4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ConcreteProblem", "[", "]"}], ":=", 
   RowBox[{"(", "\n", "\t", 
    RowBox[{
     RowBox[{"\[Lambda]", "=", 
      RowBox[{"UnitConvert", "[", 
       RowBox[{
        RowBox[{"Quantity", "[", "\"\<SpeedOfLight\>\"", "]"}], "/", 
        RowBox[{"Quantity", "[", 
         RowBox[{"75.", ",", "\"\<GigaHertz\>\""}], "]"}]}], "]"}]}], ";", 
     "\n", "\t", 
     RowBox[{
      RowBox[{"vRMS", "[", 
       RowBox[{"Quantity", "[", 
        RowBox[{"1", ",", "\"\<Seconds\>\""}], "]"}], "]"}], "=", 
      RowBox[{"Quantity", "[", 
       RowBox[{"1", ",", 
        RowBox[{"\"\<Meters\>\"", "/", "\"\<Seconds\>\""}]}], "]"}]}], ";", 
     "\n", "\t", 
     RowBox[{"T", "=", 
      RowBox[{"Quantity", "[", 
       RowBox[{"10", ",", "\"\<Seconds\>\""}], "]"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{"experiment", " ", "duration"}], "*)"}], "\n", "\t", 
     RowBox[{"Fs", "=", 
      RowBox[{"UnitConvert", "[", 
       RowBox[{"Quantity", "[", 
        RowBox[{"1000", ",", "\"\<Hertz\>\""}], "]"}], "]"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{"sampling", " ", "frequency", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"i", ".", "e", ".", " ", "chirp"}], " ", "rate"}], ")"}]}], 
      "*)"}], "\n", "\t", 
     RowBox[{"n", "=", 
      RowBox[{"Fs", " ", "T"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{"number", " ", "of", " ", "chirps"}], "*)"}], "\n", "\t", 
     RowBox[{"\[Sigma]0", "=", 
      RowBox[{
       FractionBox[
        RowBox[{"2", "\[Pi]"}], "\[Lambda]"], 
       SqrtBox[
        FractionBox["1", 
         RowBox[{"Quantity", "[", 
          RowBox[{"1", ",", "\"\<Seconds\>\""}], "]"}]]], 
       RowBox[{"vRMS", "[", 
        RowBox[{"Quantity", "[", 
         RowBox[{"1", ",", "\"\<Seconds\>\""}], "]"}], "]"}]}]}], ";", "\n", 
     "\t", 
     RowBox[{"\[Sigma]", "=", 
      RowBox[{"\[Sigma]0", " ", 
       RowBox[{"T", "^", 
        RowBox[{"(", 
         RowBox[{"3", "/", "2"}], ")"}]}]}]}], ";"}], "\n", "\t", ")"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"AbstractProblem", "[", "]"}], ":=", 
   RowBox[{"(", "\n", "\t", 
    RowBox[{"Clear", "[", 
     RowBox[{
     "\[Lambda]", ",", "vRMS", ",", "T", ",", "Fs", ",", "\[Sigma]", ",", 
      "\[Sigma]0", ",", "n"}], "]"}], "\n", ")"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.8056687780546083`*^9, 3.805668779432074*^9}, {
  3.8056688258585157`*^9, 3.805668852596963*^9}, {3.805668959091028*^9, 
  3.805668978826991*^9}, {3.805674865078492*^9, 3.805674906322928*^9}, {
  3.805675042517467*^9, 3.805675073606245*^9}, {3.8056751098507147`*^9, 
  3.805675151178632*^9}, {3.805675202523623*^9, 3.805675207944235*^9}, {
  3.8056752633264647`*^9, 3.805675362131813*^9}, {3.805675394444264*^9, 
  3.805675539555521*^9}, {3.8056763973632936`*^9, 3.80567641299317*^9}, {
  3.8056764448180113`*^9, 3.8056764788234243`*^9}, {3.805676513199844*^9, 
  3.805676529599264*^9}, {3.805680814699381*^9, 3.8056808405133553`*^9}, {
  3.8056809267553377`*^9, 3.805680942997324*^9}, {3.805689646760417*^9, 
  3.805689749823409*^9}},
 CellLabel->
  "In[110]:=",ExpressionUUID->"ce326168-4678-4727-9420-af7d6f50fbfe"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ConcreteProblem", "[", "]"}], ";"}], "\n", 
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{"incoherenceProbabilityBound", ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "1", ",", "30"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"RegionPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{"fMeanApprox", "<", 
        RowBox[{"1", "/", "2"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"-", "1"}], ",", "30"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[IndentingNewLine]", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"Opacity", "[", "1.0", "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1.0", ",", "0.5", ",", "0.5"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"BoundaryStyle", "\[Rule]", "None"}]}], "]"}]}], 
  "\[IndentingNewLine]", "]"}], "\n", 
 RowBox[{
  RowBox[{"AbstractProblem", "[", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.805675784312408*^9, 3.80567580064902*^9}, {
   3.805675833728314*^9, 3.805675935036195*^9}, {3.8056761351923437`*^9, 
   3.805676137320799*^9}, {3.80567627693849*^9, 3.8056762870825577`*^9}, 
   3.805676507464966*^9, 3.805676543152403*^9, 3.80567657391644*^9, {
   3.8056766065083723`*^9, 3.8056767366009293`*^9}, {3.805676772066566*^9, 
   3.805676855458293*^9}, {3.805676890789195*^9, 3.805676890966381*^9}, {
   3.805676923542252*^9, 3.805677059010234*^9}, 3.805677107481476*^9, {
   3.805690355463482*^9, 3.805690362962594*^9}},
 CellLabel->
  "In[134]:=",ExpressionUUID->"fb815bbd-e335-4ca5-9a0d-5dab2c988309"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwUV3c81e8Xt7OyMyJ7Z15c3Hs/n+coqSSpEFJk8xUlo0TZoWGEkGxSJJTQ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        "]]},
      Annotation[#, "Charting`Private`Tag$775117#1"]& ]}, {}}, {
    GraphicsComplexBox[CompressedData["
1:eJxdmHlcVOUeh9Fyo6bM0mxyQVIbE71u41aBiiGuTdo1cpnUq1SOa3qVuWm5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     "], {
      {RGBColor[1., 0.5, 0.5], AbsoluteThickness[1.6], Opacity[1.], EdgeForm[
       None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmHl81sURxmd/oNwJATHcSSAcgUDCKcghhHBaqAUthdpCA3hRQDxAVBRR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          "]], PolygonBox[CompressedData["
1:eJwtlWe812MYxp/7UZGG6ozOOZ3T6RwnK/OVV1555WNEZGWVkVUhMyKilIiI
IlIioqSskpGKiKxoiDQ0NDQ0NOR7fa7fi+/nue7n9///xj2up65Hny69c0pp
FDSC7pHSOngP/T5MRb8N/dH3a0/XYCD6YbgOvQU+QX8K09HTYAD6Qbga/RfM
QM+Eyei3oB/6XrgBvR3moOfCpegl8Cq6G9yM3gXz0V/BMbzsJOIjoQksg6Uw
kWuvw93a5zfL0b/B48T1xAfRCd0ZPgi/e6V+g14Ok9Bvwjz0XBiBfhruQGf+
vxi9BD4nng3D0U/qG9CHc30lepVyoFzAMD0b+qD3wrfohTAf/SWMRD8Lt6H/
gx/RP8EY9I5wLspYX4C/w7ktZX0RdodzUc56LsyEwcS1sBq9Cqai39Ez0Cfy
fi1Zj4ArYE34Wl84Ez0lXItD4Sz0+nDtm8Dz6I3h2pWwLoCvw/0yGv5Ar4DJ
6CnKCfoonteItTG8BPvC396W9Tz4GIYSd4Sx6IPhb69gPQfeDfdOCZytdw33
XgvVBH0c92+qvGsfWhKv5do6GExcRbwTvQsWE/8CE5J76mLlGsaiO8N4dLPs
2rVDXwBfhGt/qv6Dbsv1bej26K7Kfbh2p8Fr6HbZz6pFv6I8Z79LNfoS+BnG
E3dN7t1O2e+uHp4ItcT7uNYB3Q1+Dfdyd/W0fpfdu3XwBhydndt6uBxWhnPf
Cy5D/x7u5Z7Js9xDPZ880xeivwnX7nS4CP0djEGfoZlGl3P/rcnf/APx96pj
cs4WqVYwLvmbuqA/C/d6JxiKbs//9yZ/00L1vvo4+RkT0CVc34SuUZ2hDfHG
5L3zieeEZ+sUzST6pOzebYC14Z5Vr05P9qarwloeJW+5EqYle8w4/TbbC6rQ
L8Mh2bNcie6YnXPlOoe9YHhYyxPUy0+FvUY9LW+7FmYle5y860aYl+xh8sKe
ykmyJ8orr4fZyZ65rehx9bb2Nod7XL2te8oL+sKiZE/4EH2TehI9KNlbblVN
kj1G3thLM5nskf+GPUFesCDZe25RjZM9qCy75qr1FjhQzKRmUffcGfZIeaOe
+RG6d/heQ5K973b1dLIHavYeIF6fPIONs2uo2i1L9uJ71JPJnizv6wcrkj2w
afbMada0Nyv8TD1LHiHvvZN4abIHR3bPqdf0DvLqu8LPkme3yJ5RzeaaZK/q
H9byLPXiANiQ3JOts2dCs6A99eJDxJuTe1K9PzCcK82AvP4+4tXJnj8jXCPV
Rh6ss+4afUPymbcn7IFtixrJi4bAnmRPqsn2CHmD9jQ7jxHvT54heflIaB72
9BOyZ16zrj153aOsu5M9r1X2jNUUNdHZOAwOJJ+RddlnrM5W7cm7R2hGwh6u
2X8EvT3ZA+S1zxA3C3vusdkeI2/Rf3S2PsEa4TO2Mttj5a07kr1iUFjLM5pn
e2R1kcPSbI9tX+R8f/hMqCh6dkP4DNLZIw/bFD4TS4scbw2fmWXFzP0TPiPL
i5k8mfuPQreGVprhbE+oKnrqT9bR0CbsGSnbIyqLGazI9vjaIifV2Z7doch5
h2yPritq1pDt0fVFTg7LPmPaFTOgs/i54l10Jh+f7XENRY7/B86MR/E=
          
          "]]}]}, {}, {}, {}, {}}], {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 29.999999408163266`}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.805676996404992*^9, 3.805677060636074*^9}, 
   3.8056771091077538`*^9, {3.805681152442606*^9, 3.805681159697179*^9}, 
   3.8056903203494873`*^9, 3.805690364496476*^9},
 CellLabel->
  "Out[135]=",ExpressionUUID->"b89671b8-9d49-47a4-b17c-2f536a7fa2d6"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "\[Lambda]", ",", "vRMS", ",", "T", ",", "Fs", ",", "\[Sigma]", ",", 
   "\[Sigma]0", ",", "n"}], "]"}]], "Input",
 CellChangeTimes->{{3.805676316464609*^9, 3.8056763202913103`*^9}, {
  3.805676382373781*^9, 3.8056763929228563`*^9}, {3.805676510240959*^9, 
  3.8056765104222927`*^9}, {3.8056774978661203`*^9, 3.805677511811096*^9}, {
  3.805680947245845*^9, 3.805680949346634*^9}},
 CellLabel->
  "In[113]:=",ExpressionUUID->"13cfdba3-cd6d-40b4-80b7-61432497a089"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.805690013186256*^9, 3.80569002746669*^9}},
 CellLabel->
  "In[114]:=",ExpressionUUID->"816d52fc-f7ea-47f4-a617-85f02acb50f9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"degreeRelation", "=", 
   RowBox[{"Factor", "/@", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Times", "[", 
        RowBox[{"#", ",", 
         RowBox[{"1152", 
          RowBox[{"\[Sigma]", "^", "2"}], " ", 
          RowBox[{"T", "^", "7"}], " ", 
          RowBox[{"Fs", "^", "7"}], 
          RowBox[{"\[Pi]", "^", "4"}]}]}], "]"}], "&"}], "/@", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Log", "/@", 
          RowBox[{"(", 
           RowBox[{"incoherenceProbabilityBound", "\[Equal]", "\[Epsilon]"}], 
           ")"}]}], ")"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Log", "[", 
           RowBox[{"Exp", "[", "x_", "]"}], "]"}], "\[Rule]", "x"}], "}"}]}], 
       "]"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"degreeRelation", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"degreeRelation", "/.", 
     RowBox[{"{", 
      RowBox[{"T", "\[Rule]", 
       RowBox[{"n", "/", "Fs"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"asymptoticDegree", "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"T", ">", "0"}], "&&", 
      RowBox[{"\[Sigma]0", ">", "0"}], "&&", 
      RowBox[{
       RowBox[{"Log", "[", "\[Epsilon]", "]"}], "<", "0"}]}], ",", 
     RowBox[{
      RowBox[{"AsymptoticSolve", "[", 
       RowBox[{
        RowBox[{"degreeRelation", "/.", 
         RowBox[{"{", 
          RowBox[{"\[Sigma]", "\[Rule]", 
           RowBox[{"\[Sigma]0", " ", 
            RowBox[{"T", "^", 
             RowBox[{"(", 
              RowBox[{"3", "/", "2"}], ")"}]}]}]}], "}"}]}], ",", "m", ",", 
        RowBox[{"n", "\[Rule]", "\[Infinity]"}], ",", "Reals"}], "]"}], "//", 
      "FullSimplify"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"asymptoticDegree", "=", 
  RowBox[{"asymptoticDegree", "/.", 
   RowBox[{"{", 
    RowBox[{"n", "\[Rule]", 
     RowBox[{"Fs", " ", "T"}]}], "}"}]}]}]}], "Input",
 CellChangeTimes->{{3.805677425518548*^9, 3.805677858711677*^9}, {
  3.8056779447434893`*^9, 3.805678024528838*^9}, {3.805678128632979*^9, 
  3.80567827922801*^9}, {3.8056783909569473`*^9, 3.805678393060236*^9}, {
  3.8056787254621363`*^9, 3.805678733755808*^9}, {3.805678777746069*^9, 
  3.805678800725181*^9}, {3.805679166710878*^9, 3.8056792030074167`*^9}, {
  3.805680465758926*^9, 3.8056805015353727`*^9}},
 CellLabel->
  "In[115]:=",ExpressionUUID->"49c498e8-c0cb-46d4-9d27-6ae2838beda7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"m", "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"3", "/", "4"}]], " ", 
        SuperscriptBox["T", 
         RowBox[{"3", "/", "4"}]], " ", 
        SqrtBox["\[Sigma]0"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"Log", "[", "\[Epsilon]", "]"}], 
            RowBox[{"Fs", " ", "T"}]]}], ")"}], 
         RowBox[{"1", "/", "4"}]]}], "\[Pi]"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"m", "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"3", "/", "4"}]], " ", 
        SuperscriptBox["T", 
         RowBox[{"3", "/", "4"}]], " ", 
        SqrtBox["\[Sigma]0"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"Log", "[", "\[Epsilon]", "]"}], 
            RowBox[{"Fs", " ", "T"}]]}], ")"}], 
         RowBox[{"1", "/", "4"}]]}], "\[Pi]"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"m", "\[Rule]", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["1", 
          RowBox[{"Fs", " ", "T"}]], ")"}], 
        RowBox[{"1", "/", "3"}]], " ", "T", " ", 
       SuperscriptBox["\[Sigma]0", 
        RowBox[{"2", "/", "3"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["\[Pi]", "2"]}], "-", 
         RowBox[{"8", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["T", 
           RowBox[{"3", "/", "2"}]], " ", "\[Sigma]0", " ", 
          SqrtBox[
           RowBox[{"-", 
            FractionBox[
             RowBox[{"Log", "[", "\[Epsilon]", "]"}], 
             RowBox[{"Fs", " ", "T"}]]}]]}]}], ")"}]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["3", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"10", "/", "3"}]]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"m", "\[Rule]", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["1", 
          RowBox[{"Fs", " ", "T"}]], ")"}], 
        RowBox[{"1", "/", "3"}]], " ", "T", " ", 
       SuperscriptBox["\[Sigma]0", 
        RowBox[{"2", "/", "3"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["\[Pi]", "2"]}], "+", 
         RowBox[{"8", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["T", 
           RowBox[{"3", "/", "2"}]], " ", "\[Sigma]0", " ", 
          SqrtBox[
           RowBox[{"-", 
            FractionBox[
             RowBox[{"Log", "[", "\[Epsilon]", "]"}], 
             RowBox[{"Fs", " ", "T"}]]}]]}]}], ")"}]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["3", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["\[Pi]", 
        RowBox[{"10", "/", "3"}]]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.805677961991734*^9, {3.805677992801991*^9, 3.805678029194441*^9}, {
   3.805678155737069*^9, 3.805678284356988*^9}, 3.805678397708729*^9, 
   3.805678740453144*^9, {3.805678798371622*^9, 3.805678805473805*^9}, {
   3.805679186690695*^9, 3.805679207514083*^9}, {3.805680488721805*^9, 
   3.805680509076757*^9}, 3.8056811452198277`*^9, 3.805681178465616*^9, 
   3.805689590817609*^9, 3.8056900622506857`*^9, 3.8056903273946257`*^9},
 CellLabel->
  "Out[118]=",ExpressionUUID->"1ea4aedb-7f77-4801-993a-7afa12b3a9ea"]
}, Open  ]],

Cell["\<\
We want the solution in which m is an increasing function of \[Sigma]0 and T, \
ruling out the first and third options:\
\>", "Text",
 CellChangeTimes->{{3.8056787510971127`*^9, 3.8056787643200073`*^9}, {
   3.8056788081298122`*^9, 3.805678835690247*^9}, {3.805678888863742*^9, 
   3.805678914077277*^9}, {3.805678950804091*^9, 3.805678985556101*^9}, {
   3.805679159990053*^9, 3.8056791619291153`*^9}, {3.805679214198224*^9, 
   3.805679253442177*^9}, 3.805679309640386*^9, 3.805680523101536*^9, {
   3.805680867909181*^9, 3.805680868838969*^9}, {3.8056900758675747`*^9, 
   3.8056900789536867`*^9}},ExpressionUUID->"fdd3dc56-7b67-43e3-ad4a-\
9b0632b9cff2"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Log", "[", "\[Epsilon]", "]"}], "<", "0"}], "&&", 
    RowBox[{"n", ">", "0"}], "&&", 
    RowBox[{"Fs", ">", "0"}], "&&", 
    RowBox[{"T", ">", "0"}]}], ",", 
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{"asymptoticDegree", "\[LeftDoubleBracket]", 
      RowBox[{";;", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"\[Sigma]0", "\[Rule]", "\[Infinity]"}]}], "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Log", "[", "\[Epsilon]", "]"}], "<", "0"}], "&&", 
    RowBox[{"n", ">", "0"}], "&&", 
    RowBox[{"Fs", ">", "0"}], "&&", 
    RowBox[{"\[Sigma]0", ">", "0"}]}], ",", 
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{"asymptoticDegree", "\[LeftDoubleBracket]", 
      RowBox[{";;", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"T", "\[Rule]", "\[Infinity]"}]}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.805678438401559*^9, 3.805678510126947*^9}, {
  3.8056785686044493`*^9, 3.8056787020281067`*^9}, {3.8056787392858667`*^9, 
  3.8056787439462214`*^9}, {3.805678841141713*^9, 3.805678855849938*^9}, {
  3.805678917858551*^9, 3.805678932694406*^9}, {3.805679046304019*^9, 
  3.805679071890601*^9}, {3.805679260689927*^9, 3.805679294993018*^9}, {
  3.805680519705328*^9, 3.805680538030066*^9}, {3.8056896042776127`*^9, 
  3.805689620838727*^9}},
 CellLabel->
  "In[119]:=",ExpressionUUID->"90814a4c-5de1-4c33-abdb-f4a0d9eac320"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]", ",", 
   RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8056786070597*^9, {3.805678663339463*^9, 3.805678702302524*^9}, {
   3.805678846440628*^9, 3.80567885628428*^9}, {3.805678920209359*^9, 
   3.8056789490678*^9}, {3.8056790638645267`*^9, 3.805679072199843*^9}, {
   3.805679269213677*^9, 3.805679311090892*^9}, {3.805680533426237*^9, 
   3.8056805384325647`*^9}, 3.8056811838775597`*^9, {3.805689594856868*^9, 
   3.805689621556674*^9}, 3.805690066635826*^9, 3.805690327579976*^9},
 CellLabel->
  "Out[119]=",ExpressionUUID->"02ff5cad-9939-49b0-8ed8-8925af7cb6f2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]", ",", 
   RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8056786070597*^9, {3.805678663339463*^9, 3.805678702302524*^9}, {
   3.805678846440628*^9, 3.80567885628428*^9}, {3.805678920209359*^9, 
   3.8056789490678*^9}, {3.8056790638645267`*^9, 3.805679072199843*^9}, {
   3.805679269213677*^9, 3.805679311090892*^9}, {3.805680533426237*^9, 
   3.8056805384325647`*^9}, 3.8056811838775597`*^9, {3.805689594856868*^9, 
   3.805689621556674*^9}, 3.805690066635826*^9, 3.8056903277995377`*^9},
 CellLabel->
  "Out[120]=",ExpressionUUID->"3be2af9b-3903-4f20-bbaf-ca6c05a0ab1f"]
}, Open  ]],

Cell["\<\
Examining a concrete example corresponding to the plot above suggests that \
the second option is the right one.\
\>", "Text",
 CellChangeTimes->{{3.8056793166348333`*^9, 3.805679321996443*^9}, {
  3.8056802033957872`*^9, 3.8056802197016897`*^9}, {3.805721444540839*^9, 
  3.8057214653060007`*^9}},ExpressionUUID->"32d91bfc-e615-4c13-b02a-\
a31834b103b1"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ConcreteProblem", "[", "]"}], "\n", 
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"asymptoticDegree", "\[LeftDoubleBracket]", 
    RowBox[{";;", ",", "1"}], "\[RightDoubleBracket]"}], "/.", 
   RowBox[{"{", 
    RowBox[{"\[Epsilon]", "\[Rule]", 
     RowBox[{"10", "^", 
      RowBox[{"-", "3"}]}]}], "}"}]}], "]"}], "\n", 
 RowBox[{"AbstractProblem", "[", "]"}]}], "Input",
 CellChangeTimes->{{3.805680112554461*^9, 3.8056801524275427`*^9}, {
  3.805689781351034*^9, 3.805689784331334*^9}, {3.805689815652197*^9, 
  3.805689862652794*^9}},
 CellLabel->
  "In[121]:=",ExpressionUUID->"5e5f545d-0e26-48fc-bc28-d713eaaa6af9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"m", "\[Rule]", 
    RowBox[{"-", "19.849380916304113`"}]}], ",", 
   RowBox[{"m", "\[Rule]", "18.849380916304113`"}], ",", 
   RowBox[{"m", "\[Rule]", 
    RowBox[{"-", "4710.952577118305`"}]}], ",", 
   RowBox[{"m", "\[Rule]", "4729.864544045298`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.805689853613681*^9, 3.805689862945891*^9}, 
   3.805690090406951*^9, 3.8056903291108913`*^9},
 CellLabel->
  "Out[122]=",ExpressionUUID->"db34c549-9fb6-41de-a9ab-3a0fd80b903f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"asymptoticDegree", "\[LeftDoubleBracket]", 
  RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], "\n", 
 RowBox[{
  RowBox[{"ConcreteProblem", "[", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Clear", "[", "T", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"curve", "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{"T", ">", "0"}], ",", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"asymptoticDegree", "\[LeftDoubleBracket]", 
        RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]", "\[Rule]", ".001"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"m", "/.", "curve"}], ",", 
   RowBox[{"{", 
    RowBox[{"T", ",", 
     RowBox[{"Quantity", "[", 
      RowBox[{"0", ",", "\"\<Seconds\>\""}], "]"}], ",", 
     RowBox[{"Quantity", "[", 
      RowBox[{"100", ",", "\"\<Seconds\>\""}], "]"}]}], "}"}]}], 
  "]"}], "\n", 
 RowBox[{
  RowBox[{"AbstractProblem", "[", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.805681094821148*^9, 3.805681097014331*^9}, {
   3.8056898992146187`*^9, 3.805689912731436*^9}, {3.80568995571745*^9, 
   3.8056899780094357`*^9}, {3.8056901082368307`*^9, 3.8056901159654016`*^9}, 
   3.805692265506768*^9},
 CellLabel->
  "In[199]:=",ExpressionUUID->"761b5f38-6922-48f6-83e0-798f6de4e221"],

Cell[BoxData[
 RowBox[{"m", "\[Rule]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["2", 
      RowBox[{"3", "/", "4"}]], " ", 
     SuperscriptBox["T", 
      RowBox[{"3", "/", "4"}]], " ", 
     SqrtBox["\[Sigma]0"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"Log", "[", "\[Epsilon]", "]"}], 
         RowBox[{"Fs", " ", "T"}]]}], ")"}], 
      RowBox[{"1", "/", "4"}]]}], "\[Pi]"]}]}]], "Output",
 CellChangeTimes->{{3.805681254755454*^9, 3.805681267410963*^9}, {
   3.805689927789571*^9, 3.805689940687304*^9}, 3.805689978517562*^9, {
   3.805690111795418*^9, 3.80569011629447*^9}, 3.805690329252718*^9, 
   3.805692266017473*^9},
 CellLabel->
  "Out[199]=",ExpressionUUID->"2b4a9552-eba4-49c7-aeb9-a50dfe27e6be"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVj3s4lIkCh4fkdogk911D7toyxSjh+2HGfb6YXD4ViuyMwmpEKqyum1Dh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       "]]},
     Annotation[#, "Charting`Private`Tag$791418#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 100}, {-0.4912588407128976, 60.68811438534832}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.805681254755454*^9, 3.805681267410963*^9}, {
   3.805689927789571*^9, 3.805689940687304*^9}, 3.805689978517562*^9, {
   3.805690111795418*^9, 3.80569011629447*^9}, 3.805690329252718*^9, 
   3.80569226608702*^9},
 CellLabel->
  "Out[203]=",ExpressionUUID->"839456d5-5d86-49bb-b5c7-3c6994e4ba5b"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Asymptotic form for the roots of eigvaleqn", "Section",
 CellChangeTimes->{{3.8056670154518223`*^9, 
  3.805667028061644*^9}},ExpressionUUID->"496c2e71-1dd5-4d49-8d0f-\
6d94301ed47d"],

Cell["\<\
As a curio, while the eigenvalue relation for the integrated random walk \
lacks an obvious closed-form solution, we can express its solutions as a \
power series in Exp[-\[Pi](n-1/2)].\
\>", "Text",
 CellChangeTimes->{{3.805721481710744*^9, 3.805721606113347*^9}, 
   3.8057216377763166`*^9},ExpressionUUID->"6853f466-fecb-4030-b530-\
52750a595a81"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Phi]0", "=", 
   RowBox[{"\[Pi]", 
    RowBox[{"(", 
     RowBox[{"n", "-", 
      RowBox[{"1", "/", "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"s", "^", "2"}], "\[Equal]", "1"}], "&&", 
    RowBox[{
     RowBox[{"1", "/", "s"}], "\[Equal]", "s"}], "&&", 
    RowBox[{"n", "\[Element]", "Integers"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"residual", "=", 
     RowBox[{"Assuming", "[", 
      RowBox[{
       RowBox[{"n", "\[Element]", "Integers"}], ",", 
       RowBox[{"FullSimplify", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Equal", "@@", 
                RowBox[{
                 RowBox[{"Solve", "[", 
                  RowBox[{"eigvaleqn", ",", 
                   RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "]"}], 
                 "\[LeftDoubleBracket]", 
                 RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ")"}], 
              "/.", 
              RowBox[{"{", 
               RowBox[{"\[Phi]", "\[Rule]", 
                RowBox[{"\[Phi]0", "+", "e"}]}], "}"}]}], ")"}], "//", 
            "ExpandAll"}], "//", "TrigExpand"}], ")"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"n", " ", "\[Pi]"}], "]"}], "\[Rule]", "0"}], "}"}]}], 
        "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"residual", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"residual", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "^", "n"}], "\[Rule]", "s"}], ",", 
         RowBox[{"n", "\[Rule]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{"1", "/", "\[Pi]"}], ")"}]}], 
            RowBox[{"Log", "[", "u", "]"}]}], "+", 
           RowBox[{"1", "/", "2"}]}]}]}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"mRoot", "=", "8"}], ";", "\[IndentingNewLine]", 
    RowBox[{"residualSeries", "=", 
     RowBox[{"ExpToTrig", "[", 
      RowBox[{
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{"TrigToExp", "[", 
          RowBox[{
           RowBox[{
           "residual", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
            "-", 
           RowBox[{
           "residual", "\[LeftDoubleBracket]", "2", 
            "\[RightDoubleBracket]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"e", ",", "0", ",", 
           RowBox[{"mRoot", "-", "1"}]}], "}"}]}], "]"}], "//", 
       "FullSimplify"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"root", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"InverseSeries", "[", 
         RowBox[{"residualSeries", ",", "r"}], "]"}], "//", "Normal"}], ")"}],
       "/.", 
      RowBox[{"{", 
       RowBox[{"r", "\[Rule]", "0"}], "}"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"rootSeries", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Expand", "[", "root", "]"}], "+", 
        RowBox[{
         RowBox[{"O", "[", "u", "]"}], "^", "mRoot"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{"s", "\[Rule]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "^", "n"}]}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"rootSeries", "=", 
     RowBox[{"\[Phi]0", "+", "rootSeries"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"approxRoot", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Normal", "[", "rootSeries", "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{"u", "\[Rule]", 
        RowBox[{"Exp", "[", 
         RowBox[{"-", "\[Phi]0"}], "]"}]}], "}"}]}]}]}]}], "\n", 
  "]"}]}], "Input",
 CellChangeTimes->{{3.805664073522581*^9, 3.8056641049363747`*^9}, {
   3.80566415687713*^9, 3.805664176212717*^9}, {3.805664210534235*^9, 
   3.8056642333583*^9}, {3.805664264466282*^9, 3.805664292389175*^9}, {
   3.805664326249374*^9, 3.805664451575699*^9}, {3.805664530515584*^9, 
   3.80566453858177*^9}, {3.805664578293796*^9, 3.8056645785484056`*^9}, {
   3.805664730829171*^9, 3.8056648154652967`*^9}, {3.805664958675215*^9, 
   3.8056650138220377`*^9}, {3.805665045624497*^9, 3.805665087039896*^9}, {
   3.805665144887493*^9, 3.805665151518487*^9}, {3.8056651844760637`*^9, 
   3.80566523565874*^9}, {3.805665265789486*^9, 3.805665305412984*^9}, {
   3.805665346950564*^9, 3.805665351041564*^9}, {3.805665384908396*^9, 
   3.8056654190252666`*^9}, 3.8056654758421097`*^9, {3.8056657390565653`*^9, 
   3.8056657655474987`*^9}, {3.805666372512672*^9, 3.80566638109453*^9}, {
   3.8056664422223387`*^9, 3.805666626403419*^9}, {3.805692307264393*^9, 
   3.805692314902018*^9}},
 CellLabel->
  "In[205]:=",ExpressionUUID->"7e129803-b792-4ffe-a9f5-73e5de11fb6d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["124834", "63"]}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "n"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "7"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], "+", "n"}], ")"}], " ", "\[Pi]"}]]}], "-", 
  RowBox[{
   FractionBox["1516", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "6"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], "+", "n"}], ")"}], " ", "\[Pi]"}]]}], "-", 
  RowBox[{
   FractionBox["2006", "15"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "n"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "5"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], "+", "n"}], ")"}], " ", "\[Pi]"}]]}], "-", 
  RowBox[{
   FractionBox["112", "3"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "4"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], "+", "n"}], ")"}], " ", "\[Pi]"}]]}], "-", 
  RowBox[{
   FractionBox["34", "3"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "n"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], "+", "n"}], ")"}], " ", "\[Pi]"}]]}], "-", 
  RowBox[{"4", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], "+", "n"}], ")"}], " ", "\[Pi]"}]]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "n"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], "+", "n"}], ")"}]}], " ", "\[Pi]"}]]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], "+", "n"}], ")"}], " ", "\[Pi]"}]}]], "Output",\

 CellChangeTimes->{{3.805666455133196*^9, 3.805666523169924*^9}, {
   3.805666576673684*^9, 3.805666628948365*^9}, 3.805690130819153*^9, 
   3.805690331655442*^9, 3.8056923224682217`*^9},
 CellLabel->
  "Out[206]=",ExpressionUUID->"2cba9fe8-1998-4bd9-811a-edfc1c85b6e3"]
}, Open  ]],

Cell["Numerical test:", "Text",ExpressionUUID->"3909b8d0-50fb-47cb-a378-96a5d588064e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"neigval", "=", 
   RowBox[{
    RowBox[{"NSolve", "[", 
     RowBox[{
      RowBox[{"eigvaleqn", "&&", 
       RowBox[{"\[Phi]", ">", "0"}]}], ",", 
      RowBox[{"\[Phi]", "\[Element]", 
       RowBox[{"Interval", "[", 
        RowBox[{"{", 
         RowBox[{"0", ",", "200"}], "}"}], "]"}]}], ",", "Reals", ",", 
      RowBox[{"WorkingPrecision", "\[Rule]", "200"}]}], "]"}], 
    "\[LeftDoubleBracket]", 
    RowBox[{";;", ",", "1", ",", "2", ",", "1"}], "\[RightDoubleBracket]"}]}],
   ";"}], "\n", 
 RowBox[{
  RowBox[{"Log10", "[", 
   RowBox[{"Abs", "[", 
    RowBox[{
     RowBox[{"approxRoot", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], "]"}], 
     "-", 
     RowBox[{"neigval", "\[LeftDoubleBracket]", 
      RowBox[{"1", ";;", "5"}], "\[RightDoubleBracket]"}]}], "]"}], "]"}], "//",
   "N"}]}], "Input",
 CellLabel->
  "In[207]:=",ExpressionUUID->"75ffda1f-5967-452b-8ccf-3eca8fb17538"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.822026899370055`"}], ",", 
   RowBox[{"-", "12.453945313634057`"}], ",", 
   RowBox[{"-", "23.386013358570633`"}], ",", 
   RowBox[{"-", "34.30030122147117`"}], ",", 
   RowBox[{"-", "45.21534332019644`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.805666649489828*^9, 3.805690135343821*^9, 
  3.8056903318040867`*^9, 3.805692326385152*^9},
 CellLabel->
  "Out[208]=",ExpressionUUID->"15052e2b-bf0d-4d99-80df-744d71a44976"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1680, 1005},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
AutoIndent->True,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"7408eb08-395f-473f-9fb5-f5a3458e1e16"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 250, 4, 64, "Subsection",ExpressionUUID->"9fa8ee0a-d523-4b1b-91dc-be6a56914584"],
Cell[833, 28, 10410, 266, 908, "Input",ExpressionUUID->"a3e2d778-417d-43b2-b53f-65430206e861",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[11280, 299, 177, 3, 54, "Subsection",ExpressionUUID->"9c96a281-e8ec-4545-af4c-bfa21973e780"],
Cell[11460, 304, 214, 5, 35, "Text",ExpressionUUID->"9b97635e-3dfd-4222-9fff-6617474d2dfd"],
Cell[CellGroupData[{
Cell[11699, 313, 3138, 97, 178, "Input",ExpressionUUID->"ab3d85c3-4d0d-4150-ada7-d824d5804ef5"],
Cell[14840, 412, 663, 17, 52, "Output",ExpressionUUID->"636d89b4-7bb9-4c4c-8d9a-f0e6b8389f55"],
Cell[15506, 431, 232, 3, 34, "Output",ExpressionUUID->"679b4da0-8f97-4a70-96ef-ff3206242373"],
Cell[15741, 436, 107607, 1791, 210, "Output",ExpressionUUID->"9d30826f-51ec-40a2-9044-ab53f449c482"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[123397, 2233, 188, 3, 54, "Subsection",ExpressionUUID->"d79f531c-1f27-4671-a941-bc1ea125e65a"],
Cell[123588, 2238, 309, 4, 35, "Text",ExpressionUUID->"84b2ece9-c3c5-459e-9c9d-768ea5854c40"],
Cell[CellGroupData[{
Cell[123922, 2246, 5868, 169, 262, "Input",ExpressionUUID->"ad2719b7-b1ef-4a92-af3c-7ff696290ba3"],
Cell[129793, 2417, 2539, 70, 57, "Output",ExpressionUUID->"b663633e-e495-4f2c-8365-1ddd44726fd6"],
Cell[132335, 2489, 376, 5, 34, "Output",ExpressionUUID->"06f97131-5d75-4685-98f3-46cccf20d817"],
Cell[132714, 2496, 106485, 1773, 207, "Output",ExpressionUUID->"9eacef96-e250-49e3-a0c5-cc6e9f033e0f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[239236, 4274, 189, 3, 45, "Subsubsection",ExpressionUUID->"69a8645b-400c-4610-95c0-d3242a4130a2"],
Cell[239428, 4279, 229, 6, 35, "Text",ExpressionUUID->"2260c057-c3fc-42ae-b988-9162ebab53ac"],
Cell[CellGroupData[{
Cell[239682, 4289, 3203, 90, 226, "Input",ExpressionUUID->"e288f959-5262-4cfd-adb3-ece1ca708f01"],
Cell[242888, 4381, 9802, 195, 231, "Output",ExpressionUUID->"a8971e11-c50b-4424-9a1a-1ebfc5ec0c22"],
Cell[252693, 4578, 695, 17, 55, "Output",ExpressionUUID->"4f77f477-15c7-4bd0-b744-a75f40a27974"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[253449, 4602, 184, 3, 67, "Section",ExpressionUUID->"a165ee07-ee06-46bb-99c9-1789c837c884"],
Cell[CellGroupData[{
Cell[253658, 4609, 191, 3, 54, "Subsection",ExpressionUUID->"e90a49b0-f8e3-42bc-81c4-51e2a98a7dab"],
Cell[253852, 4614, 845, 15, 104, "Text",ExpressionUUID->"110beb83-f89a-4f43-8de4-207e4eb59407"],
Cell[254700, 4631, 1130, 32, 46, "Input",ExpressionUUID->"787e58d1-758b-4e4d-ab35-c8b8b7511b2e",
 InitializationCell->True],
Cell[255833, 4665, 714, 12, 58, "Text",ExpressionUUID->"24d854b3-d593-42f8-ab6e-ff6abde83d2a"],
Cell[256550, 4679, 12142, 351, 782, "Input",ExpressionUUID->"918de53b-7e72-4183-89a2-3e250d3f0889",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[268729, 5035, 224, 3, 54, "Subsection",ExpressionUUID->"9ab0fbbb-f4dd-48cf-a34c-5b8bcf9de58c"],
Cell[268956, 5040, 145, 2, 35, "Text",ExpressionUUID->"cd064aa0-3321-4909-ae16-9ad96db47432"],
Cell[CellGroupData[{
Cell[269126, 5046, 4913, 145, 350, "Input",ExpressionUUID->"2447c12c-c00f-44ea-b8fb-f642610d9e7a"],
Cell[274042, 5193, 598, 17, 75, "Output",ExpressionUUID->"51be32a3-91a1-49fc-9c1b-f8846b9644f6"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[274689, 5216, 180, 3, 54, "Subsection",ExpressionUUID->"2dde48ad-84f3-411a-86ba-24563f2924b6"],
Cell[CellGroupData[{
Cell[274894, 5223, 6805, 211, 367, "Input",ExpressionUUID->"d1c619bc-8eac-435e-9667-89020c94f64e"],
Cell[281702, 5436, 623, 17, 57, "Output",ExpressionUUID->"e5441de2-4ff8-4cb3-8083-71468ec2f5b7"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[282374, 5459, 162, 3, 54, "Subsection",ExpressionUUID->"b6c5143b-fe0e-4e89-b528-7030a35b752f"],
Cell[282539, 5464, 475, 11, 81, "Text",ExpressionUUID->"247336de-e4d5-4e45-a5f5-f4cb15dea2c8"],
Cell[CellGroupData[{
Cell[283039, 5479, 746, 21, 30, "Input",ExpressionUUID->"b2235601-7551-485b-9864-8cb3a698bdcb"],
Cell[283788, 5502, 1226, 33, 71, "Output",ExpressionUUID->"90dd1aa4-9961-48b4-852a-552e4d828ee4"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[285063, 5541, 162, 3, 54, "Subsection",ExpressionUUID->"a30922fc-b56f-49ce-b2f7-8598786233d7"],
Cell[285228, 5546, 419, 8, 35, "Text",ExpressionUUID->"a2644d50-4a19-416a-964b-7080862a16e4"],
Cell[285650, 5556, 3201, 79, 374, "Input",ExpressionUUID->"ce326168-4678-4727-9420-af7d6f50fbfe",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[288876, 5639, 1899, 44, 157, "Input",ExpressionUUID->"fb815bbd-e335-4ca5-9a0d-5dab2c988309"],
Cell[290778, 5685, 34210, 582, 256, "Output",ExpressionUUID->"b89671b8-9d49-47a4-b17c-2f536a7fa2d6"]
}, Open  ]],
Cell[325003, 6270, 515, 10, 30, "Input",ExpressionUUID->"13cfdba3-cd6d-40b4-80b7-61432497a089"],
Cell[325521, 6282, 174, 3, 30, "Input",ExpressionUUID->"816d52fc-f7ea-47f4-a617-85f02acb50f9"],
Cell[CellGroupData[{
Cell[325720, 6289, 2537, 67, 94, "Input",ExpressionUUID->"49c498e8-c0cb-46d4-9d27-6ae2838beda7"],
Cell[328260, 6358, 3663, 107, 64, "Output",ExpressionUUID->"1ea4aedb-7f77-4801-993a-7afa12b3a9ea"]
}, Open  ]],
Cell[331938, 6468, 668, 11, 35, "Text",ExpressionUUID->"fdd3dc56-7b67-43e3-ad4a-9b0632b9cff2"],
Cell[CellGroupData[{
Cell[332631, 6483, 1561, 36, 52, "Input",ExpressionUUID->"90814a4c-5de1-4c33-abdb-f4a0d9eac320"],
Cell[334195, 6521, 708, 13, 34, "Output",ExpressionUUID->"02ff5cad-9939-49b0-8ed8-8925af7cb6f2"],
Cell[334906, 6536, 710, 13, 34, "Output",ExpressionUUID->"3be2af9b-3903-4f20-bbaf-ca6c05a0ab1f"]
}, Open  ]],
Cell[335631, 6552, 365, 7, 35, "Text",ExpressionUUID->"32d91bfc-e615-4c13-b02a-a31834b103b1"],
Cell[CellGroupData[{
Cell[336021, 6563, 645, 15, 73, "Input",ExpressionUUID->"5e5f545d-0e26-48fc-bc28-d713eaaa6af9"],
Cell[336669, 6580, 522, 12, 34, "Output",ExpressionUUID->"db34c549-9fb6-41de-a9ab-3a0fd80b903f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[337228, 6597, 1372, 36, 136, "Input",ExpressionUUID->"761b5f38-6922-48f6-83e0-798f6de4e221"],
Cell[338603, 6635, 849, 24, 59, "Output",ExpressionUUID->"2b4a9552-eba4-49c7-aeb9-a50dfe27e6be"],
Cell[339455, 6661, 4290, 90, 239, "Output",ExpressionUUID->"839456d5-5d86-49bb-b5c7-3c6994e4ba5b"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[343806, 6758, 189, 3, 67, "Section",ExpressionUUID->"496c2e71-1dd5-4d49-8d0f-6d94301ed47d"],
Cell[343998, 6763, 360, 7, 35, "Text",ExpressionUUID->"6853f466-fecb-4030-b530-52750a595a81"],
Cell[CellGroupData[{
Cell[344383, 6774, 5049, 129, 241, "Input",ExpressionUUID->"7e129803-b792-4ffe-a9f5-73e5de11fb6d"],
Cell[349435, 6905, 2544, 86, 50, "Output",ExpressionUUID->"2cba9fe8-1998-4bd9-811a-edfc1c85b6e3"]
}, Open  ]],
Cell[351994, 6994, 86, 0, 35, "Text",ExpressionUUID->"3909b8d0-50fb-47cb-a378-96a5d588064e"],
Cell[CellGroupData[{
Cell[352105, 6998, 986, 28, 52, "Input",ExpressionUUID->"75ffda1f-5967-452b-8ccf-3eca8fb17538"],
Cell[353094, 7028, 481, 11, 34, "Output",ExpressionUUID->"15052e2b-bf0d-4d99-80df-744d71a44976"]
}, Open  ]]
}, Open  ]]
}
]
*)

